/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint no-unused-vars: warn */

// include required items for testing & logging
const assert = require('assert');
const fs = require('fs');
const mocha = require('mocha');
const path = require('path');
const winston = require('winston');
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');

const anything = td.matchers.anything();

// stub and attemptTimeout are used throughout the code so set them here
let logLevel = 'none';
const stub = true;
const isRapidFail = false;
const isSaveMockData = false;
const attemptTimeout = 5000;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
const host = 'replace.hostorip.here';
const username = 'username';
const password = 'password';
const protocol = 'http';
const port = 80;
const sslenable = false;
const sslinvalid = false;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-128technology',
      type: '128technology',
      properties: {
        host,
        port,
        base_path: '/',
        version: 'v1',
        cache_location: 'none',
        encode_pathvars: true,
        save_metric: false,
        stub,
        protocol,
        authentication: {
          auth_method: 'basic user_password',
          username,
          password,
          token: '',
          invalid_token_error: 401,
          token_timeout: -1,
          token_cache: 'local',
          auth_field: 'header.headers.Authorization',
          auth_field_format: 'Basic {b64}{username}:{password}{/b64}'
        },
        healthcheck: {
          type: 'startup',
          frequency: 60000
        },
        throttle: {
          throttle_enabled: false,
          number_pronghorns: 1,
          sync_async: 'sync',
          max_in_queue: 1000,
          concurrent_max: 1,
          expire_timeout: 0,
          avg_runtime: 200,
          priorities: [
            {
              value: 0,
              percent: 100
            }
          ]
        },
        request: {
          number_redirects: 0,
          number_retries: 3,
          limit_retry_error: [0],
          failover_codes: [],
          attempt_timeout: attemptTimeout,
          global_request: {
            payload: {},
            uriOptions: {},
            addlHeaders: {},
            authData: {}
          },
          healthcheck_on_timeout: true,
          return_raw: true,
          archiving: false
        },
        proxy: {
          enabled: false,
          host: '',
          port: 1,
          protocol: 'http'
        },
        ssl: {
          ecdhCurve: '',
          enabled: sslenable,
          accept_invalid_cert: sslinvalid,
          ca_file: '',
          key_file: '',
          cert_file: '',
          secure_protocol: '',
          ciphers: ''
        },
        mongo: {
          host: '',
          port: 0,
          database: '',
          username: '',
          password: '',
          replSet: '',
          db_ssl: {
            enabled: false,
            accept_invalid_cert: false,
            ca_file: '',
            key_file: '',
            cert_file: ''
          }
        }
      }
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = winston.createLogger({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the common asserts for test
 */
function runCommonAsserts(data, error) {
  assert.equal(undefined, error);
  assert.notEqual(undefined, data);
  assert.notEqual(null, data);
  assert.notEqual(undefined, data.response);
  assert.notEqual(null, data.response);
}

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

/**
 * @function saveMockData
 * Attempts to take data from responses and place them in MockDataFiles to help create Mockdata.
 * Note, this was built based on entity file structure for Adapter-Engine 1.6.x
 * @param {string} entityName - Name of the entity saving mock data for
 * @param {string} actionName -  Name of the action saving mock data for
 * @param {string} descriptor -  Something to describe this test (used as a type)
 * @param {string or object} responseData - The data to put in the mock file.
 */
function saveMockData(entityName, actionName, descriptor, responseData) {
  // do not need to save mockdata if we are running in stub mode (already has mock data) or if told not to save
  if (stub || !isSaveMockData) {
    return false;
  }

  // must have a response in order to store the response
  if (responseData && responseData.response) {
    let data = responseData.response;

    // if there was a raw response that one is better as it is untranslated
    if (responseData.raw) {
      data = responseData.raw;

      try {
        const temp = JSON.parse(data);
        data = temp;
      } catch (pex) {
        // do not care if it did not parse as we will just use data
      }
    }

    try {
      const base = path.join(__dirname, `../../entities/${entityName}/`);
      const mockdatafolder = 'mockdatafiles';
      const filename = `mockdatafiles/${actionName}-${descriptor}.json`;

      if (!fs.existsSync(base + mockdatafolder)) {
        fs.mkdirSync(base + mockdatafolder);
      }

      // write the data we retrieved
      fs.writeFile(base + filename, JSON.stringify(data, null, 2), 'utf8', (errWritingMock) => {
        if (errWritingMock) throw errWritingMock;

        // update the action file to reflect the changes. Note: We're replacing the default object for now!
        fs.readFile(`${base}action.json`, (errRead, content) => {
          if (errRead) throw errRead;

          // parse the action file into JSON
          const parsedJson = JSON.parse(content);

          // The object update we'll write in.
          const responseObj = {
            type: descriptor,
            key: '',
            mockFile: filename
          };

          // get the object for method we're trying to change.
          const currentMethodAction = parsedJson.actions.find((obj) => obj.name === actionName);

          // if the method was not found - should never happen but...
          if (!currentMethodAction) {
            throw Error('Can\'t find an action for this method in the provided entity.');
          }

          // if there is a response object, we want to replace the Response object. Otherwise we'll create one.
          const actionResponseObj = currentMethodAction.responseObjects.find((obj) => obj.type === descriptor);

          // Add the action responseObj back into the array of response objects.
          if (!actionResponseObj) {
            // if there is a default response object, we want to get the key.
            const defaultResponseObj = currentMethodAction.responseObjects.find((obj) => obj.type === 'default');

            // save the default key into the new response object
            if (defaultResponseObj) {
              responseObj.key = defaultResponseObj.key;
            }

            // save the new response object
            currentMethodAction.responseObjects = [responseObj];
          } else {
            // update the location of the mock data file
            actionResponseObj.mockFile = responseObj.mockFile;
          }

          // Save results
          fs.writeFile(`${base}action.json`, JSON.stringify(parsedJson, null, 2), (err) => {
            if (err) throw err;
          });
        });
      });
    } catch (e) {
      log.debug(`Failed to save mock data for ${actionName}. ${e.message}`);
      return false;
    }
  }

  // no response to save
  log.debug(`No data passed to save into mockdata for ${actionName}`);
  return false;
}

// require the adapter that we are going to be using
const Technology = require('../../adapter.js');

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[integration] 128technology Adapter Test', () => {
  describe('Technology Class Tests', () => {
    const a = new Technology(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#connect', () => {
      it('should get connected - no healthcheck', (done) => {
        try {
          a.healthcheckType = 'none';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
      it('should get connected - startup healthcheck', (done) => {
        try {
          a.healthcheckType = 'startup';
          a.connect();

          try {
            assert.equal(true, a.alive);
            done();
          } catch (error) {
            log.error(`Test Failure: ${error}`);
            done(error);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should be healthy', (done) => {
        try {
          a.healthCheck(null, (data) => {
            try {
              assert.equal(true, a.healthy);
              saveMockData('system', 'healthcheck', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    const alarmRouter = 'fakedata';
    const alarmNode = 'fakedata';
    describe('#getAlarm - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getAlarm(alarmRouter, alarmNode, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Alarm', 'getAlarm', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterAlarm - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterAlarm(alarmRouter, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Alarm', 'getRouterAlarm', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeAlarm - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeAlarm(alarmRouter, alarmNode, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Alarm', 'getRouterNodeAlarm', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const analyticsPostAnalyticsRunningTransformBodyParam = {
      metric: 'TCP_RETRANSMISSIONS',
      transform: 'sum',
      resolution: 4
    };
    describe('#postAnalyticsRunningTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postAnalyticsRunningTransform(analyticsPostAnalyticsRunningTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Analytics', 'postAnalyticsRunningTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const analyticsPostAnalyticsTransformBodyParam = {
      metric: 'BANDWIDTH_TCP',
      transform: 'rate'
    };
    describe('#postAnalyticsTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postAnalyticsTransform(analyticsPostAnalyticsTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal(9, data.response.result);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Analytics', 'postAnalyticsTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const assetAssetId = 'fakedata';
    const assetPutAssetIdControlBodyParam = {
      command: 'START'
    };
    describe('#putAssetIdControl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.putAssetIdControl(assetAssetId, assetPutAssetIdControlBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Asset', 'putAssetIdControl', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getAudit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getAudit(null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Audit', 'getAudit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getAuditDownload - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getAuditDownload(null, null, null, null, null, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Audit', 'getAuditDownload', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigCommitBodyParam = {
      distributed: true
    };
    describe('#postConfigCommit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigCommit(configPostConfigCommitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigCommit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigExportBodyParam = {
      filename: 'string',
      datastore: 'running'
    };
    describe('#postConfigExport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigExport(configPostConfigExportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response['export-path']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigExport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigImportBodyParam = {
      filename: 'string'
    };
    describe('#postConfigImport - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigImport(configPostConfigImportBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigImport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postConfigRevertToRunning - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRevertToRunning((data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRevertToRunning', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigValidateBodyParam = {
      distributed: true
    };
    describe('#postConfigValidate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigValidate(configPostConfigValidateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigValidate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configConfigStore = 'fakedata';
    let configNeighborhood = 'fakedata';
    const configPostConfigStoreAuthorityDistrictBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityDistrict - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityDistrict(configConfigStore, configPostConfigStoreAuthorityDistrictBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal(true, Array.isArray(data.response.neighborhood));
              } else {
                runCommonAsserts(data, error);
              }
              configNeighborhood = data.response.neighborhood;
              saveMockData('Config', 'postConfigStoreAuthorityDistrict', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityDistrictCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityDistrictClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityDistrictClone(configConfigStore, configPostConfigStoreAuthorityDistrictCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityDistrictClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityDscpMapBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityDscpMap - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityDscpMap(configConfigStore, configPostConfigStoreAuthorityDscpMapBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityDscpMap', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityDscpMapCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityDscpMapClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityDscpMapClone(configConfigStore, configPostConfigStoreAuthorityDscpMapCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityDscpMapClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDscpmap = 'fakedata';
    const configPostConfigDscpMapDscpmapPrioritizationBodyParam = {
      priority: 'string'
    };
    describe('#postConfigDscpMapDscpmapPrioritization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDscpMapDscpmapPrioritization(configConfigStore, configDscpmap, configPostConfigDscpMapDscpmapPrioritizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDscpMapDscpmapPrioritization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMapDscpmapDscpPrioritizationCloneBodyParam = {
      priority: 'string'
    };
    describe('#postConfigMapDscpmapDscpPrioritizationClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigMapDscpmapDscpPrioritizationClone(configConfigStore, configDscpmap, configPostConfigMapDscpmapDscpPrioritizationCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMapDscpmapDscpPrioritizationClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDscpprioritization = 'fakedata';
    const configPostConfigDscpPrioritizationDscpprioritizationRangeBodyParam = {
      'start-value': 'string'
    };
    describe('#postConfigDscpPrioritizationDscpprioritizationRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDscpPrioritizationDscpprioritizationRange(configConfigStore, configDscpmap, configDscpprioritization, configPostConfigDscpPrioritizationDscpprioritizationRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(2, data.response['start-value']);
                assert.equal(2, data.response['end-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDscpPrioritizationDscpprioritizationRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPrioritizationDscpprioritizationDscpRangeCloneBodyParam = {
      'start-value': 'string'
    };
    describe('#postConfigPrioritizationDscpprioritizationDscpRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPrioritizationDscpprioritizationDscpRangeClone(configConfigStore, configDscpmap, configDscpprioritization, configPostConfigPrioritizationDscpprioritizationDscpRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPrioritizationDscpprioritizationDscpRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMapDscpmapDscpTrafficClassBodyParam = {
      'traffic-class': 'string'
    };
    describe('#postConfigMapDscpmapDscpTrafficClass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigMapDscpmapDscpTrafficClass(configConfigStore, configDscpmap, configPostConfigMapDscpmapDscpTrafficClassBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['traffic-class']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMapDscpmapDscpTrafficClass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigDscpmapDscpTrafficClassCloneBodyParam = {
      'traffic-class': 'string'
    };
    describe('#postConfigDscpmapDscpTrafficClassClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigDscpmapDscpTrafficClassClone(configConfigStore, configDscpmap, configPostConfigDscpmapDscpTrafficClassCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDscpmapDscpTrafficClassClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDscptrafficclass = 'fakedata';
    const configPostConfigTrafficClassDscptrafficclassDscpRangeBodyParam = {
      'start-value': 'string'
    };
    describe('#postConfigTrafficClassDscptrafficclassDscpRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigTrafficClassDscptrafficclassDscpRange(configConfigStore, configDscpmap, configDscptrafficclass, configPostConfigTrafficClassDscptrafficclassDscpRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response['start-value']);
                assert.equal(10, data.response['end-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTrafficClassDscptrafficclassDscpRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigClassDscptrafficclassDscpRangeCloneBodyParam = {
      'start-value': 'string'
    };
    describe('#postConfigClassDscptrafficclassDscpRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigClassDscptrafficclassDscpRangeClone(configConfigStore, configDscpmap, configDscptrafficclass, configPostConfigClassDscptrafficclassDscpRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigClassDscptrafficclassDscpRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configTenant = 'fakedata';
    const configPostConfigStoreAuthorityIpfixCollectorBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityIpfixCollector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityIpfixCollector(configConfigStore, configPostConfigStoreAuthorityIpfixCollectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['ip-address']);
                assert.equal(3, data.response.port);
                assert.equal('string', data.response.protocol);
                assert.equal(4, data.response['interim-record-interval']);
                assert.equal(10, data.response['template-refresh-interval']);
                assert.equal('string', data.response['sampling-percentage']);
                assert.equal(true, Array.isArray(data.response.tenant));
              } else {
                runCommonAsserts(data, error);
              }
              configTenant = data.response.tenant;
              saveMockData('Config', 'postConfigStoreAuthorityIpfixCollector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityIpfixCollectorCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityIpfixCollectorClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityIpfixCollectorClone(configConfigStore, configPostConfigStoreAuthorityIpfixCollectorCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityIpfixCollectorClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configAddress = 'fakedata';
    const configPostConfigStoreAuthorityLdapServerBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityLdapServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityLdapServer(configConfigStore, configPostConfigStoreAuthorityLdapServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.address);
                assert.equal('string', data.response['search-base']);
                assert.equal('string', data.response['server-type']);
                assert.equal('string', data.response.port);
                assert.equal('string', data.response['bind-type']);
                assert.equal('string', data.response['distinguished-name']);
                assert.equal('string', data.response.password);
              } else {
                runCommonAsserts(data, error);
              }
              configAddress = data.response.address;
              saveMockData('Config', 'postConfigStoreAuthorityLdapServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityLdapServerCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityLdapServerClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityLdapServerClone(configConfigStore, configPostConfigStoreAuthorityLdapServerCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityLdapServerClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityRouterBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityRouter(configConfigStore, configPostConfigStoreAuthorityRouterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response['location-coordinates']);
                assert.equal('string', data.response.description);
                assert.equal(true, Array.isArray(data.response['router-group']));
                assert.equal(true, Array.isArray(data.response['conductor-address']));
                assert.equal('string', data.response['maintenance-mode']);
                assert.equal('string', data.response['inter-node-security']);
                assert.equal('string', data.response['reverse-flow-enforcement']);
                assert.equal(true, Array.isArray(data.response['administrative-group']));
                assert.equal('string', data.response['dhcp-server-generated-address-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityRouterCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityRouterClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityRouterClone(configConfigStore, configPostConfigStoreAuthorityRouterCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityRouterClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRouter = 'fakedata';
    const configPostConfigAuthorityRouterDistrictSettingsBodyParam = {
      'district-name': 'string'
    };
    describe('#postConfigAuthorityRouterDistrictSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterDistrictSettings(configConfigStore, configRouter, configPostConfigAuthorityRouterDistrictSettingsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['district-name']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterDistrictSettings', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterDistrictSettingsCloneBodyParam = {
      'district-name': 'string'
    };
    describe('#postConfigRouterDistrictSettingsClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterDistrictSettingsClone(configConfigStore, configRouter, configPostConfigRouterDistrictSettingsCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterDistrictSettingsClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterDnsBodyParam = {
      mode: 'string'
    };
    describe('#postConfigAuthorityRouterDns - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterDns(configConfigStore, configRouter, configPostConfigAuthorityRouterDnsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(true, Array.isArray(data.response.address));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterDns', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterDnsCloneBodyParam = {
      mode: 'string'
    };
    describe('#postConfigRouterDnsClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterDnsClone(configConfigStore, configRouter, configPostConfigRouterDnsCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterDnsClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterNatPoolBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRouterNatPool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterNatPool(configConfigStore, configRouter, configPostConfigAuthorityRouterNatPoolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterNatPool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterNatPoolCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterNatPoolClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterNatPoolClone(configConfigStore, configRouter, configPostConfigRouterNatPoolCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterNatPoolClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNatpool = 'fakedata';
    const configPostConfigNatPoolNatpoolAddressBodyParam = {
      address: 'string'
    };
    describe('#postConfigNatPoolNatpoolAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNatPoolNatpoolAddress(configConfigStore, configRouter, configNatpool, configPostConfigNatPoolNatpoolAddressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response['tenant-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNatPoolNatpoolAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPoolNatpoolAddressCloneBodyParam = {
      address: 'string'
    };
    describe('#postConfigPoolNatpoolAddressClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPoolNatpoolAddressClone(configConfigStore, configRouter, configNatpool, configPostConfigPoolNatpoolAddressCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPoolNatpoolAddressClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPoolNatpoolAddressMoveBodyParam = {
      position: 'first'
    };
    describe('#postConfigPoolNatpoolAddressMove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPoolNatpoolAddressMove(configConfigStore, configRouter, configNatpool, configPostConfigPoolNatpoolAddressMoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPoolNatpoolAddressMove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterNodeBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRouterNode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterNode(configConfigStore, configRouter, configPostConfigAuthorityRouterNodeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['asset-id']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.role);
                assert.equal('string', data.response['asset-validation-enabled']);
                assert.equal('string', data.response['usage-reporter-enabled']);
                assert.equal('string', data.response['forwarding-core-mode']);
                assert.equal(5, data.response['forwarding-core-count']);
                assert.equal('string', data.response['power-saver']);
                assert.equal('string', data.response['clean-before-install']);
                assert.equal('string', data.response['clean-after-failed-install']);
                assert.equal('string', data.response['software-update-bandwidth']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterNodeCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterNodeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterNodeClone(configConfigStore, configRouter, configPostConfigRouterNodeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterNodeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNode = 'fakedata';
    const configPostConfigRouterNodeDeviceInterfaceBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterNodeDeviceInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterNodeDeviceInterface(configConfigStore, configRouter, configNode, configPostConfigRouterNodeDeviceInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['pci-address']);
                assert.equal('string', data.response['link-settings']);
                assert.equal('string', data.response.mode);
                assert.equal('string', data.response['target-interface']);
                assert.equal('string', data.response['bridge-name']);
                assert.equal('string', data.response['network-namespace']);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.forwarding);
                assert.equal(true, Array.isArray(data.response['capture-filter']));
                assert.equal('string', data.response['shared-phys-address']);
                assert.equal('string', data.response['strip-vlan']);
                assert.equal('string', data.response['promiscuous-mode']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterNodeDeviceInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNodeDeviceInterfaceCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigNodeDeviceInterfaceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNodeDeviceInterfaceClone(configConfigStore, configRouter, configNode, configPostConfigNodeDeviceInterfaceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNodeDeviceInterfaceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDeviceinterface = 'fakedata';
    const configPostConfigDeviceInterfaceDeviceinterfaceNetworkBodyParam = {
      name: 'string'
    };
    describe('#postConfigDeviceInterfaceDeviceinterfaceNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDeviceInterfaceDeviceinterfaceNetwork(configConfigStore, configRouter, configNode, configDeviceinterface, configPostConfigDeviceInterfaceDeviceinterfaceNetworkBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal(10, data.response['global-id']);
                assert.equal('string', data.response.description);
                assert.equal(6, data.response.vlan);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.conductor);
                assert.equal('string', data.response['default-route']);
                assert.equal('string', data.response.tenant);
                assert.equal('string', data.response['inter-router-security']);
                assert.equal('string', data.response['rewrite-dscp']);
                assert.equal('string', data.response['prioritization-mode']);
                assert.equal('string', data.response['dscp-map']);
                assert.equal('string', data.response.classify);
                assert.equal('string', data.response['source-nat']);
                assert.equal(2, data.response['qp-value']);
                assert.equal(7, data.response.mtu);
                assert.equal('string', data.response['enforced-mss']);
                assert.equal('string', data.response.hostname);
                assert.equal('string', data.response.management);
                assert.equal('string', data.response.icmp);
                assert.equal(true, Array.isArray(data.response['off-subnet-arp-prefix']));
                assert.equal('string', data.response['multicast-listeners']);
                assert.equal('string', data.response['multicast-report-proxy']);
                assert.equal('string', data.response.dhcp);
                assert.equal('string', data.response['reverse-arp-mac-learning']);
                assert.equal('string', data.response['prefix-delegation']);
                assert.equal('string', data.response['prefix-delegation-group']);
                assert.equal(9, data.response['prefix-delegation-subnet-id']);
                assert.equal('string', data.response['router-advertisement']);
                assert.equal('string', data.response['prefix-delegation-authentication']);
                assert.equal('string', data.response['dhcp-reconfig-auth-algorithm']);
                assert.equal('string', data.response['dhcp-delayed-auth-realm']);
                assert.equal(10, data.response['dhcp-delayed-auth-key-id']);
                assert.equal('string', data.response['dhcp-delayed-auth-key']);
                assert.equal('string', data.response['ingress-source-nat-pool']);
                assert.equal('string', data.response['egress-source-nat-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDeviceInterfaceDeviceinterfaceNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigInterfaceDeviceinterfaceNetworkCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigInterfaceDeviceinterfaceNetworkClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigInterfaceDeviceinterfaceNetworkClone(configConfigStore, configRouter, configNode, configDeviceinterface, configPostConfigInterfaceDeviceinterfaceNetworkCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigInterfaceDeviceinterfaceNetworkClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNetworkinterface = 'fakedata';
    const configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddressBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['utility-ip-address']);
                assert.equal(8, data.response['prefix-length']);
                assert.equal('string', data.response.gateway);
                assert.equal('string', data.response['ppp-peer-ip']);
                assert.equal(true, Array.isArray(data.response['in-subnet-arp-prefix']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceAddressCloneBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceAddressClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceAddressClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceAddressCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceAddressClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkinterfaceAddressHostServiceBodyParam = {
      'service-type': 'string'
    };
    describe('#postConfigNetworkinterfaceAddressHostService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkinterfaceAddressHostService(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configPostConfigNetworkinterfaceAddressHostServiceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-type']);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response['server-name']);
                assert.equal(2, data.response['max-lease-time']);
                assert.equal('string', data.response['echo-client-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkinterfaceAddressHostService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressHostServiceCloneBodyParam = {
      'service-type': 'string'
    };
    describe('#postConfigAddressHostServiceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAddressHostServiceClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configPostConfigAddressHostServiceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressHostServiceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configSource = 'fakedata';
    const configHostservice = 'fakedata';
    const configPostConfigHostServiceHostserviceAccessPolicyBodyParam = {
      source: 'string'
    };
    describe('#postConfigHostServiceHostserviceAccessPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostServiceHostserviceAccessPolicy(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigHostServiceHostserviceAccessPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              configSource = data.response.source;
              saveMockData('Config', 'postConfigHostServiceHostserviceAccessPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceHostserviceAccessPolicyCloneBodyParam = {
      source: 'string'
    };
    describe('#postConfigServiceHostserviceAccessPolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceHostserviceAccessPolicyClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigServiceHostserviceAccessPolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceHostserviceAccessPolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostServiceHostserviceAddressPoolBodyParam = {
      'start-address': 'string'
    };
    describe('#postConfigHostServiceHostserviceAddressPool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostServiceHostserviceAddressPool(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigHostServiceHostserviceAddressPoolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['start-address']);
                assert.equal('string', data.response['end-address']);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(6, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostServiceHostserviceAddressPool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceHostserviceAddressPoolCloneBodyParam = {
      'start-address': 'string'
    };
    describe('#postConfigServiceHostserviceAddressPoolClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceHostserviceAddressPoolClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigServiceHostserviceAddressPoolCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceHostserviceAddressPoolClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAddresspool = 'fakedata';
    const configPostConfigHostserviceAddressPoolAddresspoolCustomBodyParam = {
      code: 'string'
    };
    describe('#postConfigHostserviceAddressPoolAddresspoolCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostserviceAddressPoolAddresspoolCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigHostserviceAddressPoolAddresspoolCustomBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostserviceAddressPoolAddresspoolCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressPoolAddresspoolCustomCloneBodyParam = {
      code: 'string'
    };
    describe('#postConfigAddressPoolAddresspoolCustomClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAddressPoolAddresspoolCustomClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigAddressPoolAddresspoolCustomCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressPoolAddresspoolCustomClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressPoolAddresspoolStaticAssignmentBodyParam = {
      address: 'string'
    };
    describe('#postConfigAddressPoolAddresspoolStaticAssignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAddressPoolAddresspoolStaticAssignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigAddressPoolAddresspoolStaticAssignmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['link-layer-address']);
                assert.equal('string', data.response['client-identifier']);
                assert.equal('string', data.response['circuit-identifier']);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(1, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressPoolAddresspoolStaticAssignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPoolAddresspoolStaticAssignmentCloneBodyParam = {
      address: 'string'
    };
    describe('#postConfigPoolAddresspoolStaticAssignmentClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPoolAddresspoolStaticAssignmentClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigPoolAddresspoolStaticAssignmentCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPoolAddresspoolStaticAssignmentClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configStaticassignment = 'fakedata';
    const configPostConfigAddresspoolStaticAssignmentStaticassignmentCustomBodyParam = {
      code: 'string'
    };
    describe('#postConfigAddresspoolStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAddresspoolStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigAddresspoolStaticAssignmentStaticassignmentCustomBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddresspoolStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticAssignmentStaticassignmentCustomCloneBodyParam = {
      code: 'string'
    };
    describe('#postConfigStaticAssignmentStaticassignmentCustomClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStaticAssignmentStaticassignmentCustomClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigStaticAssignmentStaticassignmentCustomCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticAssignmentStaticassignmentCustomClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticAssignmentStaticassignmentRouteBodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigStaticAssignmentStaticassignmentRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStaticAssignmentStaticassignmentRoute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigStaticAssignmentStaticassignmentRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticAssignmentStaticassignmentRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAssignmentStaticassignmentStaticRouteCloneBodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigAssignmentStaticassignmentStaticRouteClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAssignmentStaticassignmentStaticRouteClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigAssignmentStaticassignmentStaticRouteCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAssignmentStaticassignmentStaticRouteClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigVendorIdentifyingSpecificInformationBodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigVendorIdentifyingSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigVendorIdentifyingSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigVendorIdentifyingSpecificInformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response['enterprise-number']);
                assert.equal(10, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigVendorIdentifyingSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigIdentifyingVendorSpecificInformationCloneBodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigIdentifyingVendorSpecificInformationClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigIdentifyingVendorSpecificInformationClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigIdentifyingVendorSpecificInformationCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigIdentifyingVendorSpecificInformationClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAssignmentStaticassignmentVendorSpecificInformationBodyParam = {
      code: 'string'
    };
    describe('#postConfigAssignmentStaticassignmentVendorSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAssignmentStaticassignmentVendorSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigAssignmentStaticassignmentVendorSpecificInformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAssignmentStaticassignmentVendorSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticassignmentVendorSpecificInformationCloneBodyParam = {
      code: 'string'
    };
    describe('#postConfigStaticassignmentVendorSpecificInformationClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStaticassignmentVendorSpecificInformationClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPostConfigStaticassignmentVendorSpecificInformationCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticassignmentVendorSpecificInformationClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressPoolAddresspoolStaticRouteBodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigAddressPoolAddresspoolStaticRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAddressPoolAddresspoolStaticRoute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigAddressPoolAddresspoolStaticRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressPoolAddresspoolStaticRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPoolAddresspoolStaticRouteCloneBodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigPoolAddresspoolStaticRouteClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPoolAddresspoolStaticRouteClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigPoolAddresspoolStaticRouteCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPoolAddresspoolStaticRouteClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigVendorIdentifyingSpecificInformation2BodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigVendorIdentifyingSpecificInformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigVendorIdentifyingSpecificInformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigVendorIdentifyingSpecificInformation2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response['enterprise-number']);
                assert.equal(7, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigVendorIdentifyingSpecificInformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigIdentifyingVendorSpecificInformationClone2BodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigIdentifyingVendorSpecificInformationClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigIdentifyingVendorSpecificInformationClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigIdentifyingVendorSpecificInformationClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigIdentifyingVendorSpecificInformationClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPoolAddresspoolVendorSpecificInformationBodyParam = {
      code: 'string'
    };
    describe('#postConfigPoolAddresspoolVendorSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigPoolAddresspoolVendorSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigPoolAddresspoolVendorSpecificInformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(5, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPoolAddresspoolVendorSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddresspoolVendorSpecificInformationCloneBodyParam = {
      code: 'string'
    };
    describe('#postConfigAddresspoolVendorSpecificInformationClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAddresspoolVendorSpecificInformationClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPostConfigAddresspoolVendorSpecificInformationCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddresspoolVendorSpecificInformationClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostServiceHostserviceStaticAssignmentBodyParam = {
      address: 'string'
    };
    describe('#postConfigHostServiceHostserviceStaticAssignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostServiceHostserviceStaticAssignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigHostServiceHostserviceStaticAssignmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['link-layer-address']);
                assert.equal('string', data.response['client-identifier']);
                assert.equal('string', data.response['circuit-identifier']);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(10, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostServiceHostserviceStaticAssignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceHostserviceStaticAssignmentCloneBodyParam = {
      address: 'string'
    };
    describe('#postConfigServiceHostserviceStaticAssignmentClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceHostserviceStaticAssignmentClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigServiceHostserviceStaticAssignmentCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceHostserviceStaticAssignmentClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostserviceStaticAssignmentStaticassignmentCustomBodyParam = {
      code: 'string'
    };
    describe('#postConfigHostserviceStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostserviceStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigHostserviceStaticAssignmentStaticassignmentCustomBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostserviceStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticAssignmentStaticassignmentCustomClone2BodyParam = {
      code: 'string'
    };
    describe('#postConfigStaticAssignmentStaticassignmentCustomClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStaticAssignmentStaticassignmentCustomClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigStaticAssignmentStaticassignmentCustomClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticAssignmentStaticassignmentCustomClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticAssignmentStaticassignmentRoute2BodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigStaticAssignmentStaticassignmentRoute2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStaticAssignmentStaticassignmentRoute2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigStaticAssignmentStaticassignmentRoute2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticAssignmentStaticassignmentRoute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAssignmentStaticassignmentStaticRouteClone2BodyParam = {
      'destination-address': 'string'
    };
    describe('#postConfigAssignmentStaticassignmentStaticRouteClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAssignmentStaticassignmentStaticRouteClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigAssignmentStaticassignmentStaticRouteClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAssignmentStaticassignmentStaticRouteClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigVendorIdentifyingSpecificInformation3BodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigVendorIdentifyingSpecificInformation3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigVendorIdentifyingSpecificInformation3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigVendorIdentifyingSpecificInformation3BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response['enterprise-number']);
                assert.equal(10, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigVendorIdentifyingSpecificInformation3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigIdentifyingVendorSpecificInformationClone3BodyParam = {
      'enterprise-number': 'string',
      code: 'string'
    };
    describe('#postConfigIdentifyingVendorSpecificInformationClone3 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigIdentifyingVendorSpecificInformationClone3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigIdentifyingVendorSpecificInformationClone3BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigIdentifyingVendorSpecificInformationClone3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAssignmentStaticassignmentVendorSpecificInformation2BodyParam = {
      code: 'string'
    };
    describe('#postConfigAssignmentStaticassignmentVendorSpecificInformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAssignmentStaticassignmentVendorSpecificInformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigAssignmentStaticassignmentVendorSpecificInformation2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAssignmentStaticassignmentVendorSpecificInformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticassignmentVendorSpecificInformationClone2BodyParam = {
      code: 'string'
    };
    describe('#postConfigStaticassignmentVendorSpecificInformationClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStaticassignmentVendorSpecificInformationClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPostConfigStaticassignmentVendorSpecificInformationClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticassignmentVendorSpecificInformationClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressHostServiceHostserviceTransportBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigAddressHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAddressHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigAddressHostServiceHostserviceTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostServiceHostserviceTransportCloneBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigHostServiceHostserviceTransportClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigHostServiceHostserviceTransportClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPostConfigHostServiceHostserviceTransportCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostServiceHostserviceTransportClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configTransport = 'fakedata';
    const configPostConfigHostserviceTransportPortRangeBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigHostserviceTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostserviceTransportPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPostConfigHostserviceTransportPortRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response['start-port']);
                assert.equal(3, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostserviceTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigTransportPortRangeCloneBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigTransportPortRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigTransportPortRangeClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPostConfigTransportPortRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTransportPortRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configPeer = 'fakedata';
    let configVector = 'fakedata';
    const configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacencyBodyParam = {
      'ip-address': 'string',
      peer: 'string'
    };
    describe('#postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response.peer);
                assert.equal('string', data.response['peer-connectivity']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['inter-router-security']);
                assert.equal(true, Array.isArray(data.response['source-nat-address']));
                assert.equal('string', data.response['external-nat-address']);
                assert.equal(6, data.response.cost);
                assert.equal(2, data.response['qp-value']);
                assert.equal(true, Array.isArray(data.response.vector));
              } else {
                runCommonAsserts(data, error);
              }
              configPeer = data.response.peer;
              configVector = data.response.vector;
              saveMockData('Config', 'postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceAdjacencyCloneBodyParam = {
      'ip-address': 'string',
      peer: 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceAdjacencyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceAdjacencyClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceAdjacencyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceAdjacencyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAdjacency = 'fakedata';
    const configPostConfigNetworkinterfaceAdjacencyPortRangeBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigNetworkinterfaceAdjacencyPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkinterfaceAdjacencyPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigNetworkinterfaceAdjacencyPortRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(2, data.response['start-port']);
                assert.equal(6, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkinterfaceAdjacencyPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAdjacencyPortRangeCloneBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigAdjacencyPortRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAdjacencyPortRangeClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigAdjacencyPortRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAdjacencyPortRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSlaMetricsDecreaseReportDelayBodyParam = {
      percentage: 'string'
    };
    describe('#postConfigSlaMetricsDecreaseReportDelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSlaMetricsDecreaseReportDelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigSlaMetricsDecreaseReportDelayBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response.percentage);
                assert.equal(3, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSlaMetricsDecreaseReportDelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMetricsDecreaseReportDelayCloneBodyParam = {
      percentage: 'string'
    };
    describe('#postConfigMetricsDecreaseReportDelayClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigMetricsDecreaseReportDelayClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigMetricsDecreaseReportDelayCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMetricsDecreaseReportDelayClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSlaMetricsIncreaseReportDelayBodyParam = {
      percentage: 'string'
    };
    describe('#postConfigSlaMetricsIncreaseReportDelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSlaMetricsIncreaseReportDelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigSlaMetricsIncreaseReportDelayBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response.percentage);
                assert.equal(5, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSlaMetricsIncreaseReportDelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMetricsIncreaseReportDelayCloneBodyParam = {
      percentage: 'string'
    };
    describe('#postConfigMetricsIncreaseReportDelayClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigMetricsIncreaseReportDelayClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPostConfigMetricsIncreaseReportDelayCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMetricsIncreaseReportDelayClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceHostServiceBodyParam = {
      'service-type': 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceHostService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceHostService(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceHostServiceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-type']);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceHostService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigInterfaceNetworkinterfaceHostServiceCloneBodyParam = {
      'service-type': 'string'
    };
    describe('#postConfigInterfaceNetworkinterfaceHostServiceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigInterfaceNetworkinterfaceHostServiceClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigInterfaceNetworkinterfaceHostServiceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigInterfaceNetworkinterfaceHostServiceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostServiceHostserviceAccessPolicy2BodyParam = {
      source: 'string'
    };
    describe('#postConfigHostServiceHostserviceAccessPolicy2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostServiceHostserviceAccessPolicy2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configPostConfigHostServiceHostserviceAccessPolicy2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostServiceHostserviceAccessPolicy2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceHostserviceAccessPolicyClone2BodyParam = {
      source: 'string'
    };
    describe('#postConfigServiceHostserviceAccessPolicyClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceHostserviceAccessPolicyClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configPostConfigServiceHostserviceAccessPolicyClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceHostserviceAccessPolicyClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkinterfaceHostServiceHostserviceTransportBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigNetworkinterfaceHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkinterfaceHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configPostConfigNetworkinterfaceHostServiceHostserviceTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkinterfaceHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostServiceHostserviceTransportClone2BodyParam = {
      protocol: 'string'
    };
    describe('#postConfigHostServiceHostserviceTransportClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigHostServiceHostserviceTransportClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configPostConfigHostServiceHostserviceTransportClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostServiceHostserviceTransportClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigHostserviceTransportPortRange2BodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigHostserviceTransportPortRange2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigHostserviceTransportPortRange2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPostConfigHostserviceTransportPortRange2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['start-port']);
                assert.equal(4, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigHostserviceTransportPortRange2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigTransportPortRangeClone2BodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigTransportPortRangeClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigTransportPortRangeClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPostConfigTransportPortRangeClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTransportPortRangeClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceIfcfgOptionBodyParam = {
      name: 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceIfcfgOption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceIfcfgOption(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceIfcfgOptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.value);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceIfcfgOption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigInterfaceNetworkinterfaceIfcfgOptionCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigInterfaceNetworkinterfaceIfcfgOptionClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigInterfaceNetworkinterfaceIfcfgOptionClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigInterfaceNetworkinterfaceIfcfgOptionCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigInterfaceNetworkinterfaceIfcfgOptionClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['phys-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceNeighborCloneBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceNeighborClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceNeighborClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceNeighborCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceNeighborClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhoodBodyParam = {
      name: 'string'
    };
    describe('#postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhoodBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['peer-connectivity']);
                assert.equal('string', data.response.topology);
                assert.equal('string', data.response['external-nat-address']);
                assert.equal('string', data.response.vector);
                assert.equal(2, data.response['qp-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceNeighborhoodCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceNeighborhoodClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceNeighborhoodClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceNeighborhoodCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceNeighborhoodClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkInterfaceNetworkinterfaceNeighborhoodMoveBodyParam = {
      position: 'first'
    };
    describe('#postConfigNetworkInterfaceNetworkinterfaceNeighborhoodMove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNetworkInterfaceNetworkinterfaceNeighborhoodMove(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPostConfigNetworkInterfaceNetworkinterfaceNeighborhoodMoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkInterfaceNetworkinterfaceNeighborhoodMove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNetworkinterfaceNeighborhoodPortRangeBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigNetworkinterfaceNeighborhoodPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigNetworkinterfaceNeighborhoodPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigNetworkinterfaceNeighborhoodPortRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response['start-port']);
                assert.equal(10, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNetworkinterfaceNeighborhoodPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNeighborhoodPortRangeCloneBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigNeighborhoodPortRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNeighborhoodPortRangeClone(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigNeighborhoodPortRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNeighborhoodPortRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSlaMetricsDecreaseReportDelay2BodyParam = {
      percentage: 'string'
    };
    describe('#postConfigSlaMetricsDecreaseReportDelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSlaMetricsDecreaseReportDelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigSlaMetricsDecreaseReportDelay2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(8, data.response.percentage);
                assert.equal(5, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSlaMetricsDecreaseReportDelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMetricsDecreaseReportDelayClone2BodyParam = {
      percentage: 'string'
    };
    describe('#postConfigMetricsDecreaseReportDelayClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigMetricsDecreaseReportDelayClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigMetricsDecreaseReportDelayClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMetricsDecreaseReportDelayClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSlaMetricsIncreaseReportDelay2BodyParam = {
      percentage: 'string'
    };
    describe('#postConfigSlaMetricsIncreaseReportDelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSlaMetricsIncreaseReportDelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigSlaMetricsIncreaseReportDelay2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.percentage);
                assert.equal(2, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSlaMetricsIncreaseReportDelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigMetricsIncreaseReportDelayClone2BodyParam = {
      percentage: 'string'
    };
    describe('#postConfigMetricsIncreaseReportDelayClone2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigMetricsIncreaseReportDelayClone2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPostConfigMetricsIncreaseReportDelayClone2BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigMetricsIncreaseReportDelayClone2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterPeerBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRouterPeer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterPeer(configConfigStore, configRouter, configPostConfigAuthorityRouterPeerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['authority-name']);
                assert.equal('string', data.response['router-name']);
                assert.equal('string', data.response['inter-router-security']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterPeer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterPeerCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterPeerClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterPeerClone(configConfigStore, configRouter, configPostConfigRouterPeerCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterPeerClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterRedundancyGroupBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRouterRedundancyGroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterRedundancyGroup(configConfigStore, configRouter, configPostConfigAuthorityRouterRedundancyGroupBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal(5, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterRedundancyGroup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterRedundancyGroupCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterRedundancyGroupClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterRedundancyGroupClone(configConfigStore, configRouter, configPostConfigRouterRedundancyGroupCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRedundancyGroupClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRedundancygroup = 'fakedata';
    const configPostConfigRouterRedundancyGroupRedundancygroupMemberBodyParam = {
      node: 'string',
      'device-id': 'string'
    };
    describe('#postConfigRouterRedundancyGroupRedundancygroupMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterRedundancyGroupRedundancygroupMember(configConfigStore, configRouter, configRedundancygroup, configPostConfigRouterRedundancyGroupRedundancygroupMemberBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response['device-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRedundancyGroupRedundancygroupMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRedundancyGroupRedundancygroupMemberCloneBodyParam = {
      node: 'string',
      'device-id': 'string'
    };
    describe('#postConfigRedundancyGroupRedundancygroupMemberClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRedundancyGroupRedundancygroupMemberClone(configConfigStore, configRouter, configRedundancygroup, configPostConfigRedundancyGroupRedundancygroupMemberCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRedundancyGroupRedundancygroupMemberClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterRoutingBodyParam = {
      type: 'string'
    };
    describe('#postConfigAuthorityRouterRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterRouting(configConfigStore, configRouter, configPostConfigAuthorityRouterRoutingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.description);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterRoutingCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigRouterRoutingClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterRoutingClone(configConfigStore, configRouter, configPostConfigRouterRoutingCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRoutingClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRouting = 'fakedata';
    const configPostConfigRouterRoutingInterfaceBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterRoutingInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterRoutingInterface(configConfigStore, configRouter, configRouting, configPostConfigRouterRoutingInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRoutingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingInterfaceCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRoutingInterfaceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingInterfaceClone(configConfigStore, configRouter, configRouting, configPostConfigRoutingInterfaceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingInterfaceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterRoutingOspfBodyParam = {
      instance: 'string'
    };
    describe('#postConfigRouterRoutingOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterRoutingOspf(configConfigStore, configRouter, configRouting, configPostConfigRouterRoutingOspfBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response.instance);
                assert.equal('string', data.response['router-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRoutingOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingOspfCloneBodyParam = {
      instance: 'string'
    };
    describe('#postConfigRoutingOspfClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingOspfClone(configConfigStore, configRouter, configRouting, configPostConfigRoutingOspfCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingOspfClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configOspf = 'fakedata';
    const configPostConfigRoutingOspfAreaBodyParam = {
      id: 'string'
    };
    describe('#postConfigRoutingOspfArea - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingOspfArea(configConfigStore, configRouter, configRouting, configOspf, configPostConfigRoutingOspfAreaBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.id);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['summary-advertisement']);
                assert.equal(1, data.response['default-cost']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingOspfArea', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigOspfAreaCloneBodyParam = {
      id: 'string'
    };
    describe('#postConfigOspfAreaClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigOspfAreaClone(configConfigStore, configRouter, configRouting, configOspf, configPostConfigOspfAreaCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigOspfAreaClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configInterfaceParam = 'fakedata';
    const configArea = 'fakedata';
    const configPostConfigOspfAreaInterfaceBodyParam = {
      node: 'string',
      interface: 'string'
    };
    describe('#postConfigOspfAreaInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigOspfAreaInterface(configConfigStore, configRouter, configRouting, configOspf, configArea, configPostConfigOspfAreaInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.interfaceParam);
                assert.equal('string', data.response.passive);
                assert.equal(3, data.response.cost);
                assert.equal(2, data.response.priority);
                assert.equal(10, data.response['hello-interval']);
                assert.equal(2, data.response['dead-interval']);
              } else {
                runCommonAsserts(data, error);
              }
              configInterfaceParam = data.response.interfaceParam;
              saveMockData('Config', 'postConfigOspfAreaInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAreaInterfaceCloneBodyParam = {
      node: 'string',
      interface: 'string'
    };
    describe('#postConfigAreaInterfaceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAreaInterfaceClone(configConfigStore, configRouter, configRouting, configOspf, configArea, configPostConfigAreaInterfaceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAreaInterfaceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigOspfAreaSummaryRangeBodyParam = {
      prefix: 'string'
    };
    describe('#postConfigOspfAreaSummaryRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigOspfAreaSummaryRange(configConfigStore, configRouter, configRouting, configOspf, configArea, configPostConfigOspfAreaSummaryRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.prefix);
                assert.equal('string', data.response.advertise);
                assert.equal(10, data.response.cost);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigOspfAreaSummaryRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAreaSummaryRangeCloneBodyParam = {
      prefix: 'string'
    };
    describe('#postConfigAreaSummaryRangeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAreaSummaryRangeClone(configConfigStore, configRouter, configRouting, configOspf, configArea, configPostConfigAreaSummaryRangeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAreaSummaryRangeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configPolicy = 'fakedata';
    const configPostConfigRoutingOspfRedistributeBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigRoutingOspfRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingOspfRedistribute(configConfigStore, configRouter, configRouting, configOspf, configPostConfigRoutingOspfRedistributeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
                assert.equal('string', data.response.policy);
                assert.equal(2, data.response.metric);
                assert.equal('string', data.response['metric-type']);
              } else {
                runCommonAsserts(data, error);
              }
              configPolicy = data.response.policy;
              saveMockData('Config', 'postConfigRoutingOspfRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigOspfRedistributeCloneBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigOspfRedistributeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigOspfRedistributeClone(configConfigStore, configRouter, configRouting, configOspf, configPostConfigOspfRedistributeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigOspfRedistributeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterRoutingProtocolBodyParam = {
      type: 'string'
    };
    describe('#postConfigRouterRoutingProtocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterRoutingProtocol(configConfigStore, configRouter, configRouting, configPostConfigRouterRoutingProtocolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.type);
                assert.equal(9, data.response['local-as']);
                assert.equal('string', data.response['router-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRoutingProtocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingProtocolCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigRoutingProtocolClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingProtocolClone(configConfigStore, configRouter, configRouting, configPostConfigRoutingProtocolCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRoutingprotocol = 'fakedata';
    const configPostConfigRoutingProtocolRoutingprotocolAddressFamilyBodyParam = {
      'afi-safi': 'string'
    };
    describe('#postConfigRoutingProtocolRoutingprotocolAddressFamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingProtocolRoutingprotocolAddressFamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigRoutingProtocolRoutingprotocolAddressFamilyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['afi-safi']);
                assert.equal('string', data.response['send-default-route']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolRoutingprotocolAddressFamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigProtocolRoutingprotocolAddressFamilyCloneBodyParam = {
      'afi-safi': 'string'
    };
    describe('#postConfigProtocolRoutingprotocolAddressFamilyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigProtocolRoutingprotocolAddressFamilyClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigProtocolRoutingprotocolAddressFamilyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigProtocolRoutingprotocolAddressFamilyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAddressfamily = 'fakedata';
    const configPostConfigAddressFamilyAddressfamilyAggregateBodyParam = {
      prefix: 'string'
    };
    describe('#postConfigAddressFamilyAddressfamilyAggregate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAddressFamilyAddressfamilyAggregate(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPostConfigAddressFamilyAddressfamilyAggregateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.prefix);
                assert.equal('string', data.response['as-set']);
                assert.equal('string', data.response['summary-only']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressFamilyAddressfamilyAggregate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigFamilyAddressfamilyAggregateAddressCloneBodyParam = {
      prefix: 'string'
    };
    describe('#postConfigFamilyAddressfamilyAggregateAddressClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigFamilyAddressfamilyAggregateAddressClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPostConfigFamilyAddressfamilyAggregateAddressCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigFamilyAddressfamilyAggregateAddressClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingprotocolAddressFamilyAddressfamilyNetworkBodyParam = {
      'network-address': 'string'
    };
    describe('#postConfigRoutingprotocolAddressFamilyAddressfamilyNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingprotocolAddressFamilyAddressfamilyNetwork(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPostConfigRoutingprotocolAddressFamilyAddressfamilyNetworkBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['network-address']);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingprotocolAddressFamilyAddressfamilyNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAddressFamilyAddressfamilyNetworkCloneBodyParam = {
      'network-address': 'string'
    };
    describe('#postConfigAddressFamilyAddressfamilyNetworkClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAddressFamilyAddressfamilyNetworkClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPostConfigAddressFamilyAddressfamilyNetworkCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAddressFamilyAddressfamilyNetworkClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingProtocolRoutingprotocolNeighborBodyParam = {
      'neighbor-address': 'string'
    };
    describe('#postConfigRoutingProtocolRoutingprotocolNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingProtocolRoutingprotocolNeighbor(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigRoutingProtocolRoutingprotocolNeighborBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['neighbor-address']);
                assert.equal(7, data.response['neighbor-as']);
                assert.equal(10, data.response['local-as']);
                assert.equal('string', data.response.shutdown);
                assert.equal('string', data.response['auth-password']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['outbound-policy-advertise']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolRoutingprotocolNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingProtocolRoutingprotocolNeighborCloneBodyParam = {
      'neighbor-address': 'string'
    };
    describe('#postConfigRoutingProtocolRoutingprotocolNeighborClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingProtocolRoutingprotocolNeighborClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigRoutingProtocolRoutingprotocolNeighborCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolRoutingprotocolNeighborClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNeighbor = 'fakedata';
    const configPostConfigRoutingprotocolNeighborAddressFamilyBodyParam = {
      'afi-safi': 'string'
    };
    describe('#postConfigRoutingprotocolNeighborAddressFamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingprotocolNeighborAddressFamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPostConfigRoutingprotocolNeighborAddressFamilyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['afi-safi']);
                assert.equal('string', data.response['send-default-route']);
                assert.equal('string', data.response['next-hop-self']);
                assert.equal('string', data.response['remove-private-as']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingprotocolNeighborAddressFamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigNeighborAddressFamilyCloneBodyParam = {
      'afi-safi': 'string'
    };
    describe('#postConfigNeighborAddressFamilyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigNeighborAddressFamilyClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPostConfigNeighborAddressFamilyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigNeighborAddressFamilyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingProtocolRoutingprotocolRedistributeBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigRoutingProtocolRoutingprotocolRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingProtocolRoutingprotocolRedistribute(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigRoutingProtocolRoutingprotocolRedistributeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolRoutingprotocolRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingProtocolRoutingprotocolRedistributeCloneBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigRoutingProtocolRoutingprotocolRedistributeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingProtocolRoutingprotocolRedistributeClone(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPostConfigRoutingProtocolRoutingprotocolRedistributeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingProtocolRoutingprotocolRedistributeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterRoutingStaticRouteBodyParam = {
      'destination-prefix': 'string',
      distance: 'string'
    };
    describe('#postConfigRouterRoutingStaticRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterRoutingStaticRoute(configConfigStore, configRouter, configRouting, configPostConfigRouterRoutingStaticRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(true, Array.isArray(data.response['next-hop']));
                assert.equal('string', data.response.blackhole);
                assert.equal('string', data.response['destination-prefix']);
                assert.equal(4, data.response.distance);
                assert.equal('string', data.response.description);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterRoutingStaticRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingStaticRouteCloneBodyParam = {
      'destination-prefix': 'string',
      distance: 'string'
    };
    describe('#postConfigRoutingStaticRouteClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRoutingStaticRouteClone(configConfigStore, configRouter, configRouting, configPostConfigRoutingStaticRouteCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingStaticRouteClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configStaticroute = 'fakedata';
    const configPostConfigRouteStaticrouteNextHopInterfaceBodyParam = {
      node: 'string',
      interface: 'string'
    };
    describe('#postConfigRouteStaticrouteNextHopInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouteStaticrouteNextHopInterface(configConfigStore, configRouter, configRouting, configStaticroute, configPostConfigRouteStaticrouteNextHopInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.interfaceParam);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouteStaticrouteNextHopInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStaticrouteNextHopInterfaceCloneBodyParam = {
      node: 'string',
      interface: 'string'
    };
    describe('#postConfigStaticrouteNextHopInterfaceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStaticrouteNextHopInterfaceClone(configConfigStore, configRouter, configRouting, configStaticroute, configPostConfigStaticrouteNextHopInterfaceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStaticrouteNextHopInterfaceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRouterServiceRouteBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRouterServiceRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityRouterServiceRoute(configConfigStore, configRouter, configPostConfigAuthorityRouterServiceRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.destination);
                assert.equal('string', data.response['nat-target']);
                assert.equal(3, data.response['port-target']);
                assert.equal('string', data.response.peer);
                assert.equal(true, Array.isArray(data.response['next-peer']));
                assert.equal('string', data.response['use-learned-routes']);
                assert.equal('string', data.response['routing-stack']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['service-name']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['service-route-policy']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRouterServiceRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterServiceRoutePolicyBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterServiceRoutePolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterServiceRoutePolicy(configConfigStore, configRouter, configPostConfigRouterServiceRoutePolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['session-rate']);
                assert.equal('string', data.response['max-sessions']);
                assert.equal(8, data.response['session-high-water-mark']);
                assert.equal(1, data.response['session-low-water-mark']);
                assert.equal('string', data.response['packet-replication']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterServiceRoutePolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterServiceRoutePolicyCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterServiceRoutePolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterServiceRoutePolicyClone(configConfigStore, configRouter, configPostConfigRouterServiceRoutePolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterServiceRoutePolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterServiceRouteCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterServiceRouteClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterServiceRouteClone(configConfigStore, configRouter, configPostConfigRouterServiceRouteCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterServiceRouteClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configServiceroute = 'fakedata';
    const configPostConfigRouterServiceRouteServicerouteHostBodyParam = {
      'node-name': 'string'
    };
    describe('#postConfigRouterServiceRouteServicerouteHost - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterServiceRouteServicerouteHost(configConfigStore, configRouter, configServiceroute, configPostConfigRouterServiceRouteServicerouteHostBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal(true, Array.isArray(data.response['target-address']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterServiceRouteServicerouteHost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceRouteServicerouteHostCloneBodyParam = {
      'node-name': 'string'
    };
    describe('#postConfigServiceRouteServicerouteHostClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceRouteServicerouteHostClone(configConfigStore, configRouter, configServiceroute, configPostConfigServiceRouteServicerouteHostCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceRouteServicerouteHostClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceRouteServicerouteNextHopBodyParam = {
      'node-name': 'string',
      interface: 'string'
    };
    describe('#postConfigServiceRouteServicerouteNextHop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServiceRouteServicerouteNextHop(configConfigStore, configRouter, configServiceroute, configPostConfigServiceRouteServicerouteNextHopBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal('string', data.response.interfaceParam);
                assert.equal('string', data.response['gateway-ip']);
                assert.equal(true, Array.isArray(data.response['target-address']));
                assert.equal('string', data.response['source-nat-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceRouteServicerouteNextHop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouteServicerouteNextHopCloneBodyParam = {
      'node-name': 'string',
      interface: 'string'
    };
    describe('#postConfigRouteServicerouteNextHopClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouteServicerouteNextHopClone(configConfigStore, configRouter, configServiceroute, configPostConfigRouteServicerouteNextHopCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouteServicerouteNextHopClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterSystemLogCategoryBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterSystemLogCategory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterSystemLogCategory(configConfigStore, configRouter, configPostConfigRouterSystemLogCategoryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['log-level']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterSystemLogCategory', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterSystemLogCategoryCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigRouterSystemLogCategoryClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigRouterSystemLogCategoryClone(configConfigStore, configRouter, configPostConfigRouterSystemLogCategoryCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterSystemLogCategoryClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterSystemNtpServerBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigRouterSystemNtpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterSystemNtpServer(configConfigStore, configRouter, configPostConfigRouterSystemNtpServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterSystemNtpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSystemNtpServerCloneBodyParam = {
      'ip-address': 'string'
    };
    describe('#postConfigSystemNtpServerClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigSystemNtpServerClone(configConfigStore, configRouter, configPostConfigSystemNtpServerCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSystemNtpServerClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServicesSnmpServerAccessControlBodyParam = {
      name: 'string'
    };
    describe('#postConfigServicesSnmpServerAccessControl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServicesSnmpServerAccessControl(configConfigStore, configRouter, configPostConfigServicesSnmpServerAccessControlBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.community);
                assert.equal('string', data.response.source);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicesSnmpServerAccessControl', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSnmpServerAccessControlCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigSnmpServerAccessControlClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigSnmpServerAccessControlClone(configConfigStore, configRouter, configPostConfigSnmpServerAccessControlCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSnmpServerAccessControlClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServicesSnmpServerNotificationReceiverBodyParam = {
      'ip-address': 'string',
      port: 'string',
      type: 'string'
    };
    describe('#postConfigServicesSnmpServerNotificationReceiver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServicesSnmpServerNotificationReceiver(configConfigStore, configRouter, configPostConfigServicesSnmpServerNotificationReceiverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal(1, data.response.port);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.community);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicesSnmpServerNotificationReceiver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSnmpServerNotificationReceiverCloneBodyParam = {
      'ip-address': 'string',
      port: 'string',
      type: 'string'
    };
    describe('#postConfigSnmpServerNotificationReceiverClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigSnmpServerNotificationReceiverClone(configConfigStore, configRouter, configPostConfigSnmpServerNotificationReceiverCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSnmpServerNotificationReceiverClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSystemServicesWebserverServerBodyParam = {
      'node-name': 'string'
    };
    describe('#postConfigSystemServicesWebserverServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSystemServicesWebserverServer(configConfigStore, configRouter, configPostConfigSystemServicesWebserverServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal('string', data.response['ip-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSystemServicesWebserverServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServicesWebserverServerCloneBodyParam = {
      'node-name': 'string'
    };
    describe('#postConfigServicesWebserverServerClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServicesWebserverServerClone(configConfigStore, configRouter, configPostConfigServicesWebserverServerCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicesWebserverServerClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRouterSystemSyslogServerBodyParam = {
      'ip-address': 'string',
      port: 'string'
    };
    describe('#postConfigRouterSystemSyslogServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRouterSystemSyslogServer(configConfigStore, configRouter, configPostConfigRouterSystemSyslogServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal(4, data.response.port);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRouterSystemSyslogServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSystemSyslogServerCloneBodyParam = {
      'ip-address': 'string',
      port: 'string'
    };
    describe('#postConfigSystemSyslogServerClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigSystemSyslogServerClone(configConfigStore, configRouter, configPostConfigSystemSyslogServerCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSystemSyslogServerClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityRoutingFilterBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityRoutingFilter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityRoutingFilter(configConfigStore, configPostConfigStoreAuthorityRoutingFilterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityRoutingFilter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRoutingFilterCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRoutingFilterClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAuthorityRoutingFilterClone(configConfigStore, configPostConfigAuthorityRoutingFilterCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRoutingFilterClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingFilterRuleBodyParam = {
      name: 'string'
    };
    describe('#postConfigRoutingFilterRule - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingFilterRule(configConfigStore, 'fakedata', configPostConfigRoutingFilterRuleBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.filter);
                assert.equal('string', data.response.prefix);
                assert.equal(3, data.response.ge);
                assert.equal(8, data.response.le);
                assert.equal('string', data.response['as-path']);
                assert.equal('string', data.response.community);
                assert.equal('string', data.response['extended-community']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingFilterRule', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configFilter = 'fakedata';
    const configPostConfigFilterRuleCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigFilterRuleClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigFilterRuleClone(configConfigStore, configFilter, configPostConfigFilterRuleCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigFilterRuleClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigFilterRuleMoveBodyParam = {
      position: 'first'
    };
    describe('#postConfigFilterRuleMove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigFilterRuleMove(configConfigStore, configFilter, configPostConfigFilterRuleMoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigFilterRuleMove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityRoutingPolicyBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityRoutingPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityRoutingPolicy(configConfigStore, configPostConfigStoreAuthorityRoutingPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityRoutingPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityRoutingPolicyCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityRoutingPolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigAuthorityRoutingPolicyClone(configConfigStore, configPostConfigAuthorityRoutingPolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityRoutingPolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigRoutingPolicyStatementBodyParam = {
      name: 'string'
    };
    describe('#postConfigRoutingPolicyStatement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigRoutingPolicyStatement(configConfigStore, configPolicy, configPostConfigRoutingPolicyStatementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigRoutingPolicyStatement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPolicyStatementCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigPolicyStatementClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPolicyStatementClone(configConfigStore, configPolicy, configPostConfigPolicyStatementCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPolicyStatementClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPolicyStatementMoveBodyParam = {
      position: 'first'
    };
    describe('#postConfigPolicyStatementMove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPolicyStatementMove(configConfigStore, configPolicy, configPostConfigPolicyStatementMoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPolicyStatementMove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPolicyStatementActionBodyParam = {
      type: 'string'
    };
    describe('#postConfigPolicyStatementAction - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigPolicyStatementAction(configConfigStore, configPolicy, 'fakedata', configPostConfigPolicyStatementActionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(true, Array.isArray(data.response['community-attribute']));
                assert.equal('string', data.response.additive);
                assert.equal('string', data.response.none);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['peer-address']);
                assert.equal(1, data.response.set);
                assert.equal(9, data.response.add);
                assert.equal(9, data.response.subtract);
                assert.equal('string', data.response.type);
                assert.equal(7, data.response.as);
                assert.equal('string', data.response['aggregator-address']);
                assert.equal('string', data.response.exclude);
                assert.equal('string', data.response.prepend);
                assert.equal('string', data.response['community-filter']);
                assert.equal(true, Array.isArray(data.response['route-target']));
                assert.equal(true, Array.isArray(data.response['site-of-origin']));
                assert.equal(9, data.response['local-preference']);
                assert.equal('string', data.response['originator-id']);
                assert.equal('string', data.response.origin);
                assert.equal(1, data.response['bgp-weight']);
                assert.equal(7, data.response.tag);
                assert.equal('string', data.response.statement);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPolicyStatementAction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configStatement = 'fakedata';
    const configPostConfigStatementActionCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigStatementActionClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStatementActionClone(configConfigStore, configPolicy, configStatement, configPostConfigStatementActionCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStatementActionClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPolicyStatementConditionBodyParam = {
      type: 'string'
    };
    describe('#postConfigPolicyStatementCondition - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigPolicyStatementCondition(configConfigStore, configPolicy, configStatement, configPostConfigPolicyStatementConditionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['peer-address']);
                assert.equal('string', data.response['peer-local']);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['prefix-filter']);
                assert.equal('string', data.response['as-path-filter']);
                assert.equal('string', data.response['community-filter']);
                assert.equal('string', data.response['extended-community-filter']);
                assert.equal('string', data.response['next-hop-node']);
                assert.equal('string', data.response['next-hop-interface']);
                assert.equal(3, data.response.metric);
                assert.equal('string', data.response.origin);
                assert.equal(6, data.response.probability);
                assert.equal(9, data.response.tag);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPolicyStatementCondition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStatementConditionCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigStatementConditionClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStatementConditionClone(configConfigStore, configPolicy, configStatement, configPostConfigStatementConditionCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStatementConditionClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthoritySecurityBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthoritySecurity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthoritySecurity(configConfigStore, configPostConfigStoreAuthoritySecurityBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.hmac);
                assert.equal('string', data.response['hmac-mode']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['hmac-cipher']);
                assert.equal('string', data.response['hmac-key']);
                assert.equal('string', data.response['encryption-cipher']);
                assert.equal('string', data.response['encryption-key']);
                assert.equal('string', data.response['encryption-iv']);
                assert.equal('string', data.response.encrypt);
                assert.equal('string', data.response['adaptive-encryption']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthoritySecurity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthoritySecurityCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthoritySecurityClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthoritySecurityClone(configConfigStore, configPostConfigStoreAuthoritySecurityCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthoritySecurityClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    let configSecurity = 'fakedata';
    const configPostConfigStoreAuthorityServiceBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityService(configConfigStore, configPostConfigStoreAuthorityServiceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['service-group']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.tenant);
                assert.equal('string', data.response.scope);
                assert.equal('string', data.response.security);
                assert.equal('string', data.response['tap-multiplexing']);
                assert.equal(true, Array.isArray(data.response.address));
                assert.equal(true, Array.isArray(data.response['application-name']));
                assert.equal('string', data.response['access-policy-generated']);
                assert.equal('string', data.response['service-policy']);
                assert.equal('string', data.response['share-service-routes']);
                assert.equal('string', data.response['source-nat']);
                assert.equal('string', data.response['application-type']);
                assert.equal('string', data.response['fqdn-resolution-type']);
                assert.equal('string', data.response.generated);
              } else {
                runCommonAsserts(data, error);
              }
              configSecurity = data.response.security;
              saveMockData('Config', 'postConfigStoreAuthorityService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityServiceClassBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityServiceClass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityServiceClass(configConfigStore, configPostConfigStoreAuthorityServiceClassBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['traffic-class']);
                assert.equal(9, data.response.priority);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal(2, data.response.dscp);
                assert.equal('string', data.response['rate-limit']);
                assert.equal(10, data.response['max-flow-rate']);
                assert.equal(2, data.response['max-flow-burst']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityServiceClass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityServiceClassCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityServiceClassClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityServiceClassClone(configConfigStore, configPostConfigStoreAuthorityServiceClassCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityServiceClassClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityServicePolicyBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityServicePolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityServicePolicy(configConfigStore, configPostConfigStoreAuthorityServicePolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['max-loss']);
                assert.equal(2, data.response['max-latency']);
                assert.equal(3, data.response['max-jitter']);
                assert.equal('string', data.response['min-mos']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-class']);
                assert.equal('string', data.response['lb-strategy']);
                assert.equal(7, data.response['required-qp']);
                assert.equal('string', data.response['qp-preference']);
                assert.equal('string', data.response['session-resiliency']);
                assert.equal('string', data.response['peer-path-resiliency']);
                assert.equal('string', data.response['path-quality-filter']);
                assert.equal('string', data.response['best-effort']);
                assert.equal('string', data.response['transport-state-enforcement']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['ingress-source-nat']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityServicePolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityServicePolicyCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityServicePolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityServicePolicyClone(configConfigStore, configPostConfigStoreAuthorityServicePolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityServicePolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configServicepolicy = 'fakedata';
    const configPostConfigServicePolicyServicepolicyAppliesToBodyParam = {
      type: 'string'
    };
    describe('#postConfigServicePolicyServicepolicyAppliesTo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServicePolicyServicepolicyAppliesTo(configConfigStore, configServicepolicy, configPostConfigServicePolicyServicepolicyAppliesToBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal(true, Array.isArray(data.response['router-name']));
                assert.equal(true, Array.isArray(data.response['group-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicePolicyServicepolicyAppliesTo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigPolicyServicepolicyAppliesToCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigPolicyServicepolicyAppliesToClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigPolicyServicepolicyAppliesToClone(configConfigStore, configServicepolicy, configPostConfigPolicyServicepolicyAppliesToCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigPolicyServicepolicyAppliesToClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityServicePolicyServicepolicyVectorBodyParam = {
      name: 'string'
    };
    describe('#postConfigAuthorityServicePolicyServicepolicyVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityServicePolicyServicepolicyVector(configConfigStore, configServicepolicy, configPostConfigAuthorityServicePolicyServicepolicyVectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityServicePolicyServicepolicyVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServicePolicyServicepolicyVectorCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigServicePolicyServicepolicyVectorClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServicePolicyServicepolicyVectorClone(configConfigStore, configServicepolicy, configPostConfigServicePolicyServicepolicyVectorCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicePolicyServicepolicyVectorClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServicePolicyServicepolicyVectorMoveBodyParam = {
      position: 'before'
    };
    describe('#postConfigServicePolicyServicepolicyVectorMove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServicePolicyServicepolicyVectorMove(configConfigStore, configServicepolicy, configPostConfigServicePolicyServicepolicyVectorMoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServicePolicyServicepolicyVectorMove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityServiceCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityServiceClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityServiceClone(configConfigStore, configPostConfigStoreAuthorityServiceCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityServiceClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configService = 'fakedata';
    const configPostConfigAuthorityServiceAccessPolicyBodyParam = {
      source: 'string'
    };
    describe('#postConfigAuthorityServiceAccessPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityServiceAccessPolicy(configConfigStore, configService, configPostConfigAuthorityServiceAccessPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityServiceAccessPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceAccessPolicyCloneBodyParam = {
      source: 'string'
    };
    describe('#postConfigServiceAccessPolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceAccessPolicyClone(configConfigStore, configService, configPostConfigServiceAccessPolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceAccessPolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityServiceAppliesToBodyParam = {
      type: 'string'
    };
    describe('#postConfigAuthorityServiceAppliesTo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityServiceAppliesTo(configConfigStore, configService, configPostConfigAuthorityServiceAppliesToBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal(true, Array.isArray(data.response['router-name']));
                assert.equal(true, Array.isArray(data.response['group-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityServiceAppliesTo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceAppliesToCloneBodyParam = {
      type: 'string'
    };
    describe('#postConfigServiceAppliesToClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceAppliesToClone(configConfigStore, configService, configPostConfigServiceAppliesToCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceAppliesToClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceMulticastSenderPolicyBodyParam = {
      source: 'string'
    };
    describe('#postConfigServiceMulticastSenderPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServiceMulticastSenderPolicy(configConfigStore, configService, configPostConfigServiceMulticastSenderPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceMulticastSenderPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceMulticastSenderPolicyCloneBodyParam = {
      source: 'string'
    };
    describe('#postConfigServiceMulticastSenderPolicyClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceMulticastSenderPolicyClone(configConfigStore, configService, configPostConfigServiceMulticastSenderPolicyCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceMulticastSenderPolicyClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityServiceTransportBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigAuthorityServiceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityServiceTransport(configConfigStore, configService, configPostConfigAuthorityServiceTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityServiceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceTransportCloneBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigServiceTransportClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigServiceTransportClone(configConfigStore, configService, configPostConfigServiceTransportCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceTransportClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigServiceTransportPortRangeBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigServiceTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigServiceTransportPortRange(configConfigStore, configService, configTransport, configPostConfigServiceTransportPortRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['start-port']);
                assert.equal(1, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigServiceTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigTransportPortRangeClone3BodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigTransportPortRangeClone3 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigTransportPortRangeClone3(configConfigStore, configService, configTransport, configPostConfigTransportPortRangeClone3BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTransportPortRangeClone3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthoritySessionTypeBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthoritySessionType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthoritySessionType(configConfigStore, configPostConfigStoreAuthoritySessionTypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-class']);
                assert.equal(8, data.response.timeout);
                assert.equal('string', data.response['nat-keep-alive']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthoritySessionType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthoritySessionTypeCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthoritySessionTypeClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthoritySessionTypeClone(configConfigStore, configPostConfigStoreAuthoritySessionTypeCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthoritySessionTypeClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configSessiontype = 'fakedata';
    const configPostConfigAuthoritySessionTypeSessiontypeTransportBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigAuthoritySessionTypeSessiontypeTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthoritySessionTypeSessiontypeTransport(configConfigStore, configSessiontype, configPostConfigAuthoritySessionTypeSessiontypeTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthoritySessionTypeSessiontypeTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSessionTypeSessiontypeTransportCloneBodyParam = {
      protocol: 'string'
    };
    describe('#postConfigSessionTypeSessiontypeTransportClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigSessionTypeSessiontypeTransportClone(configConfigStore, configSessiontype, configPostConfigSessionTypeSessiontypeTransportCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSessionTypeSessiontypeTransportClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigSessiontypeTransportPortRangeBodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigSessiontypeTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigSessiontypeTransportPortRange(configConfigStore, configSessiontype, configTransport, configPostConfigSessiontypeTransportPortRangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['start-port']);
                assert.equal(2, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigSessiontypeTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigTransportPortRangeClone4BodyParam = {
      'start-port': 'string'
    };
    describe('#postConfigTransportPortRangeClone4 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigTransportPortRangeClone4(configConfigStore, configSessiontype, configTransport, configPostConfigTransportPortRangeClone4BodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTransportPortRangeClone4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityStepRepoBodyParam = {
      address: 'string'
    };
    describe('#postConfigStoreAuthorityStepRepo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityStepRepo(configConfigStore, configPostConfigStoreAuthorityStepRepoBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.address);
                assert.equal('string', data.response.description);
                assert.equal(4, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityStepRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityStepRepoCloneBodyParam = {
      address: 'string'
    };
    describe('#postConfigStoreAuthorityStepRepoClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityStepRepoClone(configConfigStore, configPostConfigStoreAuthorityStepRepoCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityStepRepoClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityTenantBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityTenant - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityTenant(configConfigStore, configPostConfigStoreAuthorityTenantBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.security);
                assert.equal(true, Array.isArray(data.response.address));
                assert.equal('string', data.response.generated);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityTenantCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityTenantClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityTenantClone(configConfigStore, configPostConfigStoreAuthorityTenantCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityTenantClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigAuthorityTenantMemberBodyParam = {
      neighborhood: 'string'
    };
    describe('#postConfigAuthorityTenantMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigAuthorityTenantMember(configConfigStore, configTenant, configPostConfigAuthorityTenantMemberBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.neighborhood);
                assert.equal(true, Array.isArray(data.response.address));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigAuthorityTenantMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigTenantMemberCloneBodyParam = {
      neighborhood: 'string'
    };
    describe('#postConfigTenantMemberClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigTenantMemberClone(configConfigStore, configTenant, configPostConfigTenantMemberCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigTenantMemberClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityTrafficProfileBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityTrafficProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postConfigStoreAuthorityTrafficProfile(configConfigStore, configPostConfigStoreAuthorityTrafficProfileBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityTrafficProfile', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPostConfigStoreAuthorityTrafficProfileCloneBodyParam = {
      name: 'string'
    };
    describe('#postConfigStoreAuthorityTrafficProfileClone - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postConfigStoreAuthorityTrafficProfileClone(configConfigStore, configPostConfigStoreAuthorityTrafficProfileCloneBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'postConfigStoreAuthorityTrafficProfileClone', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigExport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigExport((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response[0]);
                assert.equal('string', data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigExport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigGetJson - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.getConfigGetJson(configSource, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigGetJson', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigVersion(null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.conductorVersion);
                assert.equal('string', data.response.localVersion);
                assert.equal(false, data.response.hasChangedLocally);
                assert.equal(false, data.response.isDirty);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigVersion', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreBodyParam = {};
    describe('#patchConfigStore - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStore(configConfigStore, configPatchConfigStoreBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStore', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStore - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStore(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStore', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityBodyParam = {
      name: 'string',
      'rekey-interval': 'string',
      'conductor-address': [
        'string'
      ],
      'dynamic-hostname': 'string',
      'auto-install': 'string'
    };
    describe('#patchConfigStoreAuthority - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthority(configConfigStore, configPatchConfigStoreAuthorityBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthority', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthority - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthority(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['rekey-interval']);
                assert.equal(true, Array.isArray(data.response['conductor-address']));
                assert.equal('string', data.response['dynamic-hostname']);
                assert.equal('string', data.response['auto-install']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthority', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityDistrict - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityDistrict(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityDistrict', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDistrict = 'fakedata';
    const configPatchConfigStoreAuthorityDistrictBodyParam = {
      name: 'string',
      neighborhood: [
        'string'
      ]
    };
    describe('#patchConfigStoreAuthorityDistrict - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityDistrict(configConfigStore, configDistrict, configPatchConfigStoreAuthorityDistrictBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityDistrict', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityDistrict2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityDistrict2(configConfigStore, configDistrict, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal(true, Array.isArray(data.response.neighborhood));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityDistrict2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityDscpMap - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityDscpMap(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityDscpMap', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityDscpMapDscpmapBodyParam = {
      name: 'string'
    };
    describe('#patchConfigStoreAuthorityDscpMapDscpmap - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityDscpMapDscpmap(configConfigStore, configDscpmap, configPatchConfigStoreAuthorityDscpMapDscpmapBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityDscpMapDscpmap', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityDscpMapDscpmap - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityDscpMapDscpmap(configConfigStore, configDscpmap, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityDscpMapDscpmap', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDscpMapDscpmapPrioritization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDscpMapDscpmapPrioritization(configConfigStore, configDscpmap, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDscpMapDscpmapPrioritization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigMapDscpmapDscpPrioritizationDscpprioritizationBodyParam = {
      priority: 3
    };
    describe('#patchConfigMapDscpmapDscpPrioritizationDscpprioritization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigMapDscpmapDscpPrioritizationDscpprioritization(configConfigStore, configDscpmap, configDscpprioritization, configPatchConfigMapDscpmapDscpPrioritizationDscpprioritizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigMapDscpmapDscpPrioritizationDscpprioritization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMapDscpmapDscpPrioritizationDscpprioritization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMapDscpmapDscpPrioritizationDscpprioritization(configConfigStore, configDscpmap, configDscpprioritization, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMapDscpmapDscpPrioritizationDscpprioritization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDscpPrioritizationDscpprioritizationRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDscpPrioritizationDscpprioritizationRange(configConfigStore, configDscpmap, configDscpprioritization, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDscpPrioritizationDscpprioritizationRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDscprange = 'fakedata';
    const configPatchConfigPrioritizationDscpprioritizationDscpRangeDscprangeBodyParam = {
      'start-value': 1,
      'end-value': 1
    };
    describe('#patchConfigPrioritizationDscpprioritizationDscpRangeDscprange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPrioritizationDscpprioritizationDscpRangeDscprange(configConfigStore, configDscpmap, configDscpprioritization, configDscprange, configPatchConfigPrioritizationDscpprioritizationDscpRangeDscprangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPrioritizationDscpprioritizationDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPrioritizationDscpprioritizationDscpRangeDscprange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPrioritizationDscpprioritizationDscpRangeDscprange(configConfigStore, configDscpmap, configDscpprioritization, configDscprange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response['start-value']);
                assert.equal(4, data.response['end-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPrioritizationDscpprioritizationDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMapDscpmapDscpTrafficClass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMapDscpmapDscpTrafficClass(configConfigStore, configDscpmap, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMapDscpmapDscpTrafficClass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigDscpmapDscpTrafficClassDscptrafficclassBodyParam = {
      'traffic-class': 'string'
    };
    describe('#patchConfigDscpmapDscpTrafficClassDscptrafficclass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigDscpmapDscpTrafficClassDscptrafficclass(configConfigStore, configDscpmap, configDscptrafficclass, configPatchConfigDscpmapDscpTrafficClassDscptrafficclassBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigDscpmapDscpTrafficClassDscptrafficclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDscpmapDscpTrafficClassDscptrafficclass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDscpmapDscpTrafficClassDscptrafficclass(configConfigStore, configDscpmap, configDscptrafficclass, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['traffic-class']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDscpmapDscpTrafficClassDscptrafficclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTrafficClassDscptrafficclassDscpRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTrafficClassDscptrafficclassDscpRange(configConfigStore, configDscpmap, configDscptrafficclass, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTrafficClassDscptrafficclassDscpRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigClassDscptrafficclassDscpRangeDscprangeBodyParam = {
      'start-value': 3,
      'end-value': 6
    };
    describe('#patchConfigClassDscptrafficclassDscpRangeDscprange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigClassDscptrafficclassDscpRangeDscprange(configConfigStore, configDscpmap, configDscptrafficclass, configDscprange, configPatchConfigClassDscptrafficclassDscpRangeDscprangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigClassDscptrafficclassDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigClassDscptrafficclassDscpRangeDscprange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigClassDscptrafficclassDscpRangeDscprange(configConfigStore, configDscpmap, configDscptrafficclass, configDscprange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(5, data.response['start-value']);
                assert.equal(6, data.response['end-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigClassDscptrafficclassDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityIpfixCollector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityIpfixCollector(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityIpfixCollector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configIpfixcollector = 'fakedata';
    const configPatchConfigStoreAuthorityIpfixCollectorIpfixcollectorBodyParam = {
      name: 'string',
      'ip-address': 'string',
      port: 8,
      protocol: 'string',
      'interim-record-interval': 2,
      'template-refresh-interval': 3,
      'sampling-percentage': 'string',
      tenant: [
        'string'
      ]
    };
    describe('#patchConfigStoreAuthorityIpfixCollectorIpfixcollector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityIpfixCollectorIpfixcollector(configConfigStore, configIpfixcollector, configPatchConfigStoreAuthorityIpfixCollectorIpfixcollectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityIpfixCollectorIpfixcollector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityIpfixCollectorIpfixcollector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityIpfixCollectorIpfixcollector(configConfigStore, configIpfixcollector, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['ip-address']);
                assert.equal(1, data.response.port);
                assert.equal('string', data.response.protocol);
                assert.equal(5, data.response['interim-record-interval']);
                assert.equal(1, data.response['template-refresh-interval']);
                assert.equal('string', data.response['sampling-percentage']);
                assert.equal(true, Array.isArray(data.response.tenant));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityIpfixCollectorIpfixcollector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityLdapServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityLdapServer(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityLdapServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configLdapserver = 'fakedata';
    const configPatchConfigStoreAuthorityLdapServerLdapserverBodyParam = {
      name: 'string',
      address: 'string',
      'search-base': 'string',
      'server-type': 'string',
      port: 'string',
      'bind-type': 'string',
      'distinguished-name': 'string',
      password: 'string'
    };
    describe('#patchConfigStoreAuthorityLdapServerLdapserver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityLdapServerLdapserver(configConfigStore, configLdapserver, configPatchConfigStoreAuthorityLdapServerLdapserverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityLdapServerLdapserver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityLdapServerLdapserver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityLdapServerLdapserver(configConfigStore, configLdapserver, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.address);
                assert.equal('string', data.response['search-base']);
                assert.equal('string', data.response['server-type']);
                assert.equal('string', data.response.port);
                assert.equal('string', data.response['bind-type']);
                assert.equal('string', data.response['distinguished-name']);
                assert.equal('string', data.response.password);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityLdapServerLdapserver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityManagementServiceGenerationBodyParam = {
      'service-route-type': 'string',
      'service-policy': 'string'
    };
    describe('#patchConfigStoreAuthorityManagementServiceGeneration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityManagementServiceGeneration(configConfigStore, configPatchConfigStoreAuthorityManagementServiceGenerationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityManagementServiceGeneration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityManagementServiceGeneration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityManagementServiceGeneration(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['service-route-type']);
                assert.equal('string', data.response['service-policy']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityManagementServiceGeneration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityRemoteLoginBodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigStoreAuthorityRemoteLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityRemoteLogin(configConfigStore, configPatchConfigStoreAuthorityRemoteLoginBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityRemoteLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRemoteLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRemoteLogin(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRemoteLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRouter(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityRouterBodyParam = {
      name: 'string',
      location: 'string',
      'location-coordinates': 'string',
      description: 'string',
      'router-group': [
        'string'
      ],
      'conductor-address': [
        'string'
      ],
      'maintenance-mode': 'string',
      'inter-node-security': 'string',
      'reverse-flow-enforcement': 'string',
      'administrative-group': [
        'string'
      ],
      'dhcp-server-generated-address-pool': 'string'
    };
    describe('#patchConfigStoreAuthorityRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityRouter(configConfigStore, configRouter, configPatchConfigStoreAuthorityRouterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRouter2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRouter2(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response['location-coordinates']);
                assert.equal('string', data.response.description);
                assert.equal(true, Array.isArray(data.response['router-group']));
                assert.equal(true, Array.isArray(data.response['conductor-address']));
                assert.equal('string', data.response['maintenance-mode']);
                assert.equal('string', data.response['inter-node-security']);
                assert.equal('string', data.response['reverse-flow-enforcement']);
                assert.equal(true, Array.isArray(data.response['administrative-group']));
                assert.equal('string', data.response['dhcp-server-generated-address-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRouter2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRouterApplicationIdentificationBodyParam = {
      mode: [
        'string'
      ]
    };
    describe('#patchConfigAuthorityRouterApplicationIdentification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRouterApplicationIdentification(configConfigStore, configRouter, configPatchConfigAuthorityRouterApplicationIdentificationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRouterApplicationIdentification', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterApplicationIdentification - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterApplicationIdentification(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(true, Array.isArray(data.response.mode));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterApplicationIdentification', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRouterBfdBodyParam = {
      state: 'string',
      'desired-tx-interval': 10,
      'required-min-rx-interval': 1,
      'required-min-echo-interval': 2,
      'authentication-type': 'string',
      multiplier: 5,
      'link-test-interval': 10,
      'link-test-length': 9,
      dscp: 8
    };
    describe('#patchConfigAuthorityRouterBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRouterBfd(configConfigStore, configRouter, configPatchConfigAuthorityRouterBfdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRouterBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterBfd(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.state);
                assert.equal(10, data.response['desired-tx-interval']);
                assert.equal(8, data.response['required-min-rx-interval']);
                assert.equal(10, data.response['required-min-echo-interval']);
                assert.equal('string', data.response['authentication-type']);
                assert.equal(10, data.response.multiplier);
                assert.equal(3, data.response['link-test-interval']);
                assert.equal(6, data.response['link-test-length']);
                assert.equal(1, data.response.dscp);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterDistrictSettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterDistrictSettings(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterDistrictSettings', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDistrictsettings = 'fakedata';
    const configPatchConfigRouterDistrictSettingsDistrictsettingsBodyParam = {
      'district-name': 'string'
    };
    describe('#patchConfigRouterDistrictSettingsDistrictsettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterDistrictSettingsDistrictsettings(configConfigStore, configRouter, configDistrictsettings, configPatchConfigRouterDistrictSettingsDistrictsettingsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterDistrictSettingsDistrictsettings', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterDistrictSettingsDistrictsettings - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterDistrictSettingsDistrictsettings(configConfigStore, configRouter, configDistrictsettings, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['district-name']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterDistrictSettingsDistrictsettings', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPeerPathSlaMetricsAdvertisementBodyParam = {
      'update-rate-limit': 5,
      'minimum-update-interval': 9,
      'update-burst-size': 6
    };
    describe('#patchConfigPeerPathSlaMetricsAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPeerPathSlaMetricsAdvertisement(configConfigStore, configRouter, configDistrictsettings, configPatchConfigPeerPathSlaMetricsAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPeerPathSlaMetricsAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPeerPathSlaMetricsAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPeerPathSlaMetricsAdvertisement(configConfigStore, configRouter, configDistrictsettings, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response['update-rate-limit']);
                assert.equal(5, data.response['minimum-update-interval']);
                assert.equal(2, data.response['update-burst-size']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPeerPathSlaMetricsAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterDns - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterDns(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterDns', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDnsconfig = 'fakedata';
    const configPatchConfigRouterDnsDnsconfigBodyParam = {
      mode: 'string',
      address: [
        'string'
      ]
    };
    describe('#patchConfigRouterDnsDnsconfig - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterDnsDnsconfig(configConfigStore, configRouter, configDnsconfig, configPatchConfigRouterDnsDnsconfigBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterDnsDnsconfig', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterDnsDnsconfig - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterDnsDnsconfig(configConfigStore, configRouter, configDnsconfig, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(true, Array.isArray(data.response.address));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterDnsDnsconfig', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRouterEntitlementBodyParam = {
      id: 'string',
      description: 'string',
      'max-bandwidth': 4
    };
    describe('#patchConfigAuthorityRouterEntitlement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRouterEntitlement(configConfigStore, configRouter, configPatchConfigAuthorityRouterEntitlementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRouterEntitlement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterEntitlement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterEntitlement(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.id);
                assert.equal('string', data.response.description);
                assert.equal(6, data.response['max-bandwidth']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterEntitlement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterManagementServiceGenerationBodyParam = {
      'service-route-type': 'string',
      'service-policy': 'string',
      proxy: 'string'
    };
    describe('#patchConfigRouterManagementServiceGeneration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterManagementServiceGeneration(configConfigStore, configRouter, configPatchConfigRouterManagementServiceGenerationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterManagementServiceGeneration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterManagementServiceGeneration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterManagementServiceGeneration(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['service-route-type']);
                assert.equal('string', data.response['service-policy']);
                assert.equal('string', data.response.proxy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterManagementServiceGeneration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterNatPool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterNatPool(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterNatPool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterNatPoolNatpoolBodyParam = {
      name: 'string'
    };
    describe('#patchConfigRouterNatPoolNatpool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterNatPoolNatpool(configConfigStore, configRouter, configNatpool, configPatchConfigRouterNatPoolNatpoolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterNatPoolNatpool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterNatPoolNatpool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterNatPoolNatpool(configConfigStore, configRouter, configNatpool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterNatPoolNatpool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNatPoolNatpoolAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNatPoolNatpoolAddress(configConfigStore, configRouter, configNatpool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNatPoolNatpoolAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPoolNatpoolAddressAddresspoolBodyParam = {
      address: 'string',
      'tenant-name': [
        'string'
      ]
    };
    describe('#patchConfigPoolNatpoolAddressAddresspool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPoolNatpoolAddressAddresspool(configConfigStore, configRouter, configNatpool, configAddresspool, configPatchConfigPoolNatpoolAddressAddresspoolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPoolNatpoolAddressAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPoolNatpoolAddressAddresspool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPoolNatpoolAddressAddresspool(configConfigStore, configRouter, configNatpool, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response['tenant-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPoolNatpoolAddressAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterNode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterNode(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterNodeBodyParam = {
      name: 'string',
      'asset-id': 'string',
      description: 'string',
      enabled: 'string',
      location: 'string',
      role: 'string',
      'asset-validation-enabled': 'string',
      'usage-reporter-enabled': 'string',
      'forwarding-core-mode': 'string',
      'forwarding-core-count': 10,
      'power-saver': 'string',
      'clean-before-install': 'string',
      'clean-after-failed-install': 'string',
      'software-update-bandwidth': 'string'
    };
    describe('#patchConfigRouterNode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterNode(configConfigStore, configRouter, configNode, configPatchConfigRouterNodeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterNode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterNode(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['asset-id']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.role);
                assert.equal('string', data.response['asset-validation-enabled']);
                assert.equal('string', data.response['usage-reporter-enabled']);
                assert.equal('string', data.response['forwarding-core-mode']);
                assert.equal(8, data.response['forwarding-core-count']);
                assert.equal('string', data.response['power-saver']);
                assert.equal('string', data.response['clean-before-install']);
                assert.equal('string', data.response['clean-after-failed-install']);
                assert.equal('string', data.response['software-update-bandwidth']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterNodeDeviceInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterNodeDeviceInterface(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterNodeDeviceInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNodeDeviceInterfaceDeviceinterfaceBodyParam = {
      name: 'string',
      description: 'string',
      type: 'string',
      'pci-address': 'string',
      'link-settings': 'string',
      mode: 'string',
      'target-interface': 'string',
      'bridge-name': 'string',
      'network-namespace': 'string',
      enabled: 'string',
      forwarding: 'string',
      'capture-filter': [
        'string'
      ],
      'shared-phys-address': 'string',
      'strip-vlan': 'string',
      'promiscuous-mode': 'string'
    };
    describe('#patchConfigNodeDeviceInterfaceDeviceinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNodeDeviceInterfaceDeviceinterface(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigNodeDeviceInterfaceDeviceinterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNodeDeviceInterfaceDeviceinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNodeDeviceInterfaceDeviceinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNodeDeviceInterfaceDeviceinterface(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['pci-address']);
                assert.equal('string', data.response['link-settings']);
                assert.equal('string', data.response.mode);
                assert.equal('string', data.response['target-interface']);
                assert.equal('string', data.response['bridge-name']);
                assert.equal('string', data.response['network-namespace']);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.forwarding);
                assert.equal(true, Array.isArray(data.response['capture-filter']));
                assert.equal('string', data.response['shared-phys-address']);
                assert.equal('string', data.response['strip-vlan']);
                assert.equal('string', data.response['promiscuous-mode']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNodeDeviceInterfaceDeviceinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigDeviceInterfaceDeviceinterfaceLoadBalancingBodyParam = {
      'utilization-high-water-mark': 7,
      'utilization-low-water-mark': 1
    };
    describe('#patchConfigDeviceInterfaceDeviceinterfaceLoadBalancing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigDeviceInterfaceDeviceinterfaceLoadBalancing(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigDeviceInterfaceDeviceinterfaceLoadBalancingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigDeviceInterfaceDeviceinterfaceLoadBalancing', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceInterfaceDeviceinterfaceLoadBalancing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceInterfaceDeviceinterfaceLoadBalancing(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response['utilization-high-water-mark']);
                assert.equal(7, data.response['utilization-low-water-mark']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceInterfaceDeviceinterfaceLoadBalancing', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNodeDeviceInterfaceDeviceinterfaceLteBodyParam = {
      'apn-name': 'string'
    };
    describe('#patchConfigNodeDeviceInterfaceDeviceinterfaceLte - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNodeDeviceInterfaceDeviceinterfaceLte(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigNodeDeviceInterfaceDeviceinterfaceLteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNodeDeviceInterfaceDeviceinterfaceLte', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNodeDeviceInterfaceDeviceinterfaceLte - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNodeDeviceInterfaceDeviceinterfaceLte(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['apn-name']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNodeDeviceInterfaceDeviceinterfaceLte', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigDeviceInterfaceDeviceinterfaceLteAuthenticationBodyParam = {
      'user-name': 'string',
      password: 'string',
      'authentication-protocol': 'string'
    };
    describe('#patchConfigDeviceInterfaceDeviceinterfaceLteAuthentication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigDeviceInterfaceDeviceinterfaceLteAuthentication(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigDeviceInterfaceDeviceinterfaceLteAuthenticationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigDeviceInterfaceDeviceinterfaceLteAuthentication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceInterfaceDeviceinterfaceLteAuthentication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceInterfaceDeviceinterfaceLteAuthentication(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['user-name']);
                assert.equal('string', data.response.password);
                assert.equal('string', data.response['authentication-protocol']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceInterfaceDeviceinterfaceLteAuthentication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceInterfaceDeviceinterfaceNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceInterfaceDeviceinterfaceNetwork(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceInterfaceDeviceinterfaceNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigInterfaceDeviceinterfaceNetworkNetworkinterfaceBodyParam = {
      name: 'string',
      'global-id': 6,
      description: 'string',
      vlan: 10,
      type: 'string',
      conductor: 'string',
      'default-route': 'string',
      tenant: 'string',
      'inter-router-security': 'string',
      'rewrite-dscp': 'string',
      'prioritization-mode': 'string',
      'dscp-map': 'string',
      classify: 'string',
      'source-nat': 'string',
      'qp-value': 3,
      mtu: 4,
      'enforced-mss': 'string',
      hostname: 'string',
      management: 'string',
      icmp: 'string',
      'off-subnet-arp-prefix': [
        'string'
      ],
      'multicast-listeners': 'string',
      'multicast-report-proxy': 'string',
      dhcp: 'string',
      'reverse-arp-mac-learning': 'string',
      'prefix-delegation': 'string',
      'prefix-delegation-group': 'string',
      'prefix-delegation-subnet-id': 9,
      'router-advertisement': 'string',
      'prefix-delegation-authentication': 'string',
      'dhcp-reconfig-auth-algorithm': 'string',
      'dhcp-delayed-auth-realm': 'string',
      'dhcp-delayed-auth-key-id': 8,
      'dhcp-delayed-auth-key': 'string',
      'ingress-source-nat-pool': 'string',
      'egress-source-nat-pool': 'string'
    };
    describe('#patchConfigInterfaceDeviceinterfaceNetworkNetworkinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigInterfaceDeviceinterfaceNetworkNetworkinterface(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPatchConfigInterfaceDeviceinterfaceNetworkNetworkinterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigInterfaceDeviceinterfaceNetworkNetworkinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigInterfaceDeviceinterfaceNetworkNetworkinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigInterfaceDeviceinterfaceNetworkNetworkinterface(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal(3, data.response['global-id']);
                assert.equal('string', data.response.description);
                assert.equal(5, data.response.vlan);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.conductor);
                assert.equal('string', data.response['default-route']);
                assert.equal('string', data.response.tenant);
                assert.equal('string', data.response['inter-router-security']);
                assert.equal('string', data.response['rewrite-dscp']);
                assert.equal('string', data.response['prioritization-mode']);
                assert.equal('string', data.response['dscp-map']);
                assert.equal('string', data.response.classify);
                assert.equal('string', data.response['source-nat']);
                assert.equal(8, data.response['qp-value']);
                assert.equal(10, data.response.mtu);
                assert.equal('string', data.response['enforced-mss']);
                assert.equal('string', data.response.hostname);
                assert.equal('string', data.response.management);
                assert.equal('string', data.response.icmp);
                assert.equal(true, Array.isArray(data.response['off-subnet-arp-prefix']));
                assert.equal('string', data.response['multicast-listeners']);
                assert.equal('string', data.response['multicast-report-proxy']);
                assert.equal('string', data.response.dhcp);
                assert.equal('string', data.response['reverse-arp-mac-learning']);
                assert.equal('string', data.response['prefix-delegation']);
                assert.equal('string', data.response['prefix-delegation-group']);
                assert.equal(7, data.response['prefix-delegation-subnet-id']);
                assert.equal('string', data.response['router-advertisement']);
                assert.equal('string', data.response['prefix-delegation-authentication']);
                assert.equal('string', data.response['dhcp-reconfig-auth-algorithm']);
                assert.equal('string', data.response['dhcp-delayed-auth-realm']);
                assert.equal(8, data.response['dhcp-delayed-auth-key-id']);
                assert.equal('string', data.response['dhcp-delayed-auth-key']);
                assert.equal('string', data.response['ingress-source-nat-pool']);
                assert.equal('string', data.response['egress-source-nat-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigInterfaceDeviceinterfaceNetworkNetworkinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkInterfaceNetworkinterfaceAddressBodyParam = {
      'ip-address': 'string',
      'utility-ip-address': 'string',
      'prefix-length': 3,
      gateway: 'string',
      'ppp-peer-ip': 'string',
      'in-subnet-arp-prefix': [
        'string'
      ]
    };
    describe('#patchConfigNetworkInterfaceNetworkinterfaceAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkInterfaceNetworkinterfaceAddress(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configPatchConfigNetworkInterfaceNetworkinterfaceAddressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkInterfaceNetworkinterfaceAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceAddress(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['utility-ip-address']);
                assert.equal(8, data.response['prefix-length']);
                assert.equal('string', data.response.gateway);
                assert.equal('string', data.response['ppp-peer-ip']);
                assert.equal(true, Array.isArray(data.response['in-subnet-arp-prefix']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceAddressHostService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceAddressHostService(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceAddressHostService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressHostServiceHostserviceBodyParam = {
      description: 'string',
      'service-type': 'string',
      enabled: 'string',
      'server-name': 'string',
      'max-lease-time': 6,
      'echo-client-id': 'string'
    };
    describe('#patchConfigAddressHostServiceHostservice - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configPatchConfigAddressHostServiceHostserviceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressHostServiceHostservice - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-type']);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response['server-name']);
                assert.equal(7, data.response['max-lease-time']);
                assert.equal('string', data.response['echo-client-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceAccessPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceAccessPolicy(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceAccessPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAccesspolicy = 'fakedata';
    const configPatchConfigServiceHostserviceAccessPolicyAccesspolicyBodyParam = {
      source: 'string',
      permission: 'string'
    };
    describe('#patchConfigServiceHostserviceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceHostserviceAccessPolicyAccesspolicy(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAccesspolicy, configPatchConfigServiceHostserviceAccessPolicyAccesspolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceHostserviceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceHostserviceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceHostserviceAccessPolicyAccesspolicy(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceHostserviceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceAddressPool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceAddressPool(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceAddressPool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceHostserviceAddressPoolAddresspoolBodyParam = {
      'start-address': 'string',
      'end-address': 'string',
      router: [
        'string'
      ],
      'domain-name': 'string',
      'interface-mtu': 6,
      'domain-server': [
        'string'
      ],
      'ntp-server': [
        'string'
      ],
      'smtp-server': [
        'string'
      ],
      'pop-server': [
        'string'
      ]
    };
    describe('#patchConfigServiceHostserviceAddressPoolAddresspool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceHostserviceAddressPoolAddresspool(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configPatchConfigServiceHostserviceAddressPoolAddresspoolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceHostserviceAddressPoolAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceHostserviceAddressPoolAddresspool - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceHostserviceAddressPoolAddresspool(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['start-address']);
                assert.equal('string', data.response['end-address']);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(8, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceHostserviceAddressPoolAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostserviceAddressPoolAddresspoolCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostserviceAddressPoolAddresspoolCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostserviceAddressPoolAddresspoolCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configCustom = 'fakedata';
    const configPatchConfigAddressPoolAddresspoolCustomBodyParam = {
      code: 2,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigAddressPoolAddresspoolCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressPoolAddresspoolCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configCustom, configPatchConfigAddressPoolAddresspoolCustomBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressPoolAddresspoolCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressPoolAddresspoolCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressPoolAddresspoolCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configCustom, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressPoolAddresspoolCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressPoolAddresspoolStaticAssignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressPoolAddresspoolStaticAssignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressPoolAddresspoolStaticAssignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPoolAddresspoolStaticAssignmentStaticassignmentBodyParam = {
      'link-layer-address': 'string',
      'client-identifier': 'string',
      'circuit-identifier': 'string',
      address: 'string',
      router: [
        'string'
      ],
      'domain-name': 'string',
      'interface-mtu': 9,
      'domain-server': [
        'string'
      ],
      'ntp-server': [
        'string'
      ],
      'smtp-server': [
        'string'
      ],
      'pop-server': [
        'string'
      ]
    };
    describe('#patchConfigPoolAddresspoolStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPoolAddresspoolStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configPatchConfigPoolAddresspoolStaticAssignmentStaticassignmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPoolAddresspoolStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPoolAddresspoolStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPoolAddresspoolStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['link-layer-address']);
                assert.equal('string', data.response['client-identifier']);
                assert.equal('string', data.response['circuit-identifier']);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(5, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPoolAddresspoolStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddresspoolStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddresspoolStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddresspoolStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStaticAssignmentStaticassignmentCustomBodyParam = {
      code: 1,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configCustom, configPatchConfigStaticAssignmentStaticassignmentCustomBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configCustom, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticAssignmentStaticassignmentRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticAssignmentStaticassignmentRoute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticAssignmentStaticassignmentRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAssignmentStaticassignmentStaticRouteStaticrouteBodyParam = {
      'destination-address': 'string',
      gateway: 'string'
    };
    describe('#patchConfigAssignmentStaticassignmentStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAssignmentStaticassignmentStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configStaticroute, configPatchConfigAssignmentStaticassignmentStaticRouteStaticrouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAssignmentStaticassignmentStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAssignmentStaticassignmentStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAssignmentStaticassignmentStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configStaticroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAssignmentStaticassignmentStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigVendorIdentifyingSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigVendorIdentifyingSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigVendorIdentifyingSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configVendoridentifyingvendorspecificinformation = 'fakedata';
    const configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformationBodyParam = {
      'enterprise-number': 4,
      code: 2,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendoridentifyingvendorspecificinformation, configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response['enterprise-number']);
                assert.equal(9, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAssignmentStaticassignmentVendorSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAssignmentStaticassignmentVendorSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAssignmentStaticassignmentVendorSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configVendorspecificinformation = 'fakedata';
    const configPatchConfigStaticassignmentVendorSpecificInformationVendorspecificinformationBodyParam = {
      code: 1,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendorspecificinformation, configPatchConfigStaticassignmentVendorSpecificInformationVendorspecificinformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressPoolAddresspoolStaticRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressPoolAddresspoolStaticRoute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressPoolAddresspoolStaticRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPoolAddresspoolStaticRouteStaticrouteBodyParam = {
      'destination-address': 'string',
      gateway: 'string'
    };
    describe('#patchConfigPoolAddresspoolStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPoolAddresspoolStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticroute, configPatchConfigPoolAddresspoolStaticRouteStaticrouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPoolAddresspoolStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPoolAddresspoolStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPoolAddresspoolStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPoolAddresspoolStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigVendorIdentifyingSpecificInformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigVendorIdentifyingSpecificInformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigVendorIdentifyingSpecificInformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2BodyParam = {
      'enterprise-number': 8,
      code: 4,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendoridentifyingvendorspecificinformation, configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response['enterprise-number']);
                assert.equal(10, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPoolAddresspoolVendorSpecificInformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPoolAddresspoolVendorSpecificInformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPoolAddresspoolVendorSpecificInformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddresspoolVendorSpecificInformationVendorspecificinformationBodyParam = {
      code: 10,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigAddresspoolVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddresspoolVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendorspecificinformation, configPatchConfigAddresspoolVendorSpecificInformationVendorspecificinformationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddresspoolVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddresspoolVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddresspoolVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddresspoolVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceStaticAssignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceStaticAssignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceStaticAssignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceHostserviceStaticAssignmentStaticassignmentBodyParam = {
      'link-layer-address': 'string',
      'client-identifier': 'string',
      'circuit-identifier': 'string',
      address: 'string',
      router: [
        'string'
      ],
      'domain-name': 'string',
      'interface-mtu': 9,
      'domain-server': [
        'string'
      ],
      'ntp-server': [
        'string'
      ],
      'smtp-server': [
        'string'
      ],
      'pop-server': [
        'string'
      ]
    };
    describe('#patchConfigServiceHostserviceStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceHostserviceStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configPatchConfigServiceHostserviceStaticAssignmentStaticassignmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceHostserviceStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceHostserviceStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceHostserviceStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['link-layer-address']);
                assert.equal('string', data.response['client-identifier']);
                assert.equal('string', data.response['circuit-identifier']);
                assert.equal('string', data.response.address);
                assert.equal(true, Array.isArray(data.response.router));
                assert.equal('string', data.response['domain-name']);
                assert.equal(6, data.response['interface-mtu']);
                assert.equal(true, Array.isArray(data.response['domain-server']));
                assert.equal(true, Array.isArray(data.response['ntp-server']));
                assert.equal(true, Array.isArray(data.response['smtp-server']));
                assert.equal(true, Array.isArray(data.response['pop-server']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceHostserviceStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostserviceStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostserviceStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostserviceStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStaticAssignmentStaticassignmentCustom2BodyParam = {
      code: 4,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigStaticAssignmentStaticassignmentCustom2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStaticAssignmentStaticassignmentCustom2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configCustom, configPatchConfigStaticAssignmentStaticassignmentCustom2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStaticAssignmentStaticassignmentCustom2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticAssignmentStaticassignmentCustom2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticAssignmentStaticassignmentCustom2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configCustom, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticAssignmentStaticassignmentCustom2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticAssignmentStaticassignmentRoute2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticAssignmentStaticassignmentRoute2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticAssignmentStaticassignmentRoute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAssignmentStaticassignmentStaticRouteStaticroute2BodyParam = {
      'destination-address': 'string',
      gateway: 'string'
    };
    describe('#patchConfigAssignmentStaticassignmentStaticRouteStaticroute2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAssignmentStaticassignmentStaticRouteStaticroute2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configStaticroute, configPatchConfigAssignmentStaticassignmentStaticRouteStaticroute2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAssignmentStaticassignmentStaticRouteStaticroute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAssignmentStaticassignmentStaticRouteStaticroute2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAssignmentStaticassignmentStaticRouteStaticroute2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configStaticroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['destination-address']);
                assert.equal('string', data.response.gateway);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAssignmentStaticassignmentStaticRouteStaticroute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigVendorIdentifyingSpecificInformation3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigVendorIdentifyingSpecificInformation3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigVendorIdentifyingSpecificInformation3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3BodyParam = {
      'enterprise-number': 4,
      code: 3,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendoridentifyingvendorspecificinformation, configPatchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(5, data.response['enterprise-number']);
                assert.equal(8, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAssignmentStaticassignmentVendorSpecificInformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAssignmentStaticassignmentVendorSpecificInformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAssignmentStaticassignmentVendorSpecificInformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2BodyParam = {
      code: 3,
      description: 'string',
      'encoded-type': 'string',
      quantity: 'string',
      value: [
        'string'
      ]
    };
    describe('#patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendorspecificinformation, configPatchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.code);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['encoded-type']);
                assert.equal('string', data.response.quantity);
                assert.equal(true, Array.isArray(data.response.value));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigHostServiceHostserviceTransportBodyParam = {
      protocol: 'string'
    };
    describe('#patchConfigHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPatchConfigHostServiceHostserviceTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostserviceTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostserviceTransportPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostserviceTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPortrange = 'fakedata';
    const configPatchConfigTransportPortRangePortrangeBodyParam = {
      'start-port': 10,
      'end-port': 5
    };
    describe('#patchConfigTransportPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTransportPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPortrange, configPatchConfigTransportPortRangePortrangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTransportPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTransportPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTransportPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response['start-port']);
                assert.equal(9, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTransportPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkInterfaceNetworkinterfaceAdjacencyBodyParam = {
      'ip-address': 'string',
      peer: 'string',
      'peer-connectivity': 'string',
      generated: 'string',
      'inter-router-security': 'string',
      'source-nat-address': [
        'string'
      ],
      'external-nat-address': 'string',
      cost: 3,
      'qp-value': 5,
      vector: [
        'string'
      ]
    };
    describe('#patchConfigNetworkInterfaceNetworkinterfaceAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkInterfaceNetworkinterfaceAdjacency(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigNetworkInterfaceNetworkinterfaceAdjacencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkInterfaceNetworkinterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceAdjacency(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response.peer);
                assert.equal('string', data.response['peer-connectivity']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['inter-router-security']);
                assert.equal(true, Array.isArray(data.response['source-nat-address']));
                assert.equal('string', data.response['external-nat-address']);
                assert.equal(4, data.response.cost);
                assert.equal(6, data.response['qp-value']);
                assert.equal(true, Array.isArray(data.response.vector));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceAdjacencyBfdBodyParam = {
      state: 'string',
      'desired-tx-interval': 1,
      'required-min-rx-interval': 2,
      'required-min-echo-interval': 1,
      'authentication-type': 'string',
      multiplier: 7,
      'link-test-interval': 5,
      'link-test-length': 10,
      dscp: 7
    };
    describe('#patchConfigNetworkinterfaceAdjacencyBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceAdjacencyBfd(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigNetworkinterfaceAdjacencyBfdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceAdjacencyBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceAdjacencyBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceAdjacencyBfd(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.state);
                assert.equal(3, data.response['desired-tx-interval']);
                assert.equal(3, data.response['required-min-rx-interval']);
                assert.equal(4, data.response['required-min-echo-interval']);
                assert.equal('string', data.response['authentication-type']);
                assert.equal(5, data.response.multiplier);
                assert.equal(10, data.response['link-test-interval']);
                assert.equal(7, data.response['link-test-length']);
                assert.equal(8, data.response.dscp);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceAdjacencyBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdjacencyNatKeepAliveBodyParam = {
      mode: 'string',
      'tcp-inactivity-timeout': 8,
      'udp-inactivity-timeout': 4
    };
    describe('#patchConfigAdjacencyNatKeepAlive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdjacencyNatKeepAlive(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigAdjacencyNatKeepAliveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdjacencyNatKeepAlive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdjacencyNatKeepAlive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdjacencyNatKeepAlive(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(2, data.response['tcp-inactivity-timeout']);
                assert.equal(3, data.response['udp-inactivity-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdjacencyNatKeepAlive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdjacencyPathMtuDiscoveryBodyParam = {
      enabled: 'string',
      interval: 4
    };
    describe('#patchConfigAdjacencyPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdjacencyPathMtuDiscovery(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigAdjacencyPathMtuDiscoveryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdjacencyPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdjacencyPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdjacencyPathMtuDiscovery(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal(4, data.response.interval);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdjacencyPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceAdjacencyPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceAdjacencyPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceAdjacencyPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdjacencyPortRangePortrangeBodyParam = {
      'start-port': 8,
      'end-port': 8
    };
    describe('#patchConfigAdjacencyPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdjacencyPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPortrange, configPatchConfigAdjacencyPortRangePortrangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdjacencyPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdjacencyPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdjacencyPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['start-port']);
                assert.equal(1, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdjacencyPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdjacencyPostEncryptionPaddingBodyParam = {
      mode: 'string'
    };
    describe('#patchConfigAdjacencyPostEncryptionPadding - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdjacencyPostEncryptionPadding(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigAdjacencyPostEncryptionPaddingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdjacencyPostEncryptionPadding', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdjacencyPostEncryptionPadding - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdjacencyPostEncryptionPadding(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdjacencyPostEncryptionPadding', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceAdjacencySessionOptimizationBodyParam = {
      mode: 'string'
    };
    describe('#patchConfigNetworkinterfaceAdjacencySessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceAdjacencySessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigNetworkinterfaceAdjacencySessionOptimizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceAdjacencySessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceAdjacencySessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceAdjacencySessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceAdjacencySessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdjacencyStepPeerPathAdvertisementBodyParam = {};
    describe('#patchConfigAdjacencyStepPeerPathAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdjacencyStepPeerPathAdvertisement(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigAdjacencyStepPeerPathAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdjacencyStepPeerPathAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdjacencyStepPeerPathAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdjacencyStepPeerPathAdvertisement(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdjacencyStepPeerPathAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPeerPathAdvertisementSlaMetricsBodyParam = {
      'moving-average-sample-size': 5
    };
    describe('#patchConfigPeerPathAdvertisementSlaMetrics - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPeerPathAdvertisementSlaMetrics(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigPeerPathAdvertisementSlaMetricsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPeerPathAdvertisementSlaMetrics', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPeerPathAdvertisementSlaMetrics - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPeerPathAdvertisementSlaMetrics(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['moving-average-sample-size']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPeerPathAdvertisementSlaMetrics', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSlaMetricsDecreaseReportDelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSlaMetricsDecreaseReportDelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSlaMetricsDecreaseReportDelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configDecreasereportdelay = 'fakedata';
    const configPatchConfigMetricsDecreaseReportDelayDecreasereportdelayBodyParam = {
      percentage: 6,
      delay: 7
    };
    describe('#patchConfigMetricsDecreaseReportDelayDecreasereportdelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigMetricsDecreaseReportDelayDecreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configDecreasereportdelay, configPatchConfigMetricsDecreaseReportDelayDecreasereportdelayBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigMetricsDecreaseReportDelayDecreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMetricsDecreaseReportDelayDecreasereportdelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMetricsDecreaseReportDelayDecreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configDecreasereportdelay, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response.percentage);
                assert.equal(8, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMetricsDecreaseReportDelayDecreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSlaMetricsIncreaseReportDelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSlaMetricsIncreaseReportDelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSlaMetricsIncreaseReportDelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configIncreasereportdelay = 'fakedata';
    const configPatchConfigMetricsIncreaseReportDelayIncreasereportdelayBodyParam = {
      percentage: 8,
      delay: 6
    };
    describe('#patchConfigMetricsIncreaseReportDelayIncreasereportdelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigMetricsIncreaseReportDelayIncreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configIncreasereportdelay, configPatchConfigMetricsIncreaseReportDelayIncreasereportdelayBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigMetricsIncreaseReportDelayIncreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMetricsIncreaseReportDelayIncreasereportdelay - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMetricsIncreaseReportDelayIncreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configIncreasereportdelay, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response.percentage);
                assert.equal(9, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMetricsIncreaseReportDelayIncreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdvertisementSlaMetricsSignificanceThresholdBodyParam = {
      'min-loss': 'string',
      'min-latency': 9,
      'min-jitter': 3
    };
    describe('#patchConfigAdvertisementSlaMetricsSignificanceThreshold - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdvertisementSlaMetricsSignificanceThreshold(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigAdvertisementSlaMetricsSignificanceThresholdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdvertisementSlaMetricsSignificanceThreshold', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdvertisementSlaMetricsSignificanceThreshold - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdvertisementSlaMetricsSignificanceThreshold(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['min-loss']);
                assert.equal(2, data.response['min-latency']);
                assert.equal(10, data.response['min-jitter']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdvertisementSlaMetricsSignificanceThreshold', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceAdjacencyUdpTransformBodyParam = {
      mode: 'string',
      'detect-interval': 8,
      'nat-keep-alive-mode': 'string',
      'nat-keep-alive-timeout': 10
    };
    describe('#patchConfigNetworkinterfaceAdjacencyUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceAdjacencyUdpTransform(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPatchConfigNetworkinterfaceAdjacencyUdpTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceAdjacencyUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceAdjacencyUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceAdjacencyUdpTransform(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(9, data.response['detect-interval']);
                assert.equal('string', data.response['nat-keep-alive-mode']);
                assert.equal(5, data.response['nat-keep-alive-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceAdjacencyUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceHostService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceHostService(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceHostService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigInterfaceNetworkinterfaceHostServiceHostserviceBodyParam = {
      description: 'string',
      'service-type': 'string',
      enabled: 'string'
    };
    describe('#patchConfigInterfaceNetworkinterfaceHostServiceHostservice - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigInterfaceNetworkinterfaceHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configPatchConfigInterfaceNetworkinterfaceHostServiceHostserviceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigInterfaceNetworkinterfaceHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigInterfaceNetworkinterfaceHostServiceHostservice - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigInterfaceNetworkinterfaceHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-type']);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigInterfaceNetworkinterfaceHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceAccessPolicy2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceAccessPolicy2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceAccessPolicy2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceHostserviceAccessPolicyAccesspolicy2BodyParam = {
      source: 'string',
      permission: 'string'
    };
    describe('#patchConfigServiceHostserviceAccessPolicyAccesspolicy2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceHostserviceAccessPolicyAccesspolicy2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configAccesspolicy, configPatchConfigServiceHostserviceAccessPolicyAccesspolicy2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceHostserviceAccessPolicyAccesspolicy2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceHostserviceAccessPolicyAccesspolicy2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceHostserviceAccessPolicyAccesspolicy2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceHostserviceAccessPolicyAccesspolicy2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigHostServiceHostserviceTransport2BodyParam = {
      protocol: 'string'
    };
    describe('#patchConfigHostServiceHostserviceTransport2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigHostServiceHostserviceTransport2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPatchConfigHostServiceHostserviceTransport2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigHostServiceHostserviceTransport2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostServiceHostserviceTransport2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostServiceHostserviceTransport2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostServiceHostserviceTransport2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigHostserviceTransportPortRange2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigHostserviceTransportPortRange2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigHostserviceTransportPortRange2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigTransportPortRangePortrange2BodyParam = {
      'start-port': 8,
      'end-port': 9
    };
    describe('#patchConfigTransportPortRangePortrange2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTransportPortRangePortrange2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPortrange, configPatchConfigTransportPortRangePortrange2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTransportPortRangePortrange2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTransportPortRangePortrange2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTransportPortRangePortrange2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response['start-port']);
                assert.equal(1, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTransportPortRangePortrange2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceIfcfgOption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceIfcfgOption(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceIfcfgOption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configIfcfgoption = 'fakedata';
    const configPatchConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoptionBodyParam = {
      name: 'string',
      value: 'string'
    };
    describe('#patchConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configIfcfgoption, configPatchConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configIfcfgoption, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.value);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkInterfaceNetworkinterfaceManagementVectorBodyParam = {
      name: 'string',
      priority: 4
    };
    describe('#patchConfigNetworkInterfaceNetworkinterfaceManagementVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkInterfaceNetworkinterfaceManagementVector(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configPatchConfigNetworkInterfaceNetworkinterfaceManagementVectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkInterfaceNetworkinterfaceManagementVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceManagementVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceManagementVector(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal(1, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceManagementVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkInterfaceNetworkinterfaceNeighborBodyParam = {
      'ip-address': 'string',
      'phys-address': 'string'
    };
    describe('#patchConfigNetworkInterfaceNetworkinterfaceNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkInterfaceNetworkinterfaceNeighbor(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighbor, configPatchConfigNetworkInterfaceNetworkinterfaceNeighborBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkInterfaceNetworkinterfaceNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceNeighbor(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['phys-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceinterfaceNetworkInterfaceNetworkinterfaceNeighborhood', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkInterfaceNetworkinterfaceNeighborhoodBodyParam = {
      name: 'string',
      'peer-connectivity': 'string',
      topology: 'string',
      'external-nat-address': 'string',
      vector: 'string',
      'qp-value': 7
    };
    describe('#patchConfigNetworkInterfaceNetworkinterfaceNeighborhood - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkInterfaceNetworkinterfaceNeighborhood(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNetworkInterfaceNetworkinterfaceNeighborhoodBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkInterfaceNetworkinterfaceNeighborhood', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkInterfaceNetworkinterfaceNeighborhood - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkInterfaceNetworkinterfaceNeighborhood(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['peer-connectivity']);
                assert.equal('string', data.response.topology);
                assert.equal('string', data.response['external-nat-address']);
                assert.equal('string', data.response.vector);
                assert.equal(6, data.response['qp-value']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkInterfaceNetworkinterfaceNeighborhood', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceNeighborhoodBfdBodyParam = {
      state: 'string',
      'desired-tx-interval': 10,
      'required-min-rx-interval': 1,
      'required-min-echo-interval': 6,
      'authentication-type': 'string',
      multiplier: 8,
      'link-test-interval': 4,
      'link-test-length': 6,
      dscp: 6
    };
    describe('#patchConfigNetworkinterfaceNeighborhoodBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceNeighborhoodBfd(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNetworkinterfaceNeighborhoodBfdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceNeighborhoodBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceNeighborhoodBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceNeighborhoodBfd(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.state);
                assert.equal(4, data.response['desired-tx-interval']);
                assert.equal(9, data.response['required-min-rx-interval']);
                assert.equal(5, data.response['required-min-echo-interval']);
                assert.equal('string', data.response['authentication-type']);
                assert.equal(7, data.response.multiplier);
                assert.equal(10, data.response['link-test-interval']);
                assert.equal(1, data.response['link-test-length']);
                assert.equal(9, data.response.dscp);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceNeighborhoodBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborhoodNatKeepAliveBodyParam = {
      mode: 'string',
      'tcp-inactivity-timeout': 6,
      'udp-inactivity-timeout': 9
    };
    describe('#patchConfigNeighborhoodNatKeepAlive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborhoodNatKeepAlive(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNeighborhoodNatKeepAliveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborhoodNatKeepAlive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborhoodNatKeepAlive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborhoodNatKeepAlive(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(9, data.response['tcp-inactivity-timeout']);
                assert.equal(6, data.response['udp-inactivity-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborhoodNatKeepAlive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborhoodPathMtuDiscoveryBodyParam = {
      enabled: 'string',
      interval: 2
    };
    describe('#patchConfigNeighborhoodPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborhoodPathMtuDiscovery(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNeighborhoodPathMtuDiscoveryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborhoodPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborhoodPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborhoodPathMtuDiscovery(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal(8, data.response.interval);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborhoodPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceNeighborhoodPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceNeighborhoodPortRange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceNeighborhoodPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborhoodPortRangePortrangeBodyParam = {
      'start-port': 2,
      'end-port': 6
    };
    describe('#patchConfigNeighborhoodPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborhoodPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPortrange, configPatchConfigNeighborhoodPortRangePortrangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborhoodPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborhoodPortRangePortrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborhoodPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response['start-port']);
                assert.equal(5, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborhoodPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborhoodPostEncryptionPaddingBodyParam = {
      mode: 'string'
    };
    describe('#patchConfigNeighborhoodPostEncryptionPadding - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborhoodPostEncryptionPadding(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNeighborhoodPostEncryptionPaddingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborhoodPostEncryptionPadding', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborhoodPostEncryptionPadding - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborhoodPostEncryptionPadding(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborhoodPostEncryptionPadding', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceNeighborhoodSessionOptimizationBodyParam = {
      mode: 'string'
    };
    describe('#patchConfigNetworkinterfaceNeighborhoodSessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceNeighborhoodSessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNetworkinterfaceNeighborhoodSessionOptimizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceNeighborhoodSessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceNeighborhoodSessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceNeighborhoodSessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceNeighborhoodSessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborhoodStepPeerPathAdvertisementBodyParam = {};
    describe('#patchConfigNeighborhoodStepPeerPathAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborhoodStepPeerPathAdvertisement(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNeighborhoodStepPeerPathAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborhoodStepPeerPathAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborhoodStepPeerPathAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborhoodStepPeerPathAdvertisement(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborhoodStepPeerPathAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPeerPathAdvertisementSlaMetrics2BodyParam = {
      'moving-average-sample-size': 2
    };
    describe('#patchConfigPeerPathAdvertisementSlaMetrics2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPeerPathAdvertisementSlaMetrics2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigPeerPathAdvertisementSlaMetrics2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPeerPathAdvertisementSlaMetrics2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPeerPathAdvertisementSlaMetrics2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPeerPathAdvertisementSlaMetrics2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response['moving-average-sample-size']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPeerPathAdvertisementSlaMetrics2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSlaMetricsDecreaseReportDelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSlaMetricsDecreaseReportDelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSlaMetricsDecreaseReportDelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigMetricsDecreaseReportDelayDecreasereportdelay2BodyParam = {
      percentage: 9,
      delay: 8
    };
    describe('#patchConfigMetricsDecreaseReportDelayDecreasereportdelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigMetricsDecreaseReportDelayDecreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configDecreasereportdelay, configPatchConfigMetricsDecreaseReportDelayDecreasereportdelay2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigMetricsDecreaseReportDelayDecreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMetricsDecreaseReportDelayDecreasereportdelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMetricsDecreaseReportDelayDecreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configDecreasereportdelay, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(8, data.response.percentage);
                assert.equal(9, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMetricsDecreaseReportDelayDecreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSlaMetricsIncreaseReportDelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSlaMetricsIncreaseReportDelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSlaMetricsIncreaseReportDelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigMetricsIncreaseReportDelayIncreasereportdelay2BodyParam = {
      percentage: 4,
      delay: 2
    };
    describe('#patchConfigMetricsIncreaseReportDelayIncreasereportdelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigMetricsIncreaseReportDelayIncreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configIncreasereportdelay, configPatchConfigMetricsIncreaseReportDelayIncreasereportdelay2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigMetricsIncreaseReportDelayIncreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigMetricsIncreaseReportDelayIncreasereportdelay2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigMetricsIncreaseReportDelayIncreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configIncreasereportdelay, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(8, data.response.percentage);
                assert.equal(10, data.response.delay);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigMetricsIncreaseReportDelayIncreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAdvertisementSlaMetricsSignificanceThreshold2BodyParam = {
      'min-loss': 'string',
      'min-latency': 3,
      'min-jitter': 6
    };
    describe('#patchConfigAdvertisementSlaMetricsSignificanceThreshold2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAdvertisementSlaMetricsSignificanceThreshold2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigAdvertisementSlaMetricsSignificanceThreshold2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAdvertisementSlaMetricsSignificanceThreshold2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAdvertisementSlaMetricsSignificanceThreshold2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAdvertisementSlaMetricsSignificanceThreshold2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['min-loss']);
                assert.equal(8, data.response['min-latency']);
                assert.equal(6, data.response['min-jitter']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAdvertisementSlaMetricsSignificanceThreshold2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNetworkinterfaceNeighborhoodUdpTransformBodyParam = {
      mode: 'string',
      'detect-interval': 5,
      'nat-keep-alive-mode': 'string',
      'nat-keep-alive-timeout': 7
    };
    describe('#patchConfigNetworkinterfaceNeighborhoodUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNetworkinterfaceNeighborhoodUdpTransform(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPatchConfigNetworkinterfaceNeighborhoodUdpTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNetworkinterfaceNeighborhoodUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNetworkinterfaceNeighborhoodUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNetworkinterfaceNeighborhoodUdpTransform(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(3, data.response['detect-interval']);
                assert.equal('string', data.response['nat-keep-alive-mode']);
                assert.equal(9, data.response['nat-keep-alive-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNetworkinterfaceNeighborhoodUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNodeDeviceInterfaceDeviceinterfacePppoeBodyParam = {
      'user-name': 'string',
      password: 'string',
      'authentication-protocol': 'string'
    };
    describe('#patchConfigNodeDeviceInterfaceDeviceinterfacePppoe - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNodeDeviceInterfaceDeviceinterfacePppoe(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigNodeDeviceInterfaceDeviceinterfacePppoeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNodeDeviceInterfaceDeviceinterfacePppoe', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNodeDeviceInterfaceDeviceinterfacePppoe - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNodeDeviceInterfaceDeviceinterfacePppoe(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['user-name']);
                assert.equal('string', data.response.password);
                assert.equal('string', data.response['authentication-protocol']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNodeDeviceInterfaceDeviceinterfacePppoe', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigDeviceInterfaceDeviceinterfaceSessionOptimizationBodyParam = {
      'enable-detection': 'string'
    };
    describe('#patchConfigDeviceInterfaceDeviceinterfaceSessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigDeviceInterfaceDeviceinterfaceSessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigDeviceInterfaceDeviceinterfaceSessionOptimizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigDeviceInterfaceDeviceinterfaceSessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceInterfaceDeviceinterfaceSessionOptimization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceInterfaceDeviceinterfaceSessionOptimization(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['enable-detection']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceInterfaceDeviceinterfaceSessionOptimization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigDeviceInterfaceDeviceinterfaceTrafficEngineeringBodyParam = {
      enabled: 'string',
      'transmit-cap': 'string',
      'traffic-profile': 'string'
    };
    describe('#patchConfigDeviceInterfaceDeviceinterfaceTrafficEngineering - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigDeviceInterfaceDeviceinterfaceTrafficEngineering(configConfigStore, configRouter, configNode, configDeviceinterface, configPatchConfigDeviceInterfaceDeviceinterfaceTrafficEngineeringBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigDeviceInterfaceDeviceinterfaceTrafficEngineering', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigDeviceInterfaceDeviceinterfaceTrafficEngineering - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigDeviceInterfaceDeviceinterfaceTrafficEngineering(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response['transmit-cap']);
                assert.equal('string', data.response['traffic-profile']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigDeviceInterfaceDeviceinterfaceTrafficEngineering', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterNodeReachabilityDetectionBodyParam = {
      'arp-refresh-interval': 3,
      'gateway-refresh-interval': 10,
      'expired-refresh-interval': 1,
      'expired-refresh-count': 10,
      'arp-cache-timeout': 7
    };
    describe('#patchConfigRouterNodeReachabilityDetection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterNodeReachabilityDetection(configConfigStore, configRouter, configNode, configPatchConfigRouterNodeReachabilityDetectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterNodeReachabilityDetection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterNodeReachabilityDetection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterNodeReachabilityDetection(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response['arp-refresh-interval']);
                assert.equal(3, data.response['gateway-refresh-interval']);
                assert.equal(4, data.response['expired-refresh-interval']);
                assert.equal(3, data.response['expired-refresh-count']);
                assert.equal(2, data.response['arp-cache-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterNodeReachabilityDetection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterNodeSshKeepaliveBodyParam = {};
    describe('#patchConfigRouterNodeSshKeepalive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterNodeSshKeepalive(configConfigStore, configRouter, configNode, configPatchConfigRouterNodeSshKeepaliveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterNodeSshKeepalive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterNodeSshKeepalive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterNodeSshKeepalive(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterNodeSshKeepalive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigKeepaliveInterConductorRouterServerBodyParam = {
      interval: 1,
      'max-attempts': 10
    };
    describe('#patchConfigKeepaliveInterConductorRouterServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigKeepaliveInterConductorRouterServer(configConfigStore, configRouter, configNode, configPatchConfigKeepaliveInterConductorRouterServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigKeepaliveInterConductorRouterServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigKeepaliveInterConductorRouterServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigKeepaliveInterConductorRouterServer(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.interval);
                assert.equal(9, data.response['max-attempts']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigKeepaliveInterConductorRouterServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNodeSshKeepaliveInterBodyParam = {
      interval: 10,
      'max-attempts': 6
    };
    describe('#patchConfigNodeSshKeepaliveInter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNodeSshKeepaliveInter(configConfigStore, configRouter, configNode, configPatchConfigNodeSshKeepaliveInterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNodeSshKeepaliveInter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNodeSshKeepaliveInter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNodeSshKeepaliveInter(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response.interval);
                assert.equal(3, data.response['max-attempts']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNodeSshKeepaliveInter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigSshKeepaliveInterNodeServerBodyParam = {
      interval: 8,
      'max-attempts': 9
    };
    describe('#patchConfigSshKeepaliveInterNodeServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSshKeepaliveInterNodeServer(configConfigStore, configRouter, configNode, configPatchConfigSshKeepaliveInterNodeServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSshKeepaliveInterNodeServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSshKeepaliveInterNodeServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSshKeepaliveInterNodeServer(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.interval);
                assert.equal(4, data.response['max-attempts']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSshKeepaliveInterNodeServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNodeSshKeepaliveInterRouterBodyParam = {
      interval: 2,
      'max-attempts': 7
    };
    describe('#patchConfigNodeSshKeepaliveInterRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNodeSshKeepaliveInterRouter(configConfigStore, configRouter, configNode, configPatchConfigNodeSshKeepaliveInterRouterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNodeSshKeepaliveInterRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNodeSshKeepaliveInterRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNodeSshKeepaliveInterRouter(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response.interval);
                assert.equal(2, data.response['max-attempts']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNodeSshKeepaliveInterRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterPathMtuDiscoveryBodyParam = {
      enabled: 'string',
      interval: 4
    };
    describe('#patchConfigRouterPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterPathMtuDiscovery(configConfigStore, configRouter, configPatchConfigRouterPathMtuDiscoveryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterPathMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterPathMtuDiscovery(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal(7, data.response.interval);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterPathMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterPeer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterPeer(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterPeer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterPeerBodyParam = {
      name: 'string',
      generated: 'string',
      description: 'string',
      'authority-name': 'string',
      'router-name': 'string',
      'inter-router-security': 'string'
    };
    describe('#patchConfigRouterPeer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterPeer(configConfigStore, configRouter, configPeer, configPatchConfigRouterPeerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterPeer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterPeer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterPeer(configConfigStore, configRouter, configPeer, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['authority-name']);
                assert.equal('string', data.response['router-name']);
                assert.equal('string', data.response['inter-router-security']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterPeer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterPeerBfdBodyParam = {
      state: 'string',
      'desired-tx-interval': 8,
      'required-min-rx-interval': 1,
      'required-min-echo-interval': 6,
      'authentication-type': 'string',
      multiplier: 9,
      'link-test-interval': 8,
      'link-test-length': 10,
      dscp: 4
    };
    describe('#patchConfigRouterPeerBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterPeerBfd(configConfigStore, configRouter, configPeer, configPatchConfigRouterPeerBfdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterPeerBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterPeerBfd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterPeerBfd(configConfigStore, configRouter, configPeer, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.state);
                assert.equal(6, data.response['desired-tx-interval']);
                assert.equal(5, data.response['required-min-rx-interval']);
                assert.equal(7, data.response['required-min-echo-interval']);
                assert.equal('string', data.response['authentication-type']);
                assert.equal(8, data.response.multiplier);
                assert.equal(3, data.response['link-test-interval']);
                assert.equal(7, data.response['link-test-length']);
                assert.equal(7, data.response.dscp);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterPeerBfd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterRedundancyGroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterRedundancyGroup(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterRedundancyGroup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterRedundancyGroupRedundancygroupBodyParam = {
      name: 'string',
      description: 'string',
      priority: 10
    };
    describe('#patchConfigRouterRedundancyGroupRedundancygroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterRedundancyGroupRedundancygroup(configConfigStore, configRouter, configRedundancygroup, configPatchConfigRouterRedundancyGroupRedundancygroupBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterRedundancyGroupRedundancygroup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRedundancyGroupRedundancygroup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRedundancyGroupRedundancygroup(configConfigStore, configRouter, configRedundancygroup, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal(5, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRedundancyGroupRedundancygroup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRedundancyGroupRedundancygroupMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRedundancyGroupRedundancygroupMember(configConfigStore, configRouter, configRedundancygroup, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRedundancyGroupRedundancygroupMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configMember = 'fakedata';
    const configPatchConfigRedundancyGroupRedundancygroupMemberBodyParam = {
      node: 'string',
      'device-id': 'string'
    };
    describe('#patchConfigRedundancyGroupRedundancygroupMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRedundancyGroupRedundancygroupMember(configConfigStore, configRouter, configRedundancygroup, configMember, configPatchConfigRedundancyGroupRedundancygroupMemberBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRedundancyGroupRedundancygroupMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRedundancyGroupRedundancygroupMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRedundancyGroupRedundancygroupMember(configConfigStore, configRouter, configRedundancygroup, configMember, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response['device-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRedundancyGroupRedundancygroupMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterRouting(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterRoutingBodyParam = {
      type: 'string',
      description: 'string'
    };
    describe('#patchConfigRouterRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterRouting(configConfigStore, configRouter, configRouting, configPatchConfigRouterRoutingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRouting(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.description);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRoutingInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRoutingInterface(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRoutingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingInterfaceBodyParam = {
      name: 'string',
      'ip-address': 'string',
      enabled: 'string'
    };
    describe('#patchConfigRoutingInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingInterface(configConfigStore, configRouter, configRouting, configInterfaceParam, configPatchConfigRoutingInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingInterface(configConfigStore, configRouter, configRouting, configInterfaceParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRoutingOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRoutingOspf(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRoutingOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingOspfBodyParam = {
      instance: 7,
      'router-id': 'string'
    };
    describe('#patchConfigRoutingOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingOspf(configConfigStore, configRouter, configRouting, configOspf, configPatchConfigRoutingOspfBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingOspf(configConfigStore, configRouter, configRouting, configOspf, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.instance);
                assert.equal('string', data.response['router-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingOspfAdvertiseDefaultBodyParam = {
      always: 'string',
      policy: 'string',
      metric: 3,
      'metric-type': 'string'
    };
    describe('#patchConfigRoutingOspfAdvertiseDefault - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingOspfAdvertiseDefault(configConfigStore, configRouter, configRouting, configOspf, configPatchConfigRoutingOspfAdvertiseDefaultBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingOspfAdvertiseDefault', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingOspfAdvertiseDefault - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingOspfAdvertiseDefault(configConfigStore, configRouter, configRouting, configOspf, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.always);
                assert.equal('string', data.response.policy);
                assert.equal(4, data.response.metric);
                assert.equal('string', data.response['metric-type']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingOspfAdvertiseDefault', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingOspfArea - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingOspfArea(configConfigStore, configRouter, configRouting, configOspf, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingOspfArea', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigOspfAreaBodyParam = {
      id: 'string',
      type: 'string',
      'summary-advertisement': 'string',
      'default-cost': 5
    };
    describe('#patchConfigOspfArea - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigOspfArea(configConfigStore, configRouter, configRouting, configOspf, configArea, configPatchConfigOspfAreaBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigOspfArea', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigOspfArea - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigOspfArea(configConfigStore, configRouter, configRouting, configOspf, configArea, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.id);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['summary-advertisement']);
                assert.equal(6, data.response['default-cost']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigOspfArea', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigOspfAreaInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigOspfAreaInterface(configConfigStore, configRouter, configRouting, configOspf, configArea, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigOspfAreaInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAreaInterfaceBodyParam = {
      node: 'string',
      interface: 'string',
      passive: 'string',
      cost: 10,
      priority: 3,
      'hello-interval': 7,
      'dead-interval': 10
    };
    describe('#patchConfigAreaInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAreaInterface(configConfigStore, configRouter, configRouting, configOspf, configArea, configInterfaceParam, configPatchConfigAreaInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAreaInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAreaInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAreaInterface(configConfigStore, configRouter, configRouting, configOspf, configArea, configInterfaceParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.interfaceParam);
                assert.equal('string', data.response.passive);
                assert.equal(7, data.response.cost);
                assert.equal(1, data.response.priority);
                assert.equal(7, data.response['hello-interval']);
                assert.equal(9, data.response['dead-interval']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAreaInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigOspfAreaSummaryRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigOspfAreaSummaryRange(configConfigStore, configRouter, configRouting, configOspf, configArea, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigOspfAreaSummaryRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configSummaryrange = 'fakedata';
    const configPatchConfigAreaSummaryRangeSummaryrangeBodyParam = {
      prefix: 'string',
      advertise: 'string',
      cost: 4
    };
    describe('#patchConfigAreaSummaryRangeSummaryrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAreaSummaryRangeSummaryrange(configConfigStore, configRouter, configRouting, configOspf, configArea, configSummaryrange, configPatchConfigAreaSummaryRangeSummaryrangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAreaSummaryRangeSummaryrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAreaSummaryRangeSummaryrange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAreaSummaryRangeSummaryrange(configConfigStore, configRouter, configRouting, configOspf, configArea, configSummaryrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.prefix);
                assert.equal('string', data.response.advertise);
                assert.equal(5, data.response.cost);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAreaSummaryRangeSummaryrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingOspfRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingOspfRedistribute(configConfigStore, configRouter, configRouting, configOspf, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingOspfRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRedistribute = 'fakedata';
    const configPatchConfigOspfRedistributeBodyParam = {
      protocol: 'string',
      policy: 'string',
      metric: 9,
      'metric-type': 'string'
    };
    describe('#patchConfigOspfRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigOspfRedistribute(configConfigStore, configRouter, configRouting, configOspf, configRedistribute, configPatchConfigOspfRedistributeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigOspfRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigOspfRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigOspfRedistribute(configConfigStore, configRouter, configRouting, configOspf, configRedistribute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
                assert.equal('string', data.response.policy);
                assert.equal(3, data.response.metric);
                assert.equal('string', data.response['metric-type']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigOspfRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRoutingProtocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRoutingProtocol(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRoutingProtocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingProtocolRoutingprotocolBodyParam = {
      description: 'string',
      type: 'string',
      'local-as': 5,
      'router-id': 'string'
    };
    describe('#patchConfigRoutingProtocolRoutingprotocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingProtocolRoutingprotocol(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPatchConfigRoutingProtocolRoutingprotocolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingProtocolRoutingprotocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocol(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.type);
                assert.equal(10, data.response['local-as']);
                assert.equal('string', data.response['router-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolAddressFamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolAddressFamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolAddressFamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigProtocolRoutingprotocolAddressFamilyAddressfamilyBodyParam = {
      'afi-safi': 'string',
      'send-default-route': 'string'
    };
    describe('#patchConfigProtocolRoutingprotocolAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigProtocolRoutingprotocolAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigProtocolRoutingprotocolAddressFamilyAddressfamilyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigProtocolRoutingprotocolAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigProtocolRoutingprotocolAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigProtocolRoutingprotocolAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['afi-safi']);
                assert.equal('string', data.response['send-default-route']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigProtocolRoutingprotocolAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyAggregate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyAggregate(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyAggregate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAggregateaddress = 'fakedata';
    const configPatchConfigFamilyAddressfamilyAggregateAddressAggregateaddressBodyParam = {
      prefix: 'string',
      'as-set': 'string',
      'summary-only': 'string'
    };
    describe('#patchConfigFamilyAddressfamilyAggregateAddressAggregateaddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigFamilyAddressfamilyAggregateAddressAggregateaddress(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configAggregateaddress, configPatchConfigFamilyAddressfamilyAggregateAddressAggregateaddressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigFamilyAddressfamilyAggregateAddressAggregateaddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigFamilyAddressfamilyAggregateAddressAggregateaddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigFamilyAddressfamilyAggregateAddressAggregateaddress(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configAggregateaddress, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.prefix);
                assert.equal('string', data.response['as-set']);
                assert.equal('string', data.response['summary-only']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigFamilyAddressfamilyAggregateAddressAggregateaddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigFamilyAddressfamilyDefaultRouteDistanceBodyParam = {
      external: 3,
      internal: 6,
      local: 4
    };
    describe('#patchConfigFamilyAddressfamilyDefaultRouteDistance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigFamilyAddressfamilyDefaultRouteDistance(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigFamilyAddressfamilyDefaultRouteDistanceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigFamilyAddressfamilyDefaultRouteDistance', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigFamilyAddressfamilyDefaultRouteDistance - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigFamilyAddressfamilyDefaultRouteDistance(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response.external);
                assert.equal(2, data.response.internal);
                assert.equal(4, data.response.local);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigFamilyAddressfamilyDefaultRouteDistance', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressFamilyAddressfamilyGracefulRestartBodyParam = {
      'restart-time': 5,
      'stale-routes-time': 5
    };
    describe('#patchConfigAddressFamilyAddressfamilyGracefulRestart - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressFamilyAddressfamilyGracefulRestart(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigAddressFamilyAddressfamilyGracefulRestartBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressFamilyAddressfamilyGracefulRestart', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyGracefulRestart - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyGracefulRestart(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['restart-time']);
                assert.equal(3, data.response['stale-routes-time']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyGracefulRestart', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolAddressFamilyAddressfamilyNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolAddressFamilyAddressfamilyNetwork(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolAddressFamilyAddressfamilyNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNetwork = 'fakedata';
    const configPatchConfigAddressFamilyAddressfamilyNetworkBodyParam = {
      'network-address': 'string',
      policy: 'string'
    };
    describe('#patchConfigAddressFamilyAddressfamilyNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressFamilyAddressfamilyNetwork(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configNetwork, configPatchConfigAddressFamilyAddressfamilyNetworkBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressFamilyAddressfamilyNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyNetwork(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configNetwork, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['network-address']);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressFamilyAddressfamilyPrefixLimitBodyParam = {
      'max-prefixes': 1,
      'shutdown-threshold-pct': 8,
      'restart-timer': 4
    };
    describe('#patchConfigAddressFamilyAddressfamilyPrefixLimit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressFamilyAddressfamilyPrefixLimit(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigAddressFamilyAddressfamilyPrefixLimitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressFamilyAddressfamilyPrefixLimit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyPrefixLimit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyPrefixLimit(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response['max-prefixes']);
                assert.equal(3, data.response['shutdown-threshold-pct']);
                assert.equal(4, data.response['restart-timer']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyPrefixLimit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigFamilyAddressfamilyUseMultiplePathsBodyParam = {};
    describe('#patchConfigFamilyAddressfamilyUseMultiplePaths - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigFamilyAddressfamilyUseMultiplePaths(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigFamilyAddressfamilyUseMultiplePathsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigFamilyAddressfamilyUseMultiplePaths', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigFamilyAddressfamilyUseMultiplePaths - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigFamilyAddressfamilyUseMultiplePaths(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigFamilyAddressfamilyUseMultiplePaths', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressfamilyUseMultiplePathsEbgpBodyParam = {
      'maximum-paths': 1
    };
    describe('#patchConfigAddressfamilyUseMultiplePathsEbgp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressfamilyUseMultiplePathsEbgp(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigAddressfamilyUseMultiplePathsEbgpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressfamilyUseMultiplePathsEbgp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressfamilyUseMultiplePathsEbgp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressfamilyUseMultiplePathsEbgp(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response['maximum-paths']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressfamilyUseMultiplePathsEbgp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressfamilyUseMultiplePathsIbgpBodyParam = {
      'maximum-paths': 2
    };
    describe('#patchConfigAddressfamilyUseMultiplePathsIbgp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressfamilyUseMultiplePathsIbgp(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configPatchConfigAddressfamilyUseMultiplePathsIbgpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressfamilyUseMultiplePathsIbgp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressfamilyUseMultiplePathsIbgp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressfamilyUseMultiplePathsIbgp(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(10, data.response['maximum-paths']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressfamilyUseMultiplePathsIbgp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingProtocolRoutingprotocolConfederationBodyParam = {
      identifier: 5,
      'member-as': [
        'string'
      ]
    };
    describe('#patchConfigRoutingProtocolRoutingprotocolConfederation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingProtocolRoutingprotocolConfederation(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPatchConfigRoutingProtocolRoutingprotocolConfederationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingProtocolRoutingprotocolConfederation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolConfederation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolConfederation(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.identifier);
                assert.equal(true, Array.isArray(data.response['member-as']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolConfederation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolNeighbor(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingProtocolRoutingprotocolNeighborBodyParam = {
      'neighbor-address': 'string',
      'neighbor-as': 5,
      'local-as': 1,
      shutdown: 'string',
      'auth-password': 'string',
      description: 'string',
      'outbound-policy-advertise': 'string'
    };
    describe('#patchConfigRoutingProtocolRoutingprotocolNeighbor - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingProtocolRoutingprotocolNeighbor(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigRoutingProtocolRoutingprotocolNeighborBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingProtocolRoutingprotocolNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolNeighbor2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolNeighbor2(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['neighbor-address']);
                assert.equal(2, data.response['neighbor-as']);
                assert.equal(10, data.response['local-as']);
                assert.equal('string', data.response.shutdown);
                assert.equal('string', data.response['auth-password']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['outbound-policy-advertise']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolNeighbor2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolNeighborAddressFamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolNeighborAddressFamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolNeighborAddressFamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborAddressFamilyAddressfamilyBodyParam = {
      'afi-safi': 'string',
      'send-default-route': 'string',
      'next-hop-self': 'string',
      'remove-private-as': 'string'
    };
    describe('#patchConfigNeighborAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, configPatchConfigNeighborAddressFamilyAddressfamilyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['afi-safi']);
                assert.equal('string', data.response['send-default-route']);
                assert.equal('string', data.response['next-hop-self']);
                assert.equal('string', data.response['remove-private-as']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigFamilyAddressfamilyAsPathOptionsBodyParam = {
      'allow-own-as': 1
    };
    describe('#patchConfigFamilyAddressfamilyAsPathOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigFamilyAddressfamilyAsPathOptions(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, configPatchConfigFamilyAddressfamilyAsPathOptionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigFamilyAddressfamilyAsPathOptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigFamilyAddressfamilyAsPathOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigFamilyAddressfamilyAsPathOptions(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(1, data.response['allow-own-as']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigFamilyAddressfamilyAsPathOptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressFamilyAddressfamilyPrefixLimit2BodyParam = {
      'max-prefixes': 8,
      'shutdown-threshold-pct': 1,
      'restart-timer': 6
    };
    describe('#patchConfigAddressFamilyAddressfamilyPrefixLimit2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressFamilyAddressfamilyPrefixLimit2(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, configPatchConfigAddressFamilyAddressfamilyPrefixLimit2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressFamilyAddressfamilyPrefixLimit2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyPrefixLimit2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyPrefixLimit2(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(2, data.response['max-prefixes']);
                assert.equal(4, data.response['shutdown-threshold-pct']);
                assert.equal(4, data.response['restart-timer']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyPrefixLimit2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAddressFamilyAddressfamilyRouteReflectorBodyParam = {
      client: 'string'
    };
    describe('#patchConfigAddressFamilyAddressfamilyRouteReflector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAddressFamilyAddressfamilyRouteReflector(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, configPatchConfigAddressFamilyAddressfamilyRouteReflectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAddressFamilyAddressfamilyRouteReflector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAddressFamilyAddressfamilyRouteReflector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAddressFamilyAddressfamilyRouteReflector(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.client);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAddressFamilyAddressfamilyRouteReflector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingprotocolNeighborMultihopBodyParam = {
      ttl: 7
    };
    describe('#patchConfigRoutingprotocolNeighborMultihop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingprotocolNeighborMultihop(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigRoutingprotocolNeighborMultihopBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingprotocolNeighborMultihop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolNeighborMultihop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolNeighborMultihop(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(4, data.response.ttl);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolNeighborMultihop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingprotocolNeighborPolicyBodyParam = {
      'outbound-policy-advertise': 'string',
      'outbound-policy-transit': 'string',
      'inbound-policy': 'string',
      'outbound-policy': 'string'
    };
    describe('#patchConfigRoutingprotocolNeighborPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingprotocolNeighborPolicy(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigRoutingprotocolNeighborPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingprotocolNeighborPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolNeighborPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolNeighborPolicy(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['outbound-policy-advertise']);
                assert.equal('string', data.response['outbound-policy-transit']);
                assert.equal('string', data.response['inbound-policy']);
                assert.equal('string', data.response['outbound-policy']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolNeighborPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingprotocolNeighborTimersBodyParam = {
      'hold-time': 8,
      'keepalive-interval': 9,
      'connect-retry': 8,
      'minimum-advertisement-interval': 2
    };
    describe('#patchConfigRoutingprotocolNeighborTimers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingprotocolNeighborTimers(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigRoutingprotocolNeighborTimersBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingprotocolNeighborTimers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolNeighborTimers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolNeighborTimers(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response['hold-time']);
                assert.equal(6, data.response['keepalive-interval']);
                assert.equal(1, data.response['connect-retry']);
                assert.equal(6, data.response['minimum-advertisement-interval']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolNeighborTimers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingprotocolNeighborTransportBodyParam = {
      'passive-mode': 'string'
    };
    describe('#patchConfigRoutingprotocolNeighborTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingprotocolNeighborTransport(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigRoutingprotocolNeighborTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingprotocolNeighborTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingprotocolNeighborTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingprotocolNeighborTransport(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['passive-mode']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingprotocolNeighborTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigNeighborTransportLocalAddressBodyParam = {
      node: 'string',
      interface: 'string',
      'routing-interface': 'string'
    };
    describe('#patchConfigNeighborTransportLocalAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigNeighborTransportLocalAddress(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configPatchConfigNeighborTransportLocalAddressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigNeighborTransportLocalAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigNeighborTransportLocalAddress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigNeighborTransportLocalAddress(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.interfaceParam);
                assert.equal('string', data.response['routing-interface']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigNeighborTransportLocalAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolRedistribute(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingProtocolRoutingprotocolRedistributeBodyParam = {
      protocol: 'string',
      policy: 'string'
    };
    describe('#patchConfigRoutingProtocolRoutingprotocolRedistribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingProtocolRoutingprotocolRedistribute(configConfigStore, configRouter, configRouting, configRoutingprotocol, configRedistribute, configPatchConfigRoutingProtocolRoutingprotocolRedistributeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingProtocolRoutingprotocolRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolRedistribute2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolRedistribute2(configConfigStore, configRouter, configRouting, configRoutingprotocol, configRedistribute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolRedistribute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigProtocolRoutingprotocolRouteSelectionOptionsBodyParam = {
      'always-compare-med': 'string',
      'ignore-as-path-length': 'string',
      'external-compare-router-id': 'string'
    };
    describe('#patchConfigProtocolRoutingprotocolRouteSelectionOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigProtocolRoutingprotocolRouteSelectionOptions(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPatchConfigProtocolRoutingprotocolRouteSelectionOptionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigProtocolRoutingprotocolRouteSelectionOptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigProtocolRoutingprotocolRouteSelectionOptions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigProtocolRoutingprotocolRouteSelectionOptions(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['always-compare-med']);
                assert.equal('string', data.response['ignore-as-path-length']);
                assert.equal('string', data.response['external-compare-router-id']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigProtocolRoutingprotocolRouteSelectionOptions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingProtocolRoutingprotocolTimersBodyParam = {
      'hold-time': 8,
      'keepalive-interval': 10
    };
    describe('#patchConfigRoutingProtocolRoutingprotocolTimers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingProtocolRoutingprotocolTimers(configConfigStore, configRouter, configRouting, configRoutingprotocol, configPatchConfigRoutingProtocolRoutingprotocolTimersBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingProtocolRoutingprotocolTimers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingProtocolRoutingprotocolTimers - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingProtocolRoutingprotocolTimers(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response['hold-time']);
                assert.equal(9, data.response['keepalive-interval']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingProtocolRoutingprotocolTimers', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterRoutingStaticRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterRoutingStaticRoute(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterRoutingStaticRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRoutingStaticRouteStaticrouteBodyParam = {
      'next-hop': [
        'string'
      ],
      blackhole: 'string',
      'destination-prefix': 'string',
      distance: 5,
      description: 'string'
    };
    describe('#patchConfigRoutingStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRoutingStaticRouteStaticroute(configConfigStore, configRouter, configRouting, configStaticroute, configPatchConfigRoutingStaticRouteStaticrouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRoutingStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingStaticRouteStaticroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingStaticRouteStaticroute(configConfigStore, configRouter, configRouting, configStaticroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(true, Array.isArray(data.response['next-hop']));
                assert.equal('string', data.response.blackhole);
                assert.equal('string', data.response['destination-prefix']);
                assert.equal(1, data.response.distance);
                assert.equal('string', data.response.description);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouteStaticrouteNextHopInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouteStaticrouteNextHopInterface(configConfigStore, configRouter, configRouting, configStaticroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouteStaticrouteNextHopInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNexthopinterface = 'fakedata';
    const configPatchConfigStaticrouteNextHopInterfaceNexthopinterfaceBodyParam = {
      node: 'string',
      interface: 'string'
    };
    describe('#patchConfigStaticrouteNextHopInterfaceNexthopinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStaticrouteNextHopInterfaceNexthopinterface(configConfigStore, configRouter, configRouting, configStaticroute, configNexthopinterface, configPatchConfigStaticrouteNextHopInterfaceNexthopinterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStaticrouteNextHopInterfaceNexthopinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStaticrouteNextHopInterfaceNexthopinterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStaticrouteNextHopInterfaceNexthopinterface(configConfigStore, configRouter, configRouting, configStaticroute, configNexthopinterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.interfaceParam);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStaticrouteNextHopInterfaceNexthopinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterServiceRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterServiceRoute(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterServiceRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterServiceRoutePolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterServiceRoutePolicy(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterServiceRoutePolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configServiceroutepolicy = 'fakedata';
    const configPatchConfigRouterServiceRoutePolicyServiceroutepolicyBodyParam = {
      name: 'string',
      description: 'string',
      'session-rate': 'string',
      'max-sessions': 'string',
      'session-high-water-mark': 1,
      'session-low-water-mark': 1,
      'packet-replication': 'string'
    };
    describe('#patchConfigRouterServiceRoutePolicyServiceroutepolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterServiceRoutePolicyServiceroutepolicy(configConfigStore, configRouter, configServiceroutepolicy, configPatchConfigRouterServiceRoutePolicyServiceroutepolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterServiceRoutePolicyServiceroutepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterServiceRoutePolicyServiceroutepolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterServiceRoutePolicyServiceroutepolicy(configConfigStore, configRouter, configServiceroutepolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['session-rate']);
                assert.equal('string', data.response['max-sessions']);
                assert.equal(3, data.response['session-high-water-mark']);
                assert.equal(8, data.response['session-low-water-mark']);
                assert.equal('string', data.response['packet-replication']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterServiceRoutePolicyServiceroutepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterServiceRouteServicerouteBodyParam = {
      destination: 'string',
      'nat-target': 'string',
      'port-target': 5,
      peer: 'string',
      'next-peer': [
        'string'
      ],
      'use-learned-routes': 'string',
      'routing-stack': 'string',
      name: 'string',
      'service-name': 'string',
      generated: 'string',
      'service-route-policy': 'string'
    };
    describe('#patchConfigRouterServiceRouteServiceroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterServiceRouteServiceroute(configConfigStore, configRouter, configServiceroute, configPatchConfigRouterServiceRouteServicerouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterServiceRouteServiceroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterServiceRouteServiceroute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterServiceRouteServiceroute(configConfigStore, configRouter, configServiceroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.destination);
                assert.equal('string', data.response['nat-target']);
                assert.equal(3, data.response['port-target']);
                assert.equal('string', data.response.peer);
                assert.equal(true, Array.isArray(data.response['next-peer']));
                assert.equal('string', data.response['use-learned-routes']);
                assert.equal('string', data.response['routing-stack']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['service-name']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['service-route-policy']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterServiceRouteServiceroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterServiceRouteServicerouteHost - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterServiceRouteServicerouteHost(configConfigStore, configRouter, configServiceroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterServiceRouteServicerouteHost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configHost = 'fakedata';
    const configPatchConfigServiceRouteServicerouteHostBodyParam = {
      'node-name': 'string',
      'target-address': [
        'string'
      ]
    };
    describe('#patchConfigServiceRouteServicerouteHost - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceRouteServicerouteHost(configConfigStore, configRouter, configServiceroute, configHost, configPatchConfigServiceRouteServicerouteHostBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceRouteServicerouteHost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceRouteServicerouteHost - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceRouteServicerouteHost(configConfigStore, configRouter, configServiceroute, configHost, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal(true, Array.isArray(data.response['target-address']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceRouteServicerouteHost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceRouteServicerouteNextHop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceRouteServicerouteNextHop(configConfigStore, configRouter, configServiceroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceRouteServicerouteNextHop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNexthop = 'fakedata';
    const configPatchConfigRouteServicerouteNextHopNexthopBodyParam = {
      'node-name': 'string',
      interface: 'string',
      'gateway-ip': 'string',
      'target-address': [
        'string'
      ],
      'source-nat-pool': 'string'
    };
    describe('#patchConfigRouteServicerouteNextHopNexthop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouteServicerouteNextHopNexthop(configConfigStore, configRouter, configServiceroute, configNexthop, configPatchConfigRouteServicerouteNextHopNexthopBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouteServicerouteNextHopNexthop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouteServicerouteNextHopNexthop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouteServicerouteNextHopNexthop(configConfigStore, configRouter, configServiceroute, configNexthop, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal('string', data.response.interfaceParam);
                assert.equal('string', data.response['gateway-ip']);
                assert.equal(true, Array.isArray(data.response['target-address']));
                assert.equal('string', data.response['source-nat-pool']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouteServicerouteNextHopNexthop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceRouteServicerouteReachabilityDetectionBodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigServiceRouteServicerouteReachabilityDetection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceRouteServicerouteReachabilityDetection(configConfigStore, configRouter, configServiceroute, configPatchConfigServiceRouteServicerouteReachabilityDetectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceRouteServicerouteReachabilityDetection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceRouteServicerouteReachabilityDetection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceRouteServicerouteReachabilityDetection(configConfigStore, configRouter, configServiceroute, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceRouteServicerouteReachabilityDetection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRouterSystemBodyParam = {
      contact: 'string',
      location: 'string',
      'log-level': 'string',
      'inactivity-timer': 6
    };
    describe('#patchConfigAuthorityRouterSystem - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRouterSystem(configConfigStore, configRouter, configPatchConfigAuthorityRouterSystemBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRouterSystem', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterSystem - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterSystem(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.contact);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response['log-level']);
                assert.equal(1, data.response['inactivity-timer']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterSystem', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemAuditBodyParam = {};
    describe('#patchConfigRouterSystemAudit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemAudit(configConfigStore, configRouter, configPatchConfigRouterSystemAuditBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemAudit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemAudit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemAudit(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemAudit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemAuditAdministrationBodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigRouterSystemAuditAdministration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemAuditAdministration(configConfigStore, configRouter, configPatchConfigRouterSystemAuditAdministrationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemAuditAdministration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemAuditAdministration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemAuditAdministration(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemAuditAdministration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemAudit2BodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigRouterSystemAudit2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemAudit2(configConfigStore, configRouter, configPatchConfigRouterSystemAudit2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemAudit2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemAudit2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemAudit2(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemAudit2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemAuditTrafficBodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigRouterSystemAuditTraffic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemAuditTraffic(configConfigStore, configRouter, configPatchConfigRouterSystemAuditTrafficBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemAuditTraffic', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemAuditTraffic - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemAuditTraffic(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemAuditTraffic', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemLocalLoginBodyParam = {};
    describe('#patchConfigRouterSystemLocalLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemLocalLogin(configConfigStore, configRouter, configPatchConfigRouterSystemLocalLoginBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemLocalLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemLocalLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemLocalLogin(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemLocalLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemLocalLoginNetconfBodyParam = {
      'session-limit': 6,
      'session-limit-action': 'string'
    };
    describe('#patchConfigRouterSystemLocalLoginNetconf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemLocalLoginNetconf(configConfigStore, configRouter, configPatchConfigRouterSystemLocalLoginNetconfBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemLocalLoginNetconf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemLocalLoginNetconf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemLocalLoginNetconf(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(7, data.response['session-limit']);
                assert.equal('string', data.response['session-limit-action']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemLocalLoginNetconf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemLogCategory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemLogCategory(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemLogCategory', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configLogcategory = 'fakedata';
    const configPatchConfigRouterSystemLogCategoryLogcategoryBodyParam = {
      name: 'string',
      'log-level': 'string'
    };
    describe('#patchConfigRouterSystemLogCategoryLogcategory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemLogCategoryLogcategory(configConfigStore, configRouter, configLogcategory, configPatchConfigRouterSystemLogCategoryLogcategoryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemLogCategoryLogcategory', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemLogCategoryLogcategory - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemLogCategoryLogcategory(configConfigStore, configRouter, configLogcategory, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['log-level']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemLogCategoryLogcategory', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemMetricsBodyParam = {
      'sample-period': 3
    };
    describe('#patchConfigRouterSystemMetrics - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemMetrics(configConfigStore, configRouter, configPatchConfigRouterSystemMetricsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemMetrics', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemMetrics - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemMetrics(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response['sample-period']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemMetrics', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemNtpBodyParam = {};
    describe('#patchConfigRouterSystemNtp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemNtp(configConfigStore, configRouter, configPatchConfigRouterSystemNtpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemNtp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemNtp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemNtp(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemNtp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemNtpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemNtpServer(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemNtpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configServer = 'fakedata';
    const configPatchConfigSystemNtpServerBodyParam = {
      'ip-address': 'string'
    };
    describe('#patchConfigSystemNtpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSystemNtpServer(configConfigStore, configRouter, configServer, configPatchConfigSystemNtpServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSystemNtpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSystemNtpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSystemNtpServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSystemNtpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemRemoteLoginBodyParam = {
      enabled: 'string'
    };
    describe('#patchConfigRouterSystemRemoteLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemRemoteLogin(configConfigStore, configRouter, configPatchConfigRouterSystemRemoteLoginBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemRemoteLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemRemoteLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemRemoteLogin(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemRemoteLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemServicesBodyParam = {};
    describe('#patchConfigRouterSystemServices - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemServices(configConfigStore, configRouter, configPatchConfigRouterSystemServicesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemServices', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemServices - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemServices(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemServices', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemServicesSnmpServerBodyParam = {
      enabled: 'string',
      version: 'string',
      port: 2
    };
    describe('#patchConfigRouterSystemServicesSnmpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemServicesSnmpServer(configConfigStore, configRouter, configPatchConfigRouterSystemServicesSnmpServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemServicesSnmpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemServicesSnmpServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemServicesSnmpServer(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.version);
                assert.equal(5, data.response.port);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemServicesSnmpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServicesSnmpServerAccessControl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServicesSnmpServerAccessControl(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServicesSnmpServerAccessControl', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAccesscontrol = 'fakedata';
    const configPatchConfigSnmpServerAccessControlAccesscontrolBodyParam = {
      name: 'string',
      community: 'string',
      source: 'string'
    };
    describe('#patchConfigSnmpServerAccessControlAccesscontrol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSnmpServerAccessControlAccesscontrol(configConfigStore, configRouter, configAccesscontrol, configPatchConfigSnmpServerAccessControlAccesscontrolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSnmpServerAccessControlAccesscontrol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSnmpServerAccessControlAccesscontrol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSnmpServerAccessControlAccesscontrol(configConfigStore, configRouter, configAccesscontrol, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.community);
                assert.equal('string', data.response.source);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSnmpServerAccessControlAccesscontrol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServicesSnmpServerNotificationReceiver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServicesSnmpServerNotificationReceiver(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServicesSnmpServerNotificationReceiver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configNotificationreceiver = 'fakedata';
    const configPatchConfigSnmpServerNotificationReceiverNotificationreceiverBodyParam = {
      'ip-address': 'string',
      port: 8,
      type: 'string',
      community: 'string'
    };
    describe('#patchConfigSnmpServerNotificationReceiverNotificationreceiver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSnmpServerNotificationReceiverNotificationreceiver(configConfigStore, configRouter, configNotificationreceiver, configPatchConfigSnmpServerNotificationReceiverNotificationreceiverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSnmpServerNotificationReceiverNotificationreceiver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSnmpServerNotificationReceiverNotificationreceiver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSnmpServerNotificationReceiverNotificationreceiver(configConfigStore, configRouter, configNotificationreceiver, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal(3, data.response.port);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.community);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSnmpServerNotificationReceiverNotificationreceiver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemServicesWebserverBodyParam = {
      enabled: 'string',
      port: 1
    };
    describe('#patchConfigRouterSystemServicesWebserver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemServicesWebserver(configConfigStore, configRouter, configPatchConfigRouterSystemServicesWebserverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemServicesWebserver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemServicesWebserver - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemServicesWebserver(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.enabled);
                assert.equal(4, data.response.port);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemServicesWebserver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSystemServicesWebserverServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSystemServicesWebserverServer(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSystemServicesWebserverServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServicesWebserverServerBodyParam = {
      'node-name': 'string',
      'ip-address': 'string'
    };
    describe('#patchConfigServicesWebserverServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServicesWebserverServer(configConfigStore, configRouter, configServer, configPatchConfigServicesWebserverServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServicesWebserverServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServicesWebserverServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServicesWebserverServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['node-name']);
                assert.equal('string', data.response['ip-address']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServicesWebserverServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemSoftwareUpdateBodyParam = {
      'max-bandwidth': 'string'
    };
    describe('#patchConfigRouterSystemSoftwareUpdate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemSoftwareUpdate(configConfigStore, configRouter, configPatchConfigRouterSystemSoftwareUpdateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemSoftwareUpdate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemSoftwareUpdate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemSoftwareUpdate(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['max-bandwidth']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemSoftwareUpdate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemSoftwareUpdateRepositoryBodyParam = {
      'offline-mode': 'string',
      'source-type': 'string',
      address: 'string'
    };
    describe('#patchConfigRouterSystemSoftwareUpdateRepository - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemSoftwareUpdateRepository(configConfigStore, configRouter, configPatchConfigRouterSystemSoftwareUpdateRepositoryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemSoftwareUpdateRepository', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemSoftwareUpdateRepository - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemSoftwareUpdateRepository(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['offline-mode']);
                assert.equal('string', data.response['source-type']);
                assert.equal('string', data.response.address);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemSoftwareUpdateRepository', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigRouterSystemSyslogBodyParam = {
      severity: 'string',
      facility: 'string'
    };
    describe('#patchConfigRouterSystemSyslog - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigRouterSystemSyslog(configConfigStore, configRouter, configPatchConfigRouterSystemSyslogBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigRouterSystemSyslog', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemSyslog - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemSyslog(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.severity);
                assert.equal('string', data.response.facility);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemSyslog', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRouterSystemSyslogServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRouterSystemSyslogServer(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRouterSystemSyslogServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigSystemSyslogServerBodyParam = {
      'ip-address': 'string',
      port: 1
    };
    describe('#patchConfigSystemSyslogServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSystemSyslogServer(configConfigStore, configRouter, configServer, configPatchConfigSystemSyslogServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSystemSyslogServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSystemSyslogServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSystemSyslogServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['ip-address']);
                assert.equal(3, data.response.port);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSystemSyslogServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRouterUdpTransformBodyParam = {
      mode: 'string',
      'detect-interval': 2,
      'nat-keep-alive-mode': 'string',
      'nat-keep-alive-timeout': 2
    };
    describe('#patchConfigAuthorityRouterUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRouterUdpTransform(configConfigStore, configRouter, configPatchConfigAuthorityRouterUdpTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRouterUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRouterUdpTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRouterUdpTransform(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.mode);
                assert.equal(6, data.response['detect-interval']);
                assert.equal('string', data.response['nat-keep-alive-mode']);
                assert.equal(9, data.response['nat-keep-alive-timeout']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRouterUdpTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityRoutingBodyParam = {};
    describe('#patchConfigStoreAuthorityRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityRouting(configConfigStore, configPatchConfigStoreAuthorityRoutingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRouting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRouting(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRoutingFilter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRoutingFilter(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRoutingFilter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRoutingFilterBodyParam = {
      type: 'string',
      name: 'string'
    };
    describe('#patchConfigAuthorityRoutingFilter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRoutingFilter(configConfigStore, configFilter, configPatchConfigAuthorityRoutingFilterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRoutingFilter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRoutingFilter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRoutingFilter(configConfigStore, configFilter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRoutingFilter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingFilterRule - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingFilterRule(configConfigStore, configFilter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingFilterRule', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configRule = 'fakedata';
    const configPatchConfigFilterRuleBodyParam = {
      name: 'string',
      filter: 'string',
      prefix: 'string',
      ge: 10,
      le: 8,
      'as-path': 'string',
      community: 'string',
      'extended-community': 'string'
    };
    describe('#patchConfigFilterRule - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigFilterRule(configConfigStore, configFilter, configRule, configPatchConfigFilterRuleBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigFilterRule', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigFilterRule - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigFilterRule(configConfigStore, configFilter, configRule, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.filter);
                assert.equal('string', data.response.prefix);
                assert.equal(8, data.response.ge);
                assert.equal(1, data.response.le);
                assert.equal('string', data.response['as-path']);
                assert.equal('string', data.response.community);
                assert.equal('string', data.response['extended-community']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigFilterRule', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityRoutingPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityRoutingPolicy(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityRoutingPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityRoutingPolicyBodyParam = {
      name: 'string'
    };
    describe('#patchConfigAuthorityRoutingPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityRoutingPolicy(configConfigStore, configPolicy, configPatchConfigAuthorityRoutingPolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityRoutingPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityRoutingPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityRoutingPolicy(configConfigStore, configPolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityRoutingPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigRoutingPolicyStatement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigRoutingPolicyStatement(configConfigStore, configPolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigRoutingPolicyStatement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigPolicyStatementBodyParam = {
      name: 'string',
      policy: 'string'
    };
    describe('#patchConfigPolicyStatement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPolicyStatement(configConfigStore, configPolicy, configStatement, configPatchConfigPolicyStatementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPolicyStatement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPolicyStatement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPolicyStatement(configConfigStore, configPolicy, configStatement, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPolicyStatement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPolicyStatementAction - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPolicyStatementAction(configConfigStore, configPolicy, configStatement, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPolicyStatementAction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAction = 'fakedata';
    const configPatchConfigStatementActionBodyParam = {
      'community-attribute': [
        'string'
      ],
      additive: 'string',
      none: 'string',
      'ip-address': 'string',
      'peer-address': 'string',
      set: 4,
      add: 9,
      subtract: 8,
      type: 'string',
      as: 2,
      'aggregator-address': 'string',
      exclude: 'string',
      prepend: 'string',
      'community-filter': 'string',
      'route-target': [
        'string'
      ],
      'site-of-origin': [
        'string'
      ],
      'local-preference': 9,
      'originator-id': 'string',
      origin: 'string',
      'bgp-weight': 7,
      tag: 7,
      statement: 'string',
      policy: 'string'
    };
    describe('#patchConfigStatementAction - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStatementAction(configConfigStore, configPolicy, configStatement, configAction, configPatchConfigStatementActionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStatementAction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStatementAction - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStatementAction(configConfigStore, configPolicy, configStatement, configAction, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(true, Array.isArray(data.response['community-attribute']));
                assert.equal('string', data.response.additive);
                assert.equal('string', data.response.none);
                assert.equal('string', data.response['ip-address']);
                assert.equal('string', data.response['peer-address']);
                assert.equal(7, data.response.set);
                assert.equal(7, data.response.add);
                assert.equal(3, data.response.subtract);
                assert.equal('string', data.response.type);
                assert.equal(1, data.response.as);
                assert.equal('string', data.response['aggregator-address']);
                assert.equal('string', data.response.exclude);
                assert.equal('string', data.response.prepend);
                assert.equal('string', data.response['community-filter']);
                assert.equal(true, Array.isArray(data.response['route-target']));
                assert.equal(true, Array.isArray(data.response['site-of-origin']));
                assert.equal(4, data.response['local-preference']);
                assert.equal('string', data.response['originator-id']);
                assert.equal('string', data.response.origin);
                assert.equal(4, data.response['bgp-weight']);
                assert.equal(1, data.response.tag);
                assert.equal('string', data.response.statement);
                assert.equal('string', data.response.policy);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStatementAction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPolicyStatementCondition - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPolicyStatementCondition(configConfigStore, configPolicy, configStatement, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPolicyStatementCondition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configCondition = 'fakedata';
    const configPatchConfigStatementConditionBodyParam = {
      'peer-address': 'string',
      'peer-local': 'string',
      type: 'string',
      'prefix-filter': 'string',
      'as-path-filter': 'string',
      'community-filter': 'string',
      'extended-community-filter': 'string',
      'next-hop-node': 'string',
      'next-hop-interface': 'string',
      metric: 7,
      origin: 'string',
      probability: 2,
      tag: 4
    };
    describe('#patchConfigStatementCondition - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStatementCondition(configConfigStore, configPolicy, configStatement, configCondition, configPatchConfigStatementConditionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStatementCondition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStatementCondition - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStatementCondition(configConfigStore, configPolicy, configStatement, configCondition, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['peer-address']);
                assert.equal('string', data.response['peer-local']);
                assert.equal('string', data.response.type);
                assert.equal('string', data.response['prefix-filter']);
                assert.equal('string', data.response['as-path-filter']);
                assert.equal('string', data.response['community-filter']);
                assert.equal('string', data.response['extended-community-filter']);
                assert.equal('string', data.response['next-hop-node']);
                assert.equal('string', data.response['next-hop-interface']);
                assert.equal(3, data.response.metric);
                assert.equal('string', data.response.origin);
                assert.equal(4, data.response.probability);
                assert.equal(3, data.response.tag);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStatementCondition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthoritySecurity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthoritySecurity(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthoritySecurity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthoritySecurityBodyParam = {
      hmac: 'string',
      'hmac-mode': 'string',
      name: 'string',
      description: 'string',
      'hmac-cipher': 'string',
      'hmac-key': 'string',
      'encryption-cipher': 'string',
      'encryption-key': 'string',
      'encryption-iv': 'string',
      encrypt: 'string',
      'adaptive-encryption': 'string'
    };
    describe('#patchConfigStoreAuthoritySecurity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthoritySecurity(configConfigStore, configSecurity, configPatchConfigStoreAuthoritySecurityBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthoritySecurity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthoritySecurity2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthoritySecurity2(configConfigStore, configSecurity, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.hmac);
                assert.equal('string', data.response['hmac-mode']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['hmac-cipher']);
                assert.equal('string', data.response['hmac-key']);
                assert.equal('string', data.response['encryption-cipher']);
                assert.equal('string', data.response['encryption-key']);
                assert.equal('string', data.response['encryption-iv']);
                assert.equal('string', data.response.encrypt);
                assert.equal('string', data.response['adaptive-encryption']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthoritySecurity2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityService(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityServiceClass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityServiceClass(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityServiceClass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configServiceclass = 'fakedata';
    const configPatchConfigStoreAuthorityServiceClassServiceclassBodyParam = {
      'traffic-class': 'string',
      priority: 5,
      name: 'string',
      description: 'string',
      dscp: 9,
      'rate-limit': 'string',
      'max-flow-rate': 2,
      'max-flow-burst': 10
    };
    describe('#patchConfigStoreAuthorityServiceClassServiceclass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityServiceClassServiceclass(configConfigStore, configServiceclass, configPatchConfigStoreAuthorityServiceClassServiceclassBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityServiceClassServiceclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityServiceClassServiceclass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityServiceClassServiceclass(configConfigStore, configServiceclass, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['traffic-class']);
                assert.equal(10, data.response.priority);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal(1, data.response.dscp);
                assert.equal('string', data.response['rate-limit']);
                assert.equal(5, data.response['max-flow-rate']);
                assert.equal(7, data.response['max-flow-burst']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityServiceClassServiceclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityServicePolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityServicePolicy(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityServicePolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityServicePolicyServicepolicyBodyParam = {
      'max-loss': 'string',
      'max-latency': 9,
      'max-jitter': 10,
      'min-mos': 'string',
      name: 'string',
      description: 'string',
      'service-class': 'string',
      'lb-strategy': 'string',
      'required-qp': 9,
      'qp-preference': 'string',
      'session-resiliency': 'string',
      'peer-path-resiliency': 'string',
      'path-quality-filter': 'string',
      'best-effort': 'string',
      'transport-state-enforcement': 'string',
      generated: 'string',
      'ingress-source-nat': 'string'
    };
    describe('#patchConfigStoreAuthorityServicePolicyServicepolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityServicePolicyServicepolicy(configConfigStore, configServicepolicy, configPatchConfigStoreAuthorityServicePolicyServicepolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityServicePolicyServicepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityServicePolicyServicepolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityServicePolicyServicepolicy(configConfigStore, configServicepolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response['max-loss']);
                assert.equal(6, data.response['max-latency']);
                assert.equal(7, data.response['max-jitter']);
                assert.equal('string', data.response['min-mos']);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-class']);
                assert.equal('string', data.response['lb-strategy']);
                assert.equal(4, data.response['required-qp']);
                assert.equal('string', data.response['qp-preference']);
                assert.equal('string', data.response['session-resiliency']);
                assert.equal('string', data.response['peer-path-resiliency']);
                assert.equal('string', data.response['path-quality-filter']);
                assert.equal('string', data.response['best-effort']);
                assert.equal('string', data.response['transport-state-enforcement']);
                assert.equal('string', data.response.generated);
                assert.equal('string', data.response['ingress-source-nat']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityServicePolicyServicepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServicePolicyServicepolicyAppliesTo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServicePolicyServicepolicyAppliesTo(configConfigStore, configServicepolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServicePolicyServicepolicyAppliesTo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configAppliesto = 'fakedata';
    const configPatchConfigPolicyServicepolicyAppliesToAppliestoBodyParam = {
      type: 'string',
      'router-name': [
        'string'
      ],
      'group-name': [
        'string'
      ]
    };
    describe('#patchConfigPolicyServicepolicyAppliesToAppliesto - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigPolicyServicepolicyAppliesToAppliesto(configConfigStore, configServicepolicy, configAppliesto, configPatchConfigPolicyServicepolicyAppliesToAppliestoBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigPolicyServicepolicyAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigPolicyServicepolicyAppliesToAppliesto - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigPolicyServicepolicyAppliesToAppliesto(configConfigStore, configServicepolicy, configAppliesto, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal(true, Array.isArray(data.response['router-name']));
                assert.equal(true, Array.isArray(data.response['group-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigPolicyServicepolicyAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityServicePolicyServicepolicyVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityServicePolicyServicepolicyVector(configConfigStore, configServicepolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityServicePolicyServicepolicyVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServicePolicyServicepolicyVectorBodyParam = {
      name: 'string',
      priority: 'string'
    };
    describe('#patchConfigServicePolicyServicepolicyVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServicePolicyServicepolicyVector(configConfigStore, configServicepolicy, configVector, configPatchConfigServicePolicyServicepolicyVectorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServicePolicyServicepolicyVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServicePolicyServicepolicyVector - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServicePolicyServicepolicyVector(configConfigStore, configServicepolicy, configVector, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServicePolicyServicepolicyVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityServiceBodyParam = {
      name: 'string',
      'service-group': 'string',
      description: 'string',
      enabled: 'string',
      tenant: 'string',
      scope: 'string',
      security: 'string',
      'tap-multiplexing': 'string',
      address: [
        'string'
      ],
      'application-name': [
        'string'
      ],
      'access-policy-generated': 'string',
      'service-policy': 'string',
      'share-service-routes': 'string',
      'source-nat': 'string',
      'application-type': 'string',
      'fqdn-resolution-type': 'string',
      generated: 'string'
    };
    describe('#patchConfigStoreAuthorityService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityService(configConfigStore, configService, configPatchConfigStoreAuthorityServiceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityService2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityService2(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response['service-group']);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.enabled);
                assert.equal('string', data.response.tenant);
                assert.equal('string', data.response.scope);
                assert.equal('string', data.response.security);
                assert.equal('string', data.response['tap-multiplexing']);
                assert.equal(true, Array.isArray(data.response.address));
                assert.equal(true, Array.isArray(data.response['application-name']));
                assert.equal('string', data.response['access-policy-generated']);
                assert.equal('string', data.response['service-policy']);
                assert.equal('string', data.response['share-service-routes']);
                assert.equal('string', data.response['source-nat']);
                assert.equal('string', data.response['application-type']);
                assert.equal('string', data.response['fqdn-resolution-type']);
                assert.equal('string', data.response.generated);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityService2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityServiceAccessPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityServiceAccessPolicy(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityServiceAccessPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceAccessPolicyAccesspolicyBodyParam = {
      source: 'string',
      permission: 'string'
    };
    describe('#patchConfigServiceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceAccessPolicyAccesspolicy(configConfigStore, configService, configAccesspolicy, configPatchConfigServiceAccessPolicyAccesspolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceAccessPolicyAccesspolicy(configConfigStore, configService, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityServiceAppliesTo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityServiceAppliesTo(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityServiceAppliesTo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceAppliesToAppliestoBodyParam = {
      type: 'string',
      'router-name': [
        'string'
      ],
      'group-name': [
        'string'
      ]
    };
    describe('#patchConfigServiceAppliesToAppliesto - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceAppliesToAppliesto(configConfigStore, configService, configAppliesto, configPatchConfigServiceAppliesToAppliestoBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceAppliesToAppliesto - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceAppliesToAppliesto(configConfigStore, configService, configAppliesto, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.type);
                assert.equal(true, Array.isArray(data.response['router-name']));
                assert.equal(true, Array.isArray(data.response['group-name']));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceMulticastSenderPolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceMulticastSenderPolicy(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceMulticastSenderPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configMulticastsenderpolicy = 'fakedata';
    const configPatchConfigServiceMulticastSenderPolicyMulticastsenderpolicyBodyParam = {
      source: 'string',
      permission: 'string'
    };
    describe('#patchConfigServiceMulticastSenderPolicyMulticastsenderpolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceMulticastSenderPolicyMulticastsenderpolicy(configConfigStore, configService, configMulticastsenderpolicy, configPatchConfigServiceMulticastSenderPolicyMulticastsenderpolicyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceMulticastSenderPolicyMulticastsenderpolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceMulticastSenderPolicyMulticastsenderpolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceMulticastSenderPolicyMulticastsenderpolicy(configConfigStore, configService, configMulticastsenderpolicy, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.source);
                assert.equal('string', data.response.permission);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceMulticastSenderPolicyMulticastsenderpolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityServiceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityServiceTransport(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityServiceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigServiceTransportBodyParam = {
      protocol: 'string'
    };
    describe('#patchConfigServiceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigServiceTransport(configConfigStore, configService, configTransport, configPatchConfigServiceTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigServiceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceTransport(configConfigStore, configService, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigServiceTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigServiceTransportPortRange(configConfigStore, configService, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigServiceTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigTransportPortRangePortrange3BodyParam = {
      'start-port': 10,
      'end-port': 7
    };
    describe('#patchConfigTransportPortRangePortrange3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTransportPortRangePortrange3(configConfigStore, configService, configTransport, configPortrange, configPatchConfigTransportPortRangePortrange3BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTransportPortRangePortrange3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTransportPortRangePortrange3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTransportPortRangePortrange3(configConfigStore, configService, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(5, data.response['start-port']);
                assert.equal(4, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTransportPortRangePortrange3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthoritySessionType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthoritySessionType(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthoritySessionType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthoritySessionTypeSessiontypeBodyParam = {
      name: 'string',
      description: 'string',
      'service-class': 'string',
      timeout: 1,
      'nat-keep-alive': 'string'
    };
    describe('#patchConfigStoreAuthoritySessionTypeSessiontype - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthoritySessionTypeSessiontype(configConfigStore, configSessiontype, configPatchConfigStoreAuthoritySessionTypeSessiontypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthoritySessionTypeSessiontype', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthoritySessionTypeSessiontype - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthoritySessionTypeSessiontype(configConfigStore, configSessiontype, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response['service-class']);
                assert.equal(6, data.response.timeout);
                assert.equal('string', data.response['nat-keep-alive']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthoritySessionTypeSessiontype', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthoritySessionTypeSessiontypeTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthoritySessionTypeSessiontypeTransport(configConfigStore, configSessiontype, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthoritySessionTypeSessiontypeTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigSessionTypeSessiontypeTransportBodyParam = {
      protocol: 'string'
    };
    describe('#patchConfigSessionTypeSessiontypeTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigSessionTypeSessiontypeTransport(configConfigStore, configSessiontype, configTransport, configPatchConfigSessionTypeSessiontypeTransportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigSessionTypeSessiontypeTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSessionTypeSessiontypeTransport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSessionTypeSessiontypeTransport(configConfigStore, configSessiontype, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.protocol);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSessionTypeSessiontypeTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigSessiontypeTransportPortRange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigSessiontypeTransportPortRange(configConfigStore, configSessiontype, configTransport, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigSessiontypeTransportPortRange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigTransportPortRangePortrange4BodyParam = {
      'start-port': 9,
      'end-port': 8
    };
    describe('#patchConfigTransportPortRangePortrange4 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTransportPortRangePortrange4(configConfigStore, configSessiontype, configTransport, configPortrange, configPatchConfigTransportPortRangePortrange4BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTransportPortRangePortrange4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTransportPortRangePortrange4 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTransportPortRangePortrange4(configConfigStore, configSessiontype, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(5, data.response['start-port']);
                assert.equal(8, data.response['end-port']);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTransportPortRangePortrange4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityStepRepo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityStepRepo(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityStepRepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configSteprepo = 'fakedata';
    const configPatchConfigStoreAuthorityStepRepoSteprepoBodyParam = {
      address: 'string',
      description: 'string',
      priority: 9
    };
    describe('#patchConfigStoreAuthorityStepRepoSteprepo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityStepRepoSteprepo(configConfigStore, configSteprepo, configPatchConfigStoreAuthorityStepRepoSteprepoBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityStepRepoSteprepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityStepRepoSteprepo - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityStepRepoSteprepo(configConfigStore, configSteprepo, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.address);
                assert.equal('string', data.response.description);
                assert.equal(1, data.response.priority);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityStepRepoSteprepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityTenant - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityTenant(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigStoreAuthorityTenantBodyParam = {
      name: 'string',
      description: 'string',
      security: 'string',
      address: [
        'string'
      ],
      generated: 'string'
    };
    describe('#patchConfigStoreAuthorityTenant - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityTenant(configConfigStore, configTenant, configPatchConfigStoreAuthorityTenantBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityTenant2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityTenant2(configConfigStore, configTenant, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.security);
                assert.equal(true, Array.isArray(data.response.address));
                assert.equal('string', data.response.generated);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityTenant2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityTenantMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityTenantMember(configConfigStore, configTenant, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityTenantMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigTenantMemberBodyParam = {
      neighborhood: 'string',
      address: [
        'string'
      ]
    };
    describe('#patchConfigTenantMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTenantMember(configConfigStore, configTenant, configMember, configPatchConfigTenantMemberBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTenantMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTenantMember - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTenantMember(configConfigStore, configTenant, configMember, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.neighborhood);
                assert.equal(true, Array.isArray(data.response.address));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTenantMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityTrafficProfile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityTrafficProfile(configConfigStore, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityTrafficProfile', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configTrafficprofile = 'fakedata';
    const configPatchConfigStoreAuthorityTrafficProfileTrafficprofileBodyParam = {
      name: 'string'
    };
    describe('#patchConfigStoreAuthorityTrafficProfileTrafficprofile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigStoreAuthorityTrafficProfileTrafficprofile(configConfigStore, configTrafficprofile, configPatchConfigStoreAuthorityTrafficProfileTrafficprofileBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigStoreAuthorityTrafficProfileTrafficprofile', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigStoreAuthorityTrafficProfileTrafficprofile - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigStoreAuthorityTrafficProfileTrafficprofile(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal('string', data.response.name);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigStoreAuthorityTrafficProfileTrafficprofile', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigTrafficProfileTrafficprofileBestEffortBodyParam = {
      distribution: 3
    };
    describe('#patchConfigTrafficProfileTrafficprofileBestEffort - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigTrafficProfileTrafficprofileBestEffort(configConfigStore, configTrafficprofile, configPatchConfigTrafficProfileTrafficprofileBestEffortBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigTrafficProfileTrafficprofileBestEffort', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigTrafficProfileTrafficprofileBestEffort - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigTrafficProfileTrafficprofileBestEffort(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(3, data.response.distribution);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigTrafficProfileTrafficprofileBestEffort', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityTrafficProfileTrafficprofileHighBodyParam = {
      distribution: 3
    };
    describe('#patchConfigAuthorityTrafficProfileTrafficprofileHigh - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityTrafficProfileTrafficprofileHigh(configConfigStore, configTrafficprofile, configPatchConfigAuthorityTrafficProfileTrafficprofileHighBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityTrafficProfileTrafficprofileHigh', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityTrafficProfileTrafficprofileHigh - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityTrafficProfileTrafficprofileHigh(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(9, data.response.distribution);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityTrafficProfileTrafficprofileHigh', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityTrafficProfileTrafficprofileLowBodyParam = {
      distribution: 5
    };
    describe('#patchConfigAuthorityTrafficProfileTrafficprofileLow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityTrafficProfileTrafficprofileLow(configConfigStore, configTrafficprofile, configPatchConfigAuthorityTrafficProfileTrafficprofileLowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityTrafficProfileTrafficprofileLow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityTrafficProfileTrafficprofileLow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityTrafficProfileTrafficprofileLow(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(6, data.response.distribution);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityTrafficProfileTrafficprofileLow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const configPatchConfigAuthorityTrafficProfileTrafficprofileMediumBodyParam = {
      distribution: 5
    };
    describe('#patchConfigAuthorityTrafficProfileTrafficprofileMedium - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.patchConfigAuthorityTrafficProfileTrafficprofileMedium(configConfigStore, configTrafficprofile, configPatchConfigAuthorityTrafficProfileTrafficprofileMediumBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('success', data.response);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'patchConfigAuthorityTrafficProfileTrafficprofileMedium', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getConfigAuthorityTrafficProfileTrafficprofileMedium - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getConfigAuthorityTrafficProfileTrafficprofileMedium(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response.links);
                assert.equal(2, data.response.distribution);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'getConfigAuthorityTrafficProfileTrafficprofileMedium', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const authenticatePostLoginBodyParam = {
      username: 'string',
      password: 'string'
    };
    describe('#postLogin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postLogin(authenticatePostLoginBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.token);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Authenticate', 'postLogin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const pluginsPostPluginsInstallBodyParam = {
      name: 'string'
    };
    describe('#postPluginsInstall - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postPluginsInstall(pluginsPostPluginsInstallBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Plugins', 'postPluginsInstall', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const pluginsPostPluginsRemoveBodyParam = {
      name: 'string'
    };
    describe('#postPluginsRemove - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.postPluginsRemove(pluginsPostPluginsRemoveBodyParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Plugins', 'postPluginsRemove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getPluginsAvailable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getPluginsAvailable(null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Plugins', 'getPluginsAvailable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getPluginsInstalled - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getPluginsInstalled(null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Plugins', 'getPluginsInstalled', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const routerRouter = 'fakedata';
    const routerPostRouterMetricsBodyParam = {
      id: 'string'
    };
    describe('#postRouterMetrics - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetrics(routerRouter, routerPostRouterMetricsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Router', 'postRouterMetrics', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouter((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Router', 'getRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouter2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouter2(routerRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.location);
                assert.equal('string', data.response.interNodeSecurity);
                assert.equal('string', data.response.reverseFlowEnforcement);
                assert.equal('string', data.response.locationCoordinates);
                assert.equal('string', data.response.role);
                assert.equal(true, data.response.managementConnected);
                assert.equal(true, Array.isArray(data.response.groups));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Router', 'getRouter2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterTopSessions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterTopSessions(routerRouter, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Router', 'getRouterTopSessions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterTopSources - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterTopSources(routerRouter, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Router', 'getRouterTopSources', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const nodeRouter = 'fakedata';
    describe('#getRouterNode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNode(nodeRouter, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Node', 'getRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const nodeNode = 'fakedata';
    describe('#getRouterNode2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNode2(nodeRouter, nodeNode, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.role);
                assert.equal('string', data.response.location);
                assert.equal(true, data.response.enabled);
                assert.equal(2, data.response.traffic);
                assert.equal(10, data.response.averageBandwidth);
                assert.equal(1, data.response.sessions);
                assert.equal(2, data.response.sessionArrivalRate);
                assert.equal('object', typeof data.response.cpu);
                assert.equal(true, Array.isArray(data.response.disk));
                assert.equal('object', typeof data.response.memory);
                assert.equal('object', typeof data.response.platform);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Node', 'getRouterNode2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const adjacencyRouter = 'fakedata';
    const adjacencyNode = 'fakedata';
    describe('#getRouterNodeAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeAdjacency(adjacencyRouter, adjacencyNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Adjacency', 'getRouterNodeAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const adjacencyDeviceInterface = 'fakedata';
    const adjacencyNetworkInterface = 'fakedata';
    describe('#getRouterNetworkInterfaceAdjacency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNetworkInterfaceAdjacency(adjacencyRouter, adjacencyNode, adjacencyDeviceInterface, adjacencyNetworkInterface, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Adjacency', 'getRouterNetworkInterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const deviceInterfaceRouter = 'fakedata';
    const deviceInterfaceNode = 'fakedata';
    describe('#getRouterNodeDeviceInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeDeviceInterface(deviceInterfaceRouter, deviceInterfaceNode, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('DeviceInterface', 'getRouterNodeDeviceInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const networkInterfaceRouter = 'fakedata';
    const networkInterfaceNode = 'fakedata';
    const networkInterfaceDeviceInterface = 'fakedata';
    describe('#getRouterInterfaceDeviceNetwork - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterInterfaceDeviceNetwork(networkInterfaceRouter, networkInterfaceNode, networkInterfaceDeviceInterface, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('NetworkInterface', 'getRouterInterfaceDeviceNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeNetworkInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeNetworkInterface(networkInterfaceRouter, networkInterfaceNode, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('NetworkInterface', 'getRouterNodeNetworkInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNetworkInterfaceByDevice - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNetworkInterfaceByDevice(networkInterfaceRouter, networkInterfaceNode, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('NetworkInterface', 'getRouterNetworkInterfaceByDevice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const summaryRouter = 'fakedata';
    const summaryNode = 'fakedata';
    describe('#getRouterNodeStatus - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeStatus(summaryRouter, summaryNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.softwareVersion);
                assert.equal('string', data.response.startTime);
                assert.equal('string', data.response.status);
                assert.equal('string', data.response.role);
                assert.equal(5, data.response.alarmCount);
                assert.equal(true, Array.isArray(data.response.processes));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Summary', 'getRouterNodeStatus', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeVersion(summaryRouter, summaryNode, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.version);
                assert.equal('string', data.response.buildDate);
                assert.equal('string', data.response.machine);
                assert.equal('string', data.response.user);
                assert.equal('string', data.response.buildDirectory);
                assert.equal('string', data.response.gitHash);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Summary', 'getRouterNodeVersion', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSystem - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getSystem((data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.authority);
                assert.equal('string', data.response.node);
                assert.equal('string', data.response.router);
                assert.equal(true, data.response.isConductor);
                assert.equal('string', data.response.isManaged);
                assert.equal('string', data.response.softwareVersion);
                assert.equal('string', data.response.startTime);
                assert.equal('string', data.response.status);
                assert.equal('string', data.response.role);
                assert.equal(6, data.response.alarmCount);
                assert.equal(true, Array.isArray(data.response.processes));
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Summary', 'getSystem', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const trafficRouter = 'fakedata';
    const trafficNode = 'fakedata';
    describe('#getRouterNodeTrafficFib - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeTrafficFib(trafficRouter, trafficNode, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Traffic', 'getRouterNodeTrafficFib', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeTrafficFlows - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeTrafficFlows(trafficRouter, trafficNode, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Traffic', 'getRouterNodeTrafficFlows', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeTrafficRib - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeTrafficRib(trafficRouter, trafficNode, null, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Traffic', 'getRouterNodeTrafficRib', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRouterNodeTrafficSourceTenant - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterNodeTrafficSourceTenant(trafficRouter, trafficNode, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Traffic', 'getRouterNodeTrafficSourceTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const serviceRoutePolicyRouter = 'fakedata';
    describe('#getRouterServiceRoutePolicy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getRouterServiceRoutePolicy(serviceRoutePolicyRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('ServiceRoutePolicy', 'getRouterServiceRoutePolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsRouter = 'fakedata';
    const statsPostRouterStatsAccessPolicyMeterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsAccessPolicyMeter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAccessPolicyMeter(statsRouter, statsPostRouterStatsAccessPolicyMeterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAccessPolicyMeter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsActiveSourcesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsActiveSources - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsActiveSources(statsRouter, statsPostRouterStatsActiveSourcesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsActiveSources', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionDeviceInterfaceBandwidthBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionDeviceInterfaceBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionDeviceInterfaceBandwidth(statsRouter, statsPostRouterAggregateSessionDeviceInterfaceBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionDeviceInterfaceBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceBandwidthReceived(statsRouter, statsPostRouterSessionDeviceInterfaceBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfaceBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceBandwidthReceivedTcp(statsRouter, statsPostRouterDeviceInterfaceBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDeviceInterfaceBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceBandwidthReceivedUdp(statsRouter, statsPostRouterDeviceInterfaceBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceBandwidthTcp(statsRouter, statsPostRouterSessionDeviceInterfaceBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceBandwidthTransmitted(statsRouter, statsPostRouterSessionDeviceInterfaceBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfaceBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceBandwidthTransmittedTcp(statsRouter, statsPostRouterDeviceInterfaceBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfaceBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceBandwidthTransmittedUdp(statsRouter, statsPostRouterDeviceInterfaceBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceBandwidthUdp(statsRouter, statsPostRouterSessionDeviceInterfaceBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionDeviceInterfacePacketsBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionDeviceInterfacePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionDeviceInterfacePackets(statsRouter, statsPostRouterAggregateSessionDeviceInterfacePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionDeviceInterfacePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfacePacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfacePacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfacePacketsReceived(statsRouter, statsPostRouterSessionDeviceInterfacePacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfacePacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfacePacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfacePacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfacePacketsReceivedTcp(statsRouter, statsPostRouterDeviceInterfacePacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfacePacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfacePacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfacePacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfacePacketsReceivedUdp(statsRouter, statsPostRouterDeviceInterfacePacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfacePacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfacePacketsTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfacePacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfacePacketsTcp(statsRouter, statsPostRouterSessionDeviceInterfacePacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfacePacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfacePacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfacePacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfacePacketsTransmitted(statsRouter, statsPostRouterSessionDeviceInterfacePacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfacePacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfacePacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfacePacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfacePacketsTransmittedTcp(statsRouter, statsPostRouterDeviceInterfacePacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfacePacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfacePacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDeviceInterfacePacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfacePacketsTransmittedUdp(statsRouter, statsPostRouterDeviceInterfacePacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfacePacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfacePacketsUdpBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfacePacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfacePacketsUdp(statsRouter, statsPostRouterSessionDeviceInterfacePacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfacePacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceSessionArrivalRateBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfaceSessionArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceSessionArrivalRate(statsRouter, statsPostRouterDeviceInterfaceSessionArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceSessionArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceCountBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceCount(statsRouter, statsPostRouterSessionDeviceInterfaceCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceSessionDepartureRateBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDeviceInterfaceSessionDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceSessionDepartureRate(statsRouter, statsPostRouterDeviceInterfaceSessionDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceSessionDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionDeviceInterfaceTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionDeviceInterfaceTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionDeviceInterfaceTcpRetransmissions(statsRouter, statsPostRouterSessionDeviceInterfaceTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionDeviceInterfaceTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDeviceInterfaceTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceTcpRetransmissionsReceived(statsRouter, statsPostRouterDeviceInterfaceTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDeviceInterfaceTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'device-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDeviceInterfaceTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDeviceInterfaceTcpRetransmissionsTransmitted(statsRouter, statsPostRouterDeviceInterfaceTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDeviceInterfaceTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNetworkInterfaceBandwidthBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNetworkInterfaceBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNetworkInterfaceBandwidth(statsRouter, statsPostRouterAggregateSessionNetworkInterfaceBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNetworkInterfaceBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceBandwidthReceived(statsRouter, statsPostRouterSessionNetworkInterfaceBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfaceBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceBandwidthReceivedTcp(statsRouter, statsPostRouterNetworkInterfaceBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfaceBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceBandwidthReceivedUdp(statsRouter, statsPostRouterNetworkInterfaceBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceBandwidthTcp(statsRouter, statsPostRouterSessionNetworkInterfaceBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceBandwidthTransmitted(statsRouter, statsPostRouterSessionNetworkInterfaceBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNetworkInterfaceBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceBandwidthTransmittedTcp(statsRouter, statsPostRouterNetworkInterfaceBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNetworkInterfaceBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceBandwidthTransmittedUdp(statsRouter, statsPostRouterNetworkInterfaceBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceBandwidthUdp(statsRouter, statsPostRouterSessionNetworkInterfaceBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNetworkInterfacePacketsBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNetworkInterfacePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNetworkInterfacePackets(statsRouter, statsPostRouterAggregateSessionNetworkInterfacePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNetworkInterfacePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfacePacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfacePacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfacePacketsReceived(statsRouter, statsPostRouterSessionNetworkInterfacePacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfacePacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfacePacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfacePacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfacePacketsReceivedTcp(statsRouter, statsPostRouterNetworkInterfacePacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfacePacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfacePacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfacePacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfacePacketsReceivedUdp(statsRouter, statsPostRouterNetworkInterfacePacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfacePacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfacePacketsTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfacePacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfacePacketsTcp(statsRouter, statsPostRouterSessionNetworkInterfacePacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfacePacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfacePacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfacePacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfacePacketsTransmitted(statsRouter, statsPostRouterSessionNetworkInterfacePacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfacePacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfacePacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfacePacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfacePacketsTransmittedTcp(statsRouter, statsPostRouterNetworkInterfacePacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfacePacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfacePacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNetworkInterfacePacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfacePacketsTransmittedUdp(statsRouter, statsPostRouterNetworkInterfacePacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfacePacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfacePacketsUdpBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfacePacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfacePacketsUdp(statsRouter, statsPostRouterSessionNetworkInterfacePacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfacePacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceSessionArrivalRateBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfaceSessionArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceSessionArrivalRate(statsRouter, statsPostRouterNetworkInterfaceSessionArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceSessionArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceCountBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceCount(statsRouter, statsPostRouterSessionNetworkInterfaceCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceSessionDepartureRateBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfaceSessionDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceSessionDepartureRate(statsRouter, statsPostRouterNetworkInterfaceSessionDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceSessionDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNetworkInterfaceTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNetworkInterfaceTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNetworkInterfaceTcpRetransmissions(statsRouter, statsPostRouterSessionNetworkInterfaceTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNetworkInterfaceTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNetworkInterfaceTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceTcpRetransmissionsReceived(statsRouter, statsPostRouterNetworkInterfaceTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNetworkInterfaceTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNetworkInterfaceTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNetworkInterfaceTcpRetransmissionsTransmitted(statsRouter, statsPostRouterNetworkInterfaceTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNetworkInterfaceTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionNodeBandwidthBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionNodeBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionNodeBandwidth(statsRouter, statsPostRouterStatsAggregateSessionNodeBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionNodeBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeBandwidthReceived(statsRouter, statsPostRouterAggregateSessionNodeBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodeBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeBandwidthReceivedTcp(statsRouter, statsPostRouterSessionNodeBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodeBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeBandwidthReceivedUdp(statsRouter, statsPostRouterSessionNodeBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeBandwidthTcp(statsRouter, statsPostRouterAggregateSessionNodeBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeBandwidthTransmitted(statsRouter, statsPostRouterAggregateSessionNodeBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodeBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeBandwidthTransmittedTcp(statsRouter, statsPostRouterSessionNodeBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNodeBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeBandwidthTransmittedUdp(statsRouter, statsPostRouterSessionNodeBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeBandwidthUdp(statsRouter, statsPostRouterAggregateSessionNodeBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeGrossEntitlementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeGrossEntitlement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeGrossEntitlement(statsRouter, statsPostRouterAggregateSessionNodeGrossEntitlementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeGrossEntitlement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionNodePacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionNodePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionNodePackets(statsRouter, statsPostRouterStatsAggregateSessionNodePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionNodePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodePacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodePacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodePacketsReceived(statsRouter, statsPostRouterAggregateSessionNodePacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodePacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodePacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNodePacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodePacketsReceivedTcp(statsRouter, statsPostRouterSessionNodePacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodePacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodePacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodePacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodePacketsReceivedUdp(statsRouter, statsPostRouterSessionNodePacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodePacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodePacketsTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNodePacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodePacketsTcp(statsRouter, statsPostRouterAggregateSessionNodePacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodePacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodePacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNodePacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodePacketsTransmitted(statsRouter, statsPostRouterAggregateSessionNodePacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodePacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodePacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodePacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodePacketsTransmittedTcp(statsRouter, statsPostRouterSessionNodePacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodePacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodePacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNodePacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodePacketsTransmittedUdp(statsRouter, statsPostRouterSessionNodePacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodePacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodePacketsUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodePacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodePacketsUdp(statsRouter, statsPostRouterAggregateSessionNodePacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodePacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeArrivalRateBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodeArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeArrivalRate(statsRouter, statsPostRouterSessionNodeArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeCountBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeCount(statsRouter, statsPostRouterAggregateSessionNodeCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeDepartureRateBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNodeDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeDepartureRate(statsRouter, statsPostRouterSessionNodeDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionNodeTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionNodeTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionNodeTcpRetransmissions(statsRouter, statsPostRouterAggregateSessionNodeTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionNodeTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionNodeTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeTcpRetransmissionsReceived(statsRouter, statsPostRouterSessionNodeTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionNodeTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionNodeTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionNodeTcpRetransmissionsTransmitted(statsRouter, statsPostRouterSessionNodeTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionNodeTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceClassBandwidthBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceClassBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceClassBandwidth(statsRouter, statsPostRouterAggregateSessionServiceClassBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceClassBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassBandwidthReceived(statsRouter, statsPostRouterSessionServiceClassBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassBandwidthReceivedTcp(statsRouter, statsPostRouterServiceClassBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassBandwidthReceivedUdp(statsRouter, statsPostRouterServiceClassBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceClassBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassBandwidthTcp(statsRouter, statsPostRouterSessionServiceClassBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassBandwidthTransmitted(statsRouter, statsPostRouterSessionServiceClassBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceClassBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassBandwidthTransmittedTcp(statsRouter, statsPostRouterServiceClassBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassBandwidthTransmittedUdp(statsRouter, statsPostRouterServiceClassBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceClassBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassBandwidthUdp(statsRouter, statsPostRouterSessionServiceClassBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceClassPacketsBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceClassPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceClassPackets(statsRouter, statsPostRouterAggregateSessionServiceClassPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceClassPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassPacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassPacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassPacketsReceived(statsRouter, statsPostRouterSessionServiceClassPacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassPacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassPacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassPacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassPacketsReceivedTcp(statsRouter, statsPostRouterServiceClassPacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassPacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassPacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassPacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassPacketsReceivedUdp(statsRouter, statsPostRouterServiceClassPacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassPacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassPacketsTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassPacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassPacketsTcp(statsRouter, statsPostRouterSessionServiceClassPacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassPacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassPacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassPacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassPacketsTransmitted(statsRouter, statsPostRouterSessionServiceClassPacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassPacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassPacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassPacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassPacketsTransmittedTcp(statsRouter, statsPostRouterServiceClassPacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassPacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassPacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceClassPacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassPacketsTransmittedUdp(statsRouter, statsPostRouterServiceClassPacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassPacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassPacketsUdpBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassPacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassPacketsUdp(statsRouter, statsPostRouterSessionServiceClassPacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassPacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassSessionArrivalRateBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceClassSessionArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassSessionArrivalRate(statsRouter, statsPostRouterServiceClassSessionArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassSessionArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassCountBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceClassCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassCount(statsRouter, statsPostRouterSessionServiceClassCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassSessionDepartureRateBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassSessionDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassSessionDepartureRate(statsRouter, statsPostRouterServiceClassSessionDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassSessionDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceClassTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceClassTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceClassTcpRetransmissions(statsRouter, statsPostRouterSessionServiceClassTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceClassTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassTcpRetransmissionsReceived(statsRouter, statsPostRouterServiceClassTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceClassTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceClassTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceClassTcpRetransmissionsTransmitted(statsRouter, statsPostRouterServiceClassTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceClassTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceGroupBandwidthBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceGroupBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceGroupBandwidth(statsRouter, statsPostRouterAggregateSessionServiceGroupBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceGroupBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceGroupBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupBandwidthReceived(statsRouter, statsPostRouterSessionServiceGroupBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceGroupBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupBandwidthReceivedTcp(statsRouter, statsPostRouterServiceGroupBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceGroupBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupBandwidthReceivedUdp(statsRouter, statsPostRouterServiceGroupBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceGroupBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupBandwidthTcp(statsRouter, statsPostRouterSessionServiceGroupBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceGroupBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupBandwidthTransmitted(statsRouter, statsPostRouterSessionServiceGroupBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupBandwidthTransmittedTcp(statsRouter, statsPostRouterServiceGroupBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceGroupBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupBandwidthTransmittedUdp(statsRouter, statsPostRouterServiceGroupBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceGroupBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupBandwidthUdp(statsRouter, statsPostRouterSessionServiceGroupBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceGroupPacketsBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceGroupPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceGroupPackets(statsRouter, statsPostRouterAggregateSessionServiceGroupPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceGroupPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupPacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceGroupPacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupPacketsReceived(statsRouter, statsPostRouterSessionServiceGroupPacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupPacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupPacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceGroupPacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupPacketsReceivedTcp(statsRouter, statsPostRouterServiceGroupPacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupPacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupPacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceGroupPacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupPacketsReceivedUdp(statsRouter, statsPostRouterServiceGroupPacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupPacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupPacketsTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceGroupPacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupPacketsTcp(statsRouter, statsPostRouterSessionServiceGroupPacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupPacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupPacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceGroupPacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupPacketsTransmitted(statsRouter, statsPostRouterSessionServiceGroupPacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupPacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupPacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupPacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupPacketsTransmittedTcp(statsRouter, statsPostRouterServiceGroupPacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupPacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupPacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupPacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupPacketsTransmittedUdp(statsRouter, statsPostRouterServiceGroupPacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupPacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupPacketsUdpBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceGroupPacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupPacketsUdp(statsRouter, statsPostRouterSessionServiceGroupPacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupPacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupSessionArrivalRateBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupSessionArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupSessionArrivalRate(statsRouter, statsPostRouterServiceGroupSessionArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupSessionArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupCountBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceGroupCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupCount(statsRouter, statsPostRouterSessionServiceGroupCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupSessionDepartureRateBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupSessionDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupSessionDepartureRate(statsRouter, statsPostRouterServiceGroupSessionDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupSessionDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceGroupTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceGroupTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceGroupTcpRetransmissions(statsRouter, statsPostRouterSessionServiceGroupTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceGroupTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupTcpRetransmissionsReceived(statsRouter, statsPostRouterServiceGroupTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceGroupTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-group',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceGroupTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceGroupTcpRetransmissionsTransmitted(statsRouter, statsPostRouterServiceGroupTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceGroupTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceRouteBandwidthBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceRouteBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceRouteBandwidth(statsRouter, statsPostRouterAggregateSessionServiceRouteBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceRouteBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRouteBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteBandwidthReceived(statsRouter, statsPostRouterSessionServiceRouteBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRouteBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteBandwidthReceivedTcp(statsRouter, statsPostRouterServiceRouteBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRouteBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteBandwidthReceivedUdp(statsRouter, statsPostRouterServiceRouteBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRouteBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteBandwidthTcp(statsRouter, statsPostRouterSessionServiceRouteBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRouteBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteBandwidthTransmitted(statsRouter, statsPostRouterSessionServiceRouteBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRouteBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteBandwidthTransmittedTcp(statsRouter, statsPostRouterServiceRouteBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRouteBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteBandwidthTransmittedUdp(statsRouter, statsPostRouterServiceRouteBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceRouteBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteBandwidthUdp(statsRouter, statsPostRouterSessionServiceRouteBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceRoutePacketsBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceRoutePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceRoutePackets(statsRouter, statsPostRouterAggregateSessionServiceRoutePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceRoutePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRoutePacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceRoutePacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRoutePacketsReceived(statsRouter, statsPostRouterSessionServiceRoutePacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRoutePacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRoutePacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRoutePacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRoutePacketsReceivedTcp(statsRouter, statsPostRouterServiceRoutePacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRoutePacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRoutePacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRoutePacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRoutePacketsReceivedUdp(statsRouter, statsPostRouterServiceRoutePacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRoutePacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRoutePacketsTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRoutePacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRoutePacketsTcp(statsRouter, statsPostRouterSessionServiceRoutePacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRoutePacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRoutePacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRoutePacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRoutePacketsTransmitted(statsRouter, statsPostRouterSessionServiceRoutePacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRoutePacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRoutePacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRoutePacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRoutePacketsTransmittedTcp(statsRouter, statsPostRouterServiceRoutePacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRoutePacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRoutePacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRoutePacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRoutePacketsTransmittedUdp(statsRouter, statsPostRouterServiceRoutePacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRoutePacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRoutePacketsUdpBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRoutePacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRoutePacketsUdp(statsRouter, statsPostRouterSessionServiceRoutePacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRoutePacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteSessionArrivalRateBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRouteSessionArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteSessionArrivalRate(statsRouter, statsPostRouterServiceRouteSessionArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteSessionArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteCountBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceRouteCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteCount(statsRouter, statsPostRouterSessionServiceRouteCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteSessionDepartureRateBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceRouteSessionDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteSessionDepartureRate(statsRouter, statsPostRouterServiceRouteSessionDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteSessionDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceRouteTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceRouteTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceRouteTcpRetransmissions(statsRouter, statsPostRouterSessionServiceRouteTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceRouteTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRouteTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteTcpRetransmissionsReceived(statsRouter, statsPostRouterServiceRouteTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceRouteTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service-route',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceRouteTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceRouteTcpRetransmissionsTransmitted(statsRouter, statsPostRouterServiceRouteTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceRouteTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionServiceBandwidthBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionServiceBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionServiceBandwidth(statsRouter, statsPostRouterStatsAggregateSessionServiceBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionServiceBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceBandwidthReceived(statsRouter, statsPostRouterAggregateSessionServiceBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceBandwidthReceivedTcp(statsRouter, statsPostRouterSessionServiceBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceBandwidthReceivedUdp(statsRouter, statsPostRouterSessionServiceBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceBandwidthTcp(statsRouter, statsPostRouterAggregateSessionServiceBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceBandwidthTransmitted(statsRouter, statsPostRouterAggregateSessionServiceBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceBandwidthTransmittedTcp(statsRouter, statsPostRouterSessionServiceBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceBandwidthTransmittedUdp(statsRouter, statsPostRouterSessionServiceBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceBandwidthUdp(statsRouter, statsPostRouterAggregateSessionServiceBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionServicePacketsBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionServicePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionServicePackets(statsRouter, statsPostRouterStatsAggregateSessionServicePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionServicePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServicePacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServicePacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServicePacketsReceived(statsRouter, statsPostRouterAggregateSessionServicePacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServicePacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServicePacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServicePacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServicePacketsReceivedTcp(statsRouter, statsPostRouterSessionServicePacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServicePacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServicePacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServicePacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServicePacketsReceivedUdp(statsRouter, statsPostRouterSessionServicePacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServicePacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServicePacketsTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServicePacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServicePacketsTcp(statsRouter, statsPostRouterAggregateSessionServicePacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServicePacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServicePacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServicePacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServicePacketsTransmitted(statsRouter, statsPostRouterAggregateSessionServicePacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServicePacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServicePacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServicePacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServicePacketsTransmittedTcp(statsRouter, statsPostRouterSessionServicePacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServicePacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServicePacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServicePacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServicePacketsTransmittedUdp(statsRouter, statsPostRouterSessionServicePacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServicePacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServicePacketsUdpBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionServicePacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServicePacketsUdp(statsRouter, statsPostRouterAggregateSessionServicePacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServicePacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceArrivalRateBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceArrivalRate(statsRouter, statsPostRouterSessionServiceArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceCountBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceCount(statsRouter, statsPostRouterAggregateSessionServiceCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceDepartureRateBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionServiceDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceDepartureRate(statsRouter, statsPostRouterSessionServiceDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionServiceTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionServiceTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionServiceTcpRetransmissions(statsRouter, statsPostRouterAggregateSessionServiceTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionServiceTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceTcpRetransmissionsReceived(statsRouter, statsPostRouterSessionServiceTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionServiceTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionServiceTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionServiceTcpRetransmissionsTransmitted(statsRouter, statsPostRouterSessionServiceTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionServiceTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionTenantBandwidthBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionTenantBandwidth - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionTenantBandwidth(statsRouter, statsPostRouterStatsAggregateSessionTenantBandwidthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionTenantBandwidth', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantBandwidthReceivedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantBandwidthReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantBandwidthReceived(statsRouter, statsPostRouterAggregateSessionTenantBandwidthReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantBandwidthReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantBandwidthReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantBandwidthReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantBandwidthReceivedTcp(statsRouter, statsPostRouterSessionTenantBandwidthReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantBandwidthReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantBandwidthReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantBandwidthReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantBandwidthReceivedUdp(statsRouter, statsPostRouterSessionTenantBandwidthReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantBandwidthReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantBandwidthTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantBandwidthTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantBandwidthTcp(statsRouter, statsPostRouterAggregateSessionTenantBandwidthTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantBandwidthTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantBandwidthTransmittedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantBandwidthTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantBandwidthTransmitted(statsRouter, statsPostRouterAggregateSessionTenantBandwidthTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantBandwidthTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantBandwidthTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantBandwidthTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantBandwidthTransmittedTcp(statsRouter, statsPostRouterSessionTenantBandwidthTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantBandwidthTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantBandwidthTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantBandwidthTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantBandwidthTransmittedUdp(statsRouter, statsPostRouterSessionTenantBandwidthTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantBandwidthTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantBandwidthUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantBandwidthUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantBandwidthUdp(statsRouter, statsPostRouterAggregateSessionTenantBandwidthUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantBandwidthUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAggregateSessionTenantPacketsBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsAggregateSessionTenantPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAggregateSessionTenantPackets(statsRouter, statsPostRouterStatsAggregateSessionTenantPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAggregateSessionTenantPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantPacketsReceivedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantPacketsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantPacketsReceived(statsRouter, statsPostRouterAggregateSessionTenantPacketsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantPacketsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantPacketsReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantPacketsReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantPacketsReceivedTcp(statsRouter, statsPostRouterSessionTenantPacketsReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantPacketsReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantPacketsReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantPacketsReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantPacketsReceivedUdp(statsRouter, statsPostRouterSessionTenantPacketsReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantPacketsReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantPacketsTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantPacketsTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantPacketsTcp(statsRouter, statsPostRouterAggregateSessionTenantPacketsTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantPacketsTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantPacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantPacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantPacketsTransmitted(statsRouter, statsPostRouterAggregateSessionTenantPacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantPacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantPacketsTransmittedTcpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantPacketsTransmittedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantPacketsTransmittedTcp(statsRouter, statsPostRouterSessionTenantPacketsTransmittedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantPacketsTransmittedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantPacketsTransmittedUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantPacketsTransmittedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantPacketsTransmittedUdp(statsRouter, statsPostRouterSessionTenantPacketsTransmittedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantPacketsTransmittedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantPacketsUdpBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantPacketsUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantPacketsUdp(statsRouter, statsPostRouterAggregateSessionTenantPacketsUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantPacketsUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantArrivalRateBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantArrivalRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantArrivalRate(statsRouter, statsPostRouterSessionTenantArrivalRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantArrivalRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantCountBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantCount - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantCount(statsRouter, statsPostRouterAggregateSessionTenantCountBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantCount', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantDepartureRateBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionTenantDepartureRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantDepartureRate(statsRouter, statsPostRouterSessionTenantDepartureRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantDepartureRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAggregateSessionTenantTcpRetransmissionsBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAggregateSessionTenantTcpRetransmissions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAggregateSessionTenantTcpRetransmissions(statsRouter, statsPostRouterAggregateSessionTenantTcpRetransmissionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAggregateSessionTenantTcpRetransmissions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantTcpRetransmissionsReceivedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantTcpRetransmissionsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantTcpRetransmissionsReceived(statsRouter, statsPostRouterSessionTenantTcpRetransmissionsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantTcpRetransmissionsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionTenantTcpRetransmissionsTransmittedBodyParam = {
      parameters: [
        {
          name: 'tenant',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionTenantTcpRetransmissionsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionTenantTcpRetransmissionsTransmitted(statsRouter, statsPostRouterSessionTenantTcpRetransmissionsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionTenantTcpRetransmissionsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAppIdRefreshesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAppIdRefreshes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAppIdRefreshes(statsRouter, statsPostRouterStatsAppIdRefreshesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAppIdRefreshes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsAppIdRetriesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsAppIdRetries - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsAppIdRetries(statsRouter, statsPostRouterStatsAppIdRetriesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsAppIdRetries', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsApplicationFrameworkInitBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsApplicationFrameworkInit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsApplicationFrameworkInit(statsRouter, statsPostRouterStatsApplicationFrameworkInitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsApplicationFrameworkInit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsApplicationFrameworkShutdownBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsApplicationFrameworkShutdown - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsApplicationFrameworkShutdown(statsRouter, statsPostRouterStatsApplicationFrameworkShutdownBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsApplicationFrameworkShutdown', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsApplicationFrameworkStartBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsApplicationFrameworkStart - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsApplicationFrameworkStart(statsRouter, statsPostRouterStatsApplicationFrameworkStartBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsApplicationFrameworkStart', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsApplicationFrameworkStateBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsApplicationFrameworkState - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsApplicationFrameworkState(statsRouter, statsPostRouterStatsApplicationFrameworkStateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsApplicationFrameworkState', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsApplicationFrameworkStopBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsApplicationFrameworkStop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsApplicationFrameworkStop(statsRouter, statsPostRouterStatsApplicationFrameworkStopBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsApplicationFrameworkStop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpEncapsulationSentFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpEncapsulationSentFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpEncapsulationSentFailure(statsRouter, statsPostRouterArpEncapsulationSentFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpEncapsulationSentFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpEncapsulationSentSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpEncapsulationSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpEncapsulationSentSuccess(statsRouter, statsPostRouterArpEncapsulationSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpEncapsulationSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpEntriesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsArpEntries - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpEntries(statsRouter, statsPostRouterStatsArpEntriesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpEntries', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpQueuedFailureDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpQueuedFailureDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpQueuedFailureDrop(statsRouter, statsPostRouterArpQueuedFailureDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpQueuedFailureDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpQueuedFailureQueueFullBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpQueuedFailureQueueFull - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpQueuedFailureQueueFull(statsRouter, statsPostRouterArpQueuedFailureQueueFullBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpQueuedFailureQueueFull', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpQueuedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsArpQueuedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpQueuedPackets(statsRouter, statsPostRouterStatsArpQueuedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpQueuedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpReceivedReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsArpReceivedReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpReceivedReply(statsRouter, statsPostRouterStatsArpReceivedReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpReceivedReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpReceivedRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsArpReceivedRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpReceivedRequest(statsRouter, statsPostRouterStatsArpReceivedRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpReceivedRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsReply(statsRouter, statsPostRouterArpReceivedErrorsReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsRequest(statsRouter, statsPostRouterArpReceivedErrorsRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsNeighborAdvertisement(statsRouter, statsPostRouterArpReceivedErrorsNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsNeighborSolicitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsNeighborSolicit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsNeighborSolicit(statsRouter, statsPostRouterArpReceivedErrorsNeighborSolicitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsNeighborSolicit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsProcessingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsProcessing - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsProcessing(statsRouter, statsPostRouterArpReceivedErrorsProcessingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsProcessing', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedErrorsUnknownTypeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedErrorsUnknownType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedErrorsUnknownType(statsRouter, statsPostRouterArpReceivedErrorsUnknownTypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedErrorsUnknownType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpReceivedGratuitousBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsArpReceivedGratuitous - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpReceivedGratuitous(statsRouter, statsPostRouterStatsArpReceivedGratuitousBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpReceivedGratuitous', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpReceivedNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsArpReceivedNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpReceivedNeighborAdvertisement(statsRouter, statsPostRouterStatsArpReceivedNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpReceivedNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsArpReceivedNeighborSolicitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsArpReceivedNeighborSolicit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsArpReceivedNeighborSolicit(statsRouter, statsPostRouterStatsArpReceivedNeighborSolicitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsArpReceivedNeighborSolicit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedOffSubnetArpRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedOffSubnetArpRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedOffSubnetArpRequest(statsRouter, statsPostRouterReceivedOffSubnetArpRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedOffSubnetArpRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedOffSubnetNeighborSolicitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedOffSubnetNeighborSolicit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedOffSubnetNeighborSolicit(statsRouter, statsPostRouterReceivedOffSubnetNeighborSolicitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedOffSubnetNeighborSolicit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpReceivedUnsolicitedNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpReceivedUnsolicitedNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpReceivedUnsolicitedNeighborAdvertisement(statsRouter, statsPostRouterArpReceivedUnsolicitedNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpReceivedUnsolicitedNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureAllocationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureAllocation(statsRouter, statsPostRouterArpSentFailureAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureReply(statsRouter, statsPostRouterArpSentFailureReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureRequest(statsRouter, statsPostRouterArpSentFailureRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureGratuitousBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureGratuitous - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureGratuitous(statsRouter, statsPostRouterArpSentFailureGratuitousBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureGratuitous', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentFailureMulticastListenerReportBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentFailureMulticastListenerReport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentFailureMulticastListenerReport(statsRouter, statsPostRouterSentFailureMulticastListenerReportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentFailureMulticastListenerReport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureNeighborAdvertisement(statsRouter, statsPostRouterArpSentFailureNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureNeighborSolicitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpSentFailureNeighborSolicit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureNeighborSolicit(statsRouter, statsPostRouterArpSentFailureNeighborSolicitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureNeighborSolicit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentFailureStandbyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentFailureStandby - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentFailureStandby(statsRouter, statsPostRouterArpSentFailureStandbyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentFailureStandby', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentFailureUnsolicitedNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentFailureUnsolicitedNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentFailureUnsolicitedNeighborAdvertisement(statsRouter, statsPostRouterSentFailureUnsolicitedNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentFailureUnsolicitedNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentSuccessReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpSentSuccessReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentSuccessReply(statsRouter, statsPostRouterArpSentSuccessReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentSuccessReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentSuccessRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentSuccessRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentSuccessRequest(statsRouter, statsPostRouterArpSentSuccessRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentSuccessRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentSuccessGratuitousBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterArpSentSuccessGratuitous - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentSuccessGratuitous(statsRouter, statsPostRouterArpSentSuccessGratuitousBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentSuccessGratuitous', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentSuccessInSubnetProxyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentSuccessInSubnetProxy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentSuccessInSubnetProxy(statsRouter, statsPostRouterSentSuccessInSubnetProxyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentSuccessInSubnetProxy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentSuccessMulticastListenerReportBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentSuccessMulticastListenerReport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentSuccessMulticastListenerReport(statsRouter, statsPostRouterSentSuccessMulticastListenerReportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentSuccessMulticastListenerReport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentSuccessNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpSentSuccessNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentSuccessNeighborAdvertisement(statsRouter, statsPostRouterArpSentSuccessNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentSuccessNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterArpSentSuccessNeighborSolicitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterArpSentSuccessNeighborSolicit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterArpSentSuccessNeighborSolicit(statsRouter, statsPostRouterArpSentSuccessNeighborSolicitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterArpSentSuccessNeighborSolicit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentSuccessOffSubnetProxyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentSuccessOffSubnetProxy - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentSuccessOffSubnetProxy(statsRouter, statsPostRouterSentSuccessOffSubnetProxyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentSuccessOffSubnetProxy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentSuccessUnsolicitedNeighborAdvertisementBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentSuccessUnsolicitedNeighborAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentSuccessUnsolicitedNeighborAdvertisement(statsRouter, statsPostRouterSentSuccessUnsolicitedNeighborAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentSuccessUnsolicitedNeighborAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdAsyncReceivedMissBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdAsyncReceivedMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdAsyncReceivedMiss(statsRouter, statsPostRouterBfdAsyncReceivedMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdAsyncReceivedMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdAsyncReceivedSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterBfdAsyncReceivedSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdAsyncReceivedSuccess(statsRouter, statsPostRouterBfdAsyncReceivedSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdAsyncReceivedSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdAsyncSentArpFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterBfdAsyncSentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdAsyncSentArpFailure(statsRouter, statsPostRouterBfdAsyncSentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdAsyncSentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAsyncSentBufferAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAsyncSentBufferAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAsyncSentBufferAllocationFailure(statsRouter, statsPostRouterAsyncSentBufferAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAsyncSentBufferAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdAsyncSentSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdAsyncSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdAsyncSentSuccess(statsRouter, statsPostRouterBfdAsyncSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdAsyncSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdEchoReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdEchoReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdEchoReceived(statsRouter, statsPostRouterStatsBfdEchoReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdEchoReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdEchoSentArpFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdEchoSentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdEchoSentArpFailure(statsRouter, statsPostRouterBfdEchoSentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdEchoSentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEchoSentBufferAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEchoSentBufferAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEchoSentBufferAllocationFailure(statsRouter, statsPostRouterEchoSentBufferAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEchoSentBufferAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdEchoSentSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdEchoSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdEchoSentSuccess(statsRouter, statsPostRouterBfdEchoSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdEchoSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLinkDownLocalOperBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLinkDownLocalOper - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLinkDownLocalOper(statsRouter, statsPostRouterLinkDownLocalOperBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLinkDownLocalOper', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLinkDownRemoteAdminBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLinkDownRemoteAdmin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLinkDownRemoteAdmin(statsRouter, statsPostRouterLinkDownRemoteAdminBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLinkDownRemoteAdmin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdLinkDownRemoteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdLinkDownRemote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdLinkDownRemote(statsRouter, statsPostRouterBfdLinkDownRemoteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdLinkDownRemote', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdLinkDownTimerExpiryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterBfdLinkDownTimerExpiry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdLinkDownTimerExpiry(statsRouter, statsPostRouterBfdLinkDownTimerExpiryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdLinkDownTimerExpiry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdLinkUpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsBfdLinkUp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdLinkUp(statsRouter, statsPostRouterStatsBfdLinkUpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdLinkUp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdLocalSourceNatChangeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdLocalSourceNatChange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdLocalSourceNatChange(statsRouter, statsPostRouterBfdLocalSourceNatChangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdLocalSourceNatChange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdNeighborFailoverBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsBfdNeighborFailover - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdNeighborFailover(statsRouter, statsPostRouterStatsBfdNeighborFailoverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdNeighborFailover', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdNeighborSourceNatChangeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdNeighborSourceNatChange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdNeighborSourceNatChange(statsRouter, statsPostRouterBfdNeighborSourceNatChangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdNeighborSourceNatChange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerPathAsyncReceivedMissBodyParam = {
      parameters: [
        {
          name: 'peer-host',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPeerPathAsyncReceivedMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerPathAsyncReceivedMiss(statsRouter, statsPostRouterPeerPathAsyncReceivedMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerPathAsyncReceivedMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerPathAsyncReceivedSuccessBodyParam = {
      parameters: [
        {
          name: 'vlan',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPeerPathAsyncReceivedSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerPathAsyncReceivedSuccess(statsRouter, statsPostRouterPeerPathAsyncReceivedSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerPathAsyncReceivedSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathAsyncSentArpFailureBodyParam = {
      parameters: [
        {
          name: 'device-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathAsyncSentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathAsyncSentArpFailure(statsRouter, statsPostRouterPathAsyncSentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathAsyncSentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAsyncSentBufferAllocationFailure2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAsyncSentBufferAllocationFailure2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAsyncSentBufferAllocationFailure2(statsRouter, statsPostRouterAsyncSentBufferAllocationFailure2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAsyncSentBufferAllocationFailure2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerPathAsyncSentSuccessBodyParam = {
      parameters: [
        {
          name: 'peer-host',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPeerPathAsyncSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerPathAsyncSentSuccess(statsRouter, statsPostRouterPeerPathAsyncSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerPathAsyncSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdPeerPathEchoReceivedBodyParam = {
      parameters: [
        {
          name: 'device-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdPeerPathEchoReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdPeerPathEchoReceived(statsRouter, statsPostRouterBfdPeerPathEchoReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdPeerPathEchoReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathEchoSentArpFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathEchoSentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathEchoSentArpFailure(statsRouter, statsPostRouterPathEchoSentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathEchoSentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEchoSentBufferAllocationFailure2BodyParam = {
      parameters: [
        {
          name: 'device-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEchoSentBufferAllocationFailure2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEchoSentBufferAllocationFailure2(statsRouter, statsPostRouterEchoSentBufferAllocationFailure2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEchoSentBufferAllocationFailure2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerPathEchoSentSuccessBodyParam = {
      parameters: [
        {
          name: 'peer-host',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPeerPathEchoSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerPathEchoSentSuccess(statsRouter, statsPostRouterPeerPathEchoSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerPathEchoSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdPeerPathJitterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdPeerPathJitter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdPeerPathJitter(statsRouter, statsPostRouterStatsBfdPeerPathJitterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdPeerPathJitter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdPeerPathLatencyBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsBfdPeerPathLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdPeerPathLatency(statsRouter, statsPostRouterStatsBfdPeerPathLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdPeerPathLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLinkDownLocalOper2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLinkDownLocalOper2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLinkDownLocalOper2(statsRouter, statsPostRouterLinkDownLocalOper2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLinkDownLocalOper2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLinkDownRemoteAdmin2BodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLinkDownRemoteAdmin2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLinkDownRemoteAdmin2(statsRouter, statsPostRouterLinkDownRemoteAdmin2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLinkDownRemoteAdmin2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathLinkDownRemoteBodyParam = {
      parameters: [
        {
          name: 'peer-host',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathLinkDownRemote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathLinkDownRemote(statsRouter, statsPostRouterPathLinkDownRemoteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathLinkDownRemote', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathLinkDownTimerExpiryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathLinkDownTimerExpiry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathLinkDownTimerExpiry(statsRouter, statsPostRouterPathLinkDownTimerExpiryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathLinkDownTimerExpiry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdPeerPathLinkUpBodyParam = {
      parameters: [
        {
          name: 'vlan',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdPeerPathLinkUp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdPeerPathLinkUp(statsRouter, statsPostRouterBfdPeerPathLinkUpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdPeerPathLinkUp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathLocalSourceNatChangeBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathLocalSourceNatChange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathLocalSourceNatChange(statsRouter, statsPostRouterPathLocalSourceNatChangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathLocalSourceNatChange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdPeerPathLossBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsBfdPeerPathLoss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdPeerPathLoss(statsRouter, statsPostRouterStatsBfdPeerPathLossBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdPeerPathLoss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdPeerPathMosBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdPeerPathMos - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdPeerPathMos(statsRouter, statsPostRouterStatsBfdPeerPathMosBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdPeerPathMos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdPeerPathNeighborFailoverBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterBfdPeerPathNeighborFailover - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdPeerPathNeighborFailover(statsRouter, statsPostRouterBfdPeerPathNeighborFailoverBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdPeerPathNeighborFailover', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathNeighborSourceNatChangeBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathNeighborSourceNatChange - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathNeighborSourceNatChange(statsRouter, statsPostRouterPathNeighborSourceNatChangeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathNeighborSourceNatChange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidAuthenticationFieldBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidAuthenticationField - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidAuthenticationField(statsRouter, statsPostRouterBfdReceivedInvalidAuthenticationFieldBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidAuthenticationField', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidDetectMultipleBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidDetectMultiple - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidDetectMultiple(statsRouter, statsPostRouterBfdReceivedInvalidDetectMultipleBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidDetectMultiple', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdReceivedInvalidDiscriminatorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdReceivedInvalidDiscriminator - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdReceivedInvalidDiscriminator(statsRouter, statsPostRouterStatsBfdReceivedInvalidDiscriminatorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdReceivedInvalidDiscriminator', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidHeaderLargeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidHeaderLarge - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidHeaderLarge(statsRouter, statsPostRouterBfdReceivedInvalidHeaderLargeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidHeaderLarge', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidHeaderSmallBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidHeaderSmall - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidHeaderSmall(statsRouter, statsPostRouterBfdReceivedInvalidHeaderSmallBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidHeaderSmall', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidHeaderVersionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidHeaderVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidHeaderVersion(statsRouter, statsPostRouterBfdReceivedInvalidHeaderVersionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidHeaderVersion', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidLocalDiscriminatorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidLocalDiscriminator - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidLocalDiscriminator(statsRouter, statsPostRouterBfdReceivedInvalidLocalDiscriminatorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidLocalDiscriminator', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdReceivedInvalidMetadataBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdReceivedInvalidMetadata - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdReceivedInvalidMetadata(statsRouter, statsPostRouterStatsBfdReceivedInvalidMetadataBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdReceivedInvalidMetadata', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidPacketLengthBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidPacketLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidPacketLength(statsRouter, statsPostRouterBfdReceivedInvalidPacketLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidPacketLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterBfdReceivedInvalidPayloadSmallBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterBfdReceivedInvalidPayloadSmall - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterBfdReceivedInvalidPayloadSmall(statsRouter, statsPostRouterBfdReceivedInvalidPayloadSmallBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterBfdReceivedInvalidPayloadSmall', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsBfdReceivedInvalidSessionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsBfdReceivedInvalidSession - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsBfdReceivedInvalidSession(statsRouter, statsPostRouterStatsBfdReceivedInvalidSessionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsBfdReceivedInvalidSession', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsConfigCacheHitsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsConfigCacheHits - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsConfigCacheHits(statsRouter, statsPostRouterStatsConfigCacheHitsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsConfigCacheHits', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsConfigCacheMissesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsConfigCacheMisses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsConfigCacheMisses(statsRouter, statsPostRouterStatsConfigCacheMissesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsConfigCacheMisses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsConfluxBatchesLatencyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsConfluxBatchesLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsConfluxBatchesLatency(statsRouter, statsPostRouterStatsConfluxBatchesLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsConfluxBatchesLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxBatchesWriteDurationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxBatchesWriteDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxBatchesWriteDuration(statsRouter, statsPostRouterConfluxBatchesWriteDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxBatchesWriteDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxBatchesWriteFailureBodyParam = {
      parameters: [
        {
          name: 'pipeline',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxBatchesWriteFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxBatchesWriteFailure(statsRouter, statsPostRouterConfluxBatchesWriteFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxBatchesWriteFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxBatchesWriteSuccessBodyParam = {
      parameters: [
        {
          name: 'pipeline',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxBatchesWriteSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxBatchesWriteSuccess(statsRouter, statsPostRouterConfluxBatchesWriteSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxBatchesWriteSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsConfluxGapsDetectedBodyParam = {
      parameters: [
        {
          name: 'pipeline',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsConfluxGapsDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsConfluxGapsDetected(statsRouter, statsPostRouterStatsConfluxGapsDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsConfluxGapsDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxGapsResolutionRetryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxGapsResolutionRetry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxGapsResolutionRetry(statsRouter, statsPostRouterConfluxGapsResolutionRetryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxGapsResolutionRetry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxGapsResolutionSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxGapsResolutionSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxGapsResolutionSuccess(statsRouter, statsPostRouterConfluxGapsResolutionSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxGapsResolutionSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsConfluxMessagesReadBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsConfluxMessagesRead - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsConfluxMessagesRead(statsRouter, statsPostRouterStatsConfluxMessagesReadBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsConfluxMessagesRead', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxMessagesWriteFailureBodyParam = {
      parameters: [
        {
          name: 'source',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxMessagesWriteFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxMessagesWriteFailure(statsRouter, statsPostRouterConfluxMessagesWriteFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxMessagesWriteFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterConfluxMessagesWriteSuccessBodyParam = {
      parameters: [
        {
          name: 'pipeline',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterConfluxMessagesWriteSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterConfluxMessagesWriteSuccess(statsRouter, statsPostRouterConfluxMessagesWriteSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterConfluxMessagesWriteSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsCpuUtilizationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsCpuUtilization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsCpuUtilization(statsRouter, statsPostRouterStatsCpuUtilizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsCpuUtilization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDatabaseMemoryConsumedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsDatabaseMemoryConsumed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDatabaseMemoryConsumed(statsRouter, statsPostRouterStatsDatabaseMemoryConsumedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDatabaseMemoryConsumed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDeviceInterfaceMessageFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsDeviceInterfaceMessageFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDeviceInterfaceMessageFailure(statsRouter, statsPostRouterStatsDeviceInterfaceMessageFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDeviceInterfaceMessageFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDeviceInterfaceMessageSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsDeviceInterfaceMessageSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDeviceInterfaceMessageSuccess(statsRouter, statsPostRouterStatsDeviceInterfaceMessageSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDeviceInterfaceMessageSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDiskCapacityBodyParam = {
      parameters: [
        {
          name: 'disk',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsDiskCapacity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDiskCapacity(statsRouter, statsPostRouterStatsDiskCapacityBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDiskCapacity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDiskComponentBodyParam = {
      parameters: [
        {
          name: 'component',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsDiskComponent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDiskComponent(statsRouter, statsPostRouterStatsDiskComponentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDiskComponent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsDiskUsedBodyParam = {
      parameters: [
        {
          name: 'disk',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsDiskUsed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsDiskUsed(statsRouter, statsPostRouterStatsDiskUsedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsDiskUsed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiParsedFailureTlsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDpiParsedFailureTls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiParsedFailureTls(statsRouter, statsPostRouterDpiParsedFailureTlsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiParsedFailureTls', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiParsedSuccessTlsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDpiParsedSuccessTls - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiParsedSuccessTls(statsRouter, statsPostRouterDpiParsedSuccessTlsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiParsedSuccessTls', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiReceivedFailureCapacityExceededBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDpiReceivedFailureCapacityExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiReceivedFailureCapacityExceeded(statsRouter, statsPostRouterDpiReceivedFailureCapacityExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiReceivedFailureCapacityExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedFailureTooManySegmentsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedFailureTooManySegments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedFailureTooManySegments(statsRouter, statsPostRouterReceivedFailureTooManySegmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedFailureTooManySegments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiReceivedSuccessAddBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDpiReceivedSuccessAdd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiReceivedSuccessAdd(statsRouter, statsPostRouterDpiReceivedSuccessAddBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiReceivedSuccessAdd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiReceivedSuccessDuplicateBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDpiReceivedSuccessDuplicate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiReceivedSuccessDuplicate(statsRouter, statsPostRouterDpiReceivedSuccessDuplicateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiReceivedSuccessDuplicate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedSuccessReadyToParseBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedSuccessReadyToParse - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedSuccessReadyToParse(statsRouter, statsPostRouterReceivedSuccessReadyToParseBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedSuccessReadyToParse', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateConnectionFirstConductorConnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterUpdateConnectionFirstConductorConnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateConnectionFirstConductorConnect(statsRouter, statsPostRouterUpdateConnectionFirstConductorConnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateConnectionFirstConductorConnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateConnectionFirstServerConnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterUpdateConnectionFirstServerConnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateConnectionFirstServerConnect(statsRouter, statsPostRouterUpdateConnectionFirstServerConnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateConnectionFirstServerConnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateConnectionLastConductorDisconnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateConnectionLastConductorDisconnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateConnectionLastConductorDisconnect(statsRouter, statsPostRouterUpdateConnectionLastConductorDisconnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateConnectionLastConductorDisconnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDynamicPeerUpdateLeadershipLostBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDynamicPeerUpdateLeadershipLost - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDynamicPeerUpdateLeadershipLost(statsRouter, statsPostRouterDynamicPeerUpdateLeadershipLostBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDynamicPeerUpdateLeadershipLost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDynamicPeerUpdateLeadershipWonBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDynamicPeerUpdateLeadershipWon - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDynamicPeerUpdateLeadershipWon(statsRouter, statsPostRouterDynamicPeerUpdateLeadershipWonBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDynamicPeerUpdateLeadershipWon', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerUpdateRequestsReceivedPushBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPeerUpdateRequestsReceivedPush - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerUpdateRequestsReceivedPush(statsRouter, statsPostRouterPeerUpdateRequestsReceivedPushBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerUpdateRequestsReceivedPush', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerUpdateRequestsReceivedSyncBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPeerUpdateRequestsReceivedSync - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerUpdateRequestsReceivedSync(statsRouter, statsPostRouterPeerUpdateRequestsReceivedSyncBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerUpdateRequestsReceivedSync', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRequestsReceivedSyncPeerAddressesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRequestsReceivedSyncPeerAddresses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRequestsReceivedSyncPeerAddresses(statsRouter, statsPostRouterRequestsReceivedSyncPeerAddressesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRequestsReceivedSyncPeerAddresses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerUpdateRequestsSentPushBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPeerUpdateRequestsSentPush - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerUpdateRequestsSentPush(statsRouter, statsPostRouterPeerUpdateRequestsSentPushBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerUpdateRequestsSentPush', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerUpdateRequestsSentSyncBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPeerUpdateRequestsSentSync - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerUpdateRequestsSentSync(statsRouter, statsPostRouterPeerUpdateRequestsSentSyncBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerUpdateRequestsSentSync', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateResponsesReceivedNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateResponsesReceivedNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateResponsesReceivedNotFound(statsRouter, statsPostRouterUpdateResponsesReceivedNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateResponsesReceivedNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateResponsesReceivedOtherFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateResponsesReceivedOtherFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateResponsesReceivedOtherFailure(statsRouter, statsPostRouterUpdateResponsesReceivedOtherFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateResponsesReceivedOtherFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerUpdateResponsesReceivedSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPeerUpdateResponsesReceivedSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerUpdateResponsesReceivedSuccess(statsRouter, statsPostRouterPeerUpdateResponsesReceivedSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerUpdateResponsesReceivedSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateResponsesReceivedTimeOutBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateResponsesReceivedTimeOut - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateResponsesReceivedTimeOut(statsRouter, statsPostRouterUpdateResponsesReceivedTimeOutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateResponsesReceivedTimeOut', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentChannelMessagesReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentChannelMessagesReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentChannelMessagesReceived(statsRouter, statsPostRouterProtocolsAgentChannelMessagesReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentChannelMessagesReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentChannelMessagesSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProtocolsAgentChannelMessagesSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentChannelMessagesSent(statsRouter, statsPostRouterProtocolsAgentChannelMessagesSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentChannelMessagesSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterErrorsBgpOverSvrDropsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterErrorsBgpOverSvrDrops - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterErrorsBgpOverSvrDrops(statsRouter, statsPostRouterErrorsBgpOverSvrDropsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterErrorsBgpOverSvrDrops', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsClassifyDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsClassifyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsClassifyDrop(statsRouter, statsPostRouterProtocolsAgentErrorsClassifyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsClassifyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsEarlyInboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsEarlyInbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsEarlyInbound(statsRouter, statsPostRouterProtocolsAgentErrorsEarlyInboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsEarlyInbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsEarlyOutboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsEarlyOutbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsEarlyOutbound(statsRouter, statsPostRouterProtocolsAgentErrorsEarlyOutboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsEarlyOutbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterErrorsFastlaneNotReadyDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterErrorsFastlaneNotReadyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterErrorsFastlaneNotReadyDrop(statsRouter, statsPostRouterErrorsFastlaneNotReadyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterErrorsFastlaneNotReadyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterErrorsGlobalInterfaceLookupDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterErrorsGlobalInterfaceLookupDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterErrorsGlobalInterfaceLookupDrop(statsRouter, statsPostRouterErrorsGlobalInterfaceLookupDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterErrorsGlobalInterfaceLookupDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAgentErrorsIllegalEthernetDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAgentErrorsIllegalEthernetDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAgentErrorsIllegalEthernetDrop(statsRouter, statsPostRouterAgentErrorsIllegalEthernetDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAgentErrorsIllegalEthernetDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIllegalExternalProtocolsChannelMessageBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIllegalExternalProtocolsChannelMessage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIllegalExternalProtocolsChannelMessage(statsRouter, statsPostRouterIllegalExternalProtocolsChannelMessageBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIllegalExternalProtocolsChannelMessage', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAgentErrorsIllegalIpDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAgentErrorsIllegalIpDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAgentErrorsIllegalIpDrop(statsRouter, statsPostRouterAgentErrorsIllegalIpDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAgentErrorsIllegalIpDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsInboundDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsInboundDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsInboundDrop(statsRouter, statsPostRouterProtocolsAgentErrorsInboundDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsInboundDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInboundFromInternalInterfaceDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterInboundFromInternalInterfaceDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInboundFromInternalInterfaceDrop(statsRouter, statsPostRouterInboundFromInternalInterfaceDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInboundFromInternalInterfaceDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsOutboundDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsOutboundDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsOutboundDrop(statsRouter, statsPostRouterProtocolsAgentErrorsOutboundDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsOutboundDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterOutboundL2ResolutionReplyDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterOutboundL2ResolutionReplyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterOutboundL2ResolutionReplyDrop(statsRouter, statsPostRouterOutboundL2ResolutionReplyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterOutboundL2ResolutionReplyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsAgentErrorsSessionCollisionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsAgentErrorsSessionCollision - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsAgentErrorsSessionCollision(statsRouter, statsPostRouterProtocolsAgentErrorsSessionCollisionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsAgentErrorsSessionCollision', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterExternalProtocolsAgentPacketsInboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterExternalProtocolsAgentPacketsInbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterExternalProtocolsAgentPacketsInbound(statsRouter, statsPostRouterExternalProtocolsAgentPacketsInboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterExternalProtocolsAgentPacketsInbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterExternalProtocolsAgentPacketsOutboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterExternalProtocolsAgentPacketsOutbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterExternalProtocolsAgentPacketsOutbound(statsRouter, statsPostRouterExternalProtocolsAgentPacketsOutboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterExternalProtocolsAgentPacketsOutbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAgentPacketsSecureVectorRoutedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAgentPacketsSecureVectorRouted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAgentPacketsSecureVectorRouted(statsRouter, statsPostRouterAgentPacketsSecureVectorRoutedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAgentPacketsSecureVectorRouted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerChannelMessagesReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsManagerChannelMessagesReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerChannelMessagesReceived(statsRouter, statsPostRouterProtocolsManagerChannelMessagesReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerChannelMessagesReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerChannelMessagesSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProtocolsManagerChannelMessagesSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerChannelMessagesSent(statsRouter, statsPostRouterProtocolsManagerChannelMessagesSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerChannelMessagesSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerErrorsEarlyInboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsManagerErrorsEarlyInbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerErrorsEarlyInbound(statsRouter, statsPostRouterProtocolsManagerErrorsEarlyInboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerErrorsEarlyInbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerErrorsEarlyOutboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProtocolsManagerErrorsEarlyOutbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerErrorsEarlyOutbound(statsRouter, statsPostRouterProtocolsManagerErrorsEarlyOutboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerErrorsEarlyOutbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIllegalExternalProtocolsChannelMessage2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterIllegalExternalProtocolsChannelMessage2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIllegalExternalProtocolsChannelMessage2(statsRouter, statsPostRouterIllegalExternalProtocolsChannelMessage2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIllegalExternalProtocolsChannelMessage2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerErrorsInboundDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProtocolsManagerErrorsInboundDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerErrorsInboundDrop(statsRouter, statsPostRouterProtocolsManagerErrorsInboundDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerErrorsInboundDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProtocolsManagerErrorsOutboundDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProtocolsManagerErrorsOutboundDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProtocolsManagerErrorsOutboundDrop(statsRouter, statsPostRouterProtocolsManagerErrorsOutboundDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProtocolsManagerErrorsOutboundDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterExternalProtocolsManagerPacketsInboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterExternalProtocolsManagerPacketsInbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterExternalProtocolsManagerPacketsInbound(statsRouter, statsPostRouterExternalProtocolsManagerPacketsInboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterExternalProtocolsManagerPacketsInbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterExternalProtocolsManagerPacketsOutboundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterExternalProtocolsManagerPacketsOutbound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterExternalProtocolsManagerPacketsOutbound(statsRouter, statsPostRouterExternalProtocolsManagerPacketsOutboundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterExternalProtocolsManagerPacketsOutbound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayActionEventSendSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayActionEventSendSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayActionEventSendSuccess(statsRouter, statsPostRouterHighwayActionEventSendSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayActionEventSendSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayActionEventSendTimeoutBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayActionEventSendTimeout - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayActionEventSendTimeout(statsRouter, statsPostRouterHighwayActionEventSendTimeoutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayActionEventSendTimeout', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsHighwayActionsActionMeterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsHighwayActionsActionMeter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsHighwayActionsActionMeter(statsRouter, statsPostRouterStatsHighwayActionsActionMeterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsHighwayActionsActionMeter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityIcmpEstablishedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityIcmpEstablished - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityIcmpEstablished(statsRouter, statsPostRouterHighwayDestinationReachabilityIcmpEstablishedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityIcmpEstablished', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpTimeToEstablishmentMaxBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIcmpTimeToEstablishmentMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpTimeToEstablishmentMax(statsRouter, statsPostRouterIcmpTimeToEstablishmentMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpTimeToEstablishmentMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpTimeToEstablishmentMinBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIcmpTimeToEstablishmentMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpTimeToEstablishmentMin(statsRouter, statsPostRouterIcmpTimeToEstablishmentMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpTimeToEstablishmentMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityIcmpTimeoutBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'destination-prefix',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReachabilityIcmpTimeoutBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityIcmpTimeoutBeforeEstablishment(statsRouter, statsPostRouterReachabilityIcmpTimeoutBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityIcmpTimeoutBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityIcmpUnreachableBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityIcmpUnreachable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityIcmpUnreachable(statsRouter, statsPostRouterHighwayDestinationReachabilityIcmpUnreachableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityIcmpUnreachable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityTcpCloseBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReachabilityTcpCloseBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityTcpCloseBeforeEstablishment(statsRouter, statsPostRouterReachabilityTcpCloseBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityTcpCloseBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityTcpEstablishedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityTcpEstablished - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityTcpEstablished(statsRouter, statsPostRouterHighwayDestinationReachabilityTcpEstablishedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityTcpEstablished', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpTimeToEstablishmentMaxBodyParam = {
      parameters: [
        {
          name: 'destination-prefix',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTcpTimeToEstablishmentMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpTimeToEstablishmentMax(statsRouter, statsPostRouterTcpTimeToEstablishmentMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpTimeToEstablishmentMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpTimeToEstablishmentMinBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTcpTimeToEstablishmentMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpTimeToEstablishmentMin(statsRouter, statsPostRouterTcpTimeToEstablishmentMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpTimeToEstablishmentMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityTcpTimeoutBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReachabilityTcpTimeoutBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityTcpTimeoutBeforeEstablishment(statsRouter, statsPostRouterReachabilityTcpTimeoutBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityTcpTimeoutBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityTcpUnreachableBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityTcpUnreachable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityTcpUnreachable(statsRouter, statsPostRouterHighwayDestinationReachabilityTcpUnreachableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityTcpUnreachable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityTlsCloseBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReachabilityTlsCloseBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityTlsCloseBeforeEstablishment(statsRouter, statsPostRouterReachabilityTlsCloseBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityTlsCloseBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityTlsEstablishedBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityTlsEstablished - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityTlsEstablished(statsRouter, statsPostRouterHighwayDestinationReachabilityTlsEstablishedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityTlsEstablished', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTlsTimeToEstablishmentMaxBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTlsTimeToEstablishmentMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTlsTimeToEstablishmentMax(statsRouter, statsPostRouterTlsTimeToEstablishmentMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTlsTimeToEstablishmentMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTlsTimeToEstablishmentMinBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTlsTimeToEstablishmentMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTlsTimeToEstablishmentMin(statsRouter, statsPostRouterTlsTimeToEstablishmentMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTlsTimeToEstablishmentMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityTlsTimeoutBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReachabilityTlsTimeoutBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityTlsTimeoutBeforeEstablishment(statsRouter, statsPostRouterReachabilityTlsTimeoutBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityTlsTimeoutBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityUdpEstablishedBodyParam = {
      parameters: [
        {
          name: 'destination-prefix',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityUdpEstablished - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityUdpEstablished(statsRouter, statsPostRouterHighwayDestinationReachabilityUdpEstablishedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityUdpEstablished', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUdpTimeToEstablishmentMaxBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUdpTimeToEstablishmentMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUdpTimeToEstablishmentMax(statsRouter, statsPostRouterUdpTimeToEstablishmentMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUdpTimeToEstablishmentMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUdpTimeToEstablishmentMinBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUdpTimeToEstablishmentMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUdpTimeToEstablishmentMin(statsRouter, statsPostRouterUdpTimeToEstablishmentMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUdpTimeToEstablishmentMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReachabilityUdpTimeoutBeforeEstablishmentBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReachabilityUdpTimeoutBeforeEstablishment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReachabilityUdpTimeoutBeforeEstablishment(statsRouter, statsPostRouterReachabilityUdpTimeoutBeforeEstablishmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReachabilityUdpTimeoutBeforeEstablishment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayDestinationReachabilityUdpUnreachableBodyParam = {
      parameters: [
        {
          name: 'network-interface',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayDestinationReachabilityUdpUnreachable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayDestinationReachabilityUdpUnreachable(statsRouter, statsPostRouterHighwayDestinationReachabilityUdpUnreachableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayDestinationReachabilityUdpUnreachable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFirewallDetectorDiscoveryPacketDroppedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFirewallDetectorDiscoveryPacketDropped - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFirewallDetectorDiscoveryPacketDropped(statsRouter, statsPostRouterFirewallDetectorDiscoveryPacketDroppedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFirewallDetectorDiscoveryPacketDropped', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorDiscoveryTimeoutBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorDiscoveryTimeout - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorDiscoveryTimeout(statsRouter, statsPostRouterHighwayFirewallDetectorDiscoveryTimeoutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorDiscoveryTimeout', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFirewallDetectorDuplicateContextDetectedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFirewallDetectorDuplicateContextDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFirewallDetectorDuplicateContextDetected(statsRouter, statsPostRouterFirewallDetectorDuplicateContextDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFirewallDetectorDuplicateContextDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorReplyReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorReplyReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorReplyReceived(statsRouter, statsPostRouterHighwayFirewallDetectorReplyReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorReplyReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorReplySentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorReplySent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorReplySent(statsRouter, statsPostRouterHighwayFirewallDetectorReplySentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorReplySent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorRequestReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorRequestReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorRequestReceived(statsRouter, statsPostRouterHighwayFirewallDetectorRequestReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorRequestReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorRequestSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorRequestSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorRequestSent(statsRouter, statsPostRouterHighwayFirewallDetectorRequestSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorRequestSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFirewallDetectorTcpResetReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFirewallDetectorTcpResetReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFirewallDetectorTcpResetReceived(statsRouter, statsPostRouterFirewallDetectorTcpResetReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFirewallDetectorTcpResetReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHighwayFirewallDetectorUnknownReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHighwayFirewallDetectorUnknownReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHighwayFirewallDetectorUnknownReceived(statsRouter, statsPostRouterHighwayFirewallDetectorUnknownReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHighwayFirewallDetectorUnknownReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpReceivedFailureDestinationUnreachableBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterIcmpReceivedFailureDestinationUnreachable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpReceivedFailureDestinationUnreachable(statsRouter, statsPostRouterIcmpReceivedFailureDestinationUnreachableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpReceivedFailureDestinationUnreachable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpReceivedSuccessDestinationUnreachableBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterIcmpReceivedSuccessDestinationUnreachable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpReceivedSuccessDestinationUnreachable(statsRouter, statsPostRouterIcmpReceivedSuccessDestinationUnreachableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpReceivedSuccessDestinationUnreachable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDestinationUnreachablePacketTooBigBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDestinationUnreachablePacketTooBig - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDestinationUnreachablePacketTooBig(statsRouter, statsPostRouterDestinationUnreachablePacketTooBigBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDestinationUnreachablePacketTooBig', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpSentFailureEchoReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIcmpSentFailureEchoReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpSentFailureEchoReply(statsRouter, statsPostRouterIcmpSentFailureEchoReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpSentFailureEchoReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentFailureEchoReplyDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentFailureEchoReplyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentFailureEchoReplyDrop(statsRouter, statsPostRouterSentFailureEchoReplyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentFailureEchoReplyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDestinationUnreachableNetBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessDestinationUnreachableNet - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDestinationUnreachableNet(statsRouter, statsPostRouterSuccessDestinationUnreachableNetBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDestinationUnreachableNet', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDestinationUnreachableNotRequiredBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessDestinationUnreachableNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDestinationUnreachableNotRequired(statsRouter, statsPostRouterSuccessDestinationUnreachableNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDestinationUnreachableNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDestinationUnreachablePacketTooBig2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDestinationUnreachablePacketTooBig2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDestinationUnreachablePacketTooBig2(statsRouter, statsPostRouterDestinationUnreachablePacketTooBig2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDestinationUnreachablePacketTooBig2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDestinationUnreachableReassemblyTimeExceededBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDestinationUnreachableReassemblyTimeExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDestinationUnreachableReassemblyTimeExceeded(statsRouter, statsPostRouterDestinationUnreachableReassemblyTimeExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDestinationUnreachableReassemblyTimeExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDestinationUnreachableTimeExceededBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessDestinationUnreachableTimeExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDestinationUnreachableTimeExceeded(statsRouter, statsPostRouterSuccessDestinationUnreachableTimeExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDestinationUnreachableTimeExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpSentSuccessEchoReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterIcmpSentSuccessEchoReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpSentSuccessEchoReply(statsRouter, statsPostRouterIcmpSentSuccessEchoReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpSentSuccessEchoReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInterfaceReceivedBufferAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInterfaceReceivedBufferAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInterfaceReceivedBufferAllocationFailure(statsRouter, statsPostRouterInterfaceReceivedBufferAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInterfaceReceivedBufferAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceReceivedBytesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceReceivedBytes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceReceivedBytes(statsRouter, statsPostRouterStatsInterfaceReceivedBytesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceReceivedBytes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceReceivedErrorBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceReceivedError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceReceivedError(statsRouter, statsPostRouterStatsInterfaceReceivedErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceReceivedError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceReceivedMissedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsInterfaceReceivedMissed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceReceivedMissed(statsRouter, statsPostRouterStatsInterfaceReceivedMissedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceReceivedMissed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceReceivedPacketsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceReceivedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceReceivedPackets(statsRouter, statsPostRouterStatsInterfaceReceivedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceReceivedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceReceivedUtilizationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceReceivedUtilization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceReceivedUtilization(statsRouter, statsPostRouterStatsInterfaceReceivedUtilizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceReceivedUtilization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceSentBytesBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsInterfaceSentBytes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceSentBytes(statsRouter, statsPostRouterStatsInterfaceSentBytesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceSentBytes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceSentErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsInterfaceSentError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceSentError(statsRouter, statsPostRouterStatsInterfaceSentErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceSentError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceSentPackets(statsRouter, statsPostRouterStatsInterfaceSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsInterfaceSentUtilizationBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsInterfaceSentUtilization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsInterfaceSentUtilization(statsRouter, statsPostRouterStatsInterfaceSentUtilizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsInterfaceSentUtilization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsIpfixRecordExportRateBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsIpfixRecordExportRate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsIpfixRecordExportRate(statsRouter, statsPostRouterStatsIpfixRecordExportRateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsIpfixRecordExportRate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsIpfixTimePerExportBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsIpfixTimePerExport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsIpfixTimePerExport(statsRouter, statsPostRouterStatsIpfixTimePerExportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsIpfixTimePerExport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsIpfixTimePerSessionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsIpfixTimePerSession - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsIpfixTimePerSession(statsRouter, statsPostRouterStatsIpfixTimePerSessionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsIpfixTimePerSession', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsIpfixTotalGenerationTimeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsIpfixTotalGenerationTime - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsIpfixTotalGenerationTime(statsRouter, statsPostRouterStatsIpfixTotalGenerationTimeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsIpfixTotalGenerationTime', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsIpfixTotalRecordsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsIpfixTotalRecords - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsIpfixTotalRecords(statsRouter, statsPostRouterStatsIpfixTotalRecordsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsIpfixTotalRecords', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMemoryCapacityBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsMemoryCapacity - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMemoryCapacity(statsRouter, statsPostRouterStatsMemoryCapacityBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMemoryCapacity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMemoryUsedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsMemoryUsed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMemoryUsed(statsRouter, statsPostRouterStatsMemoryUsedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMemoryUsed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsActiveBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsMetricsActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsActive(statsRouter, statsPostRouterStatsMetricsActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsCollectionsPendingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsMetricsCollectionsPending - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsCollectionsPending(statsRouter, statsPostRouterStatsMetricsCollectionsPendingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsCollectionsPending', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsCollectionsSkippedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsMetricsCollectionsSkipped - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsCollectionsSkipped(statsRouter, statsPostRouterStatsMetricsCollectionsSkippedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsCollectionsSkipped', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsPerCollectionLatencyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsMetricsPerCollectionLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsPerCollectionLatency(statsRouter, statsPostRouterStatsMetricsPerCollectionLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsPerCollectionLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsPerMetricLatencyBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsMetricsPerMetricLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsPerMetricLatency(statsRouter, statsPostRouterStatsMetricsPerMetricLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsPerMetricLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMetricsReadMetricLatencyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsMetricsReadMetricLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMetricsReadMetricLatency(statsRouter, statsPostRouterStatsMetricsReadMetricLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMetricsReadMetricLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMtuDiscoveryPeerPathReceivedBodyParam = {
      parameters: [
        {
          name: 'device-name',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMtuDiscoveryPeerPathReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMtuDiscoveryPeerPathReceived(statsRouter, statsPostRouterMtuDiscoveryPeerPathReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMtuDiscoveryPeerPathReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPeerPathSentArpFailureBodyParam = {
      parameters: [
        {
          name: 'peer-host',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPeerPathSentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPeerPathSentArpFailure(statsRouter, statsPostRouterPeerPathSentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPeerPathSentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathSentBufferAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathSentBufferAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathSentBufferAllocationFailure(statsRouter, statsPostRouterPathSentBufferAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathSentBufferAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDiscoveryPeerPathSentSuccessBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDiscoveryPeerPathSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDiscoveryPeerPathSentSuccess(statsRouter, statsPostRouterDiscoveryPeerPathSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDiscoveryPeerPathSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMtuDiscoveryReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsMtuDiscoveryReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMtuDiscoveryReceived(statsRouter, statsPostRouterStatsMtuDiscoveryReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMtuDiscoveryReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMtuDiscoverySentArpFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMtuDiscoverySentArpFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMtuDiscoverySentArpFailure(statsRouter, statsPostRouterMtuDiscoverySentArpFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMtuDiscoverySentArpFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDiscoverySentBufferAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDiscoverySentBufferAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDiscoverySentBufferAllocationFailure(statsRouter, statsPostRouterDiscoverySentBufferAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDiscoverySentBufferAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsMtuDiscoverySentSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsMtuDiscoverySentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsMtuDiscoverySentSuccess(statsRouter, statsPostRouterStatsMtuDiscoverySentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsMtuDiscoverySentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsPacketCaptureSuccessBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsPacketCaptureSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsPacketCaptureSuccess(statsRouter, statsPostRouterStatsPacketCaptureSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsPacketCaptureSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsPacketCaptureWriteFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsPacketCaptureWriteFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsPacketCaptureWriteFailure(statsRouter, statsPostRouterStatsPacketCaptureWriteFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsPacketCaptureWriteFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesDataNormalizationBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureAesDataNormalization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesDataNormalization(statsRouter, statsPostRouterActionFailureAesDataNormalizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesDataNormalization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesDecryptionExceptionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesDecryptionException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesDecryptionException(statsRouter, statsPostRouterActionFailureAesDecryptionExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesDecryptionException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesEncryptionExceptionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesEncryptionException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesEncryptionException(statsRouter, statsPostRouterActionFailureAesEncryptionExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesEncryptionException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureAesGetDataLengthBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureAesGetDataLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureAesGetDataLength(statsRouter, statsPostRouterFailureAesGetDataLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureAesGetDataLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesIvAppendBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesIvAppend - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesIvAppend(statsRouter, statsPostRouterActionFailureAesIvAppendBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesIvAppend', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesIvGenerationBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesIvGeneration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesIvGeneration(statsRouter, statsPostRouterActionFailureAesIvGenerationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesIvGeneration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesIvSeedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesIvSeed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesIvSeed(statsRouter, statsPostRouterActionFailureAesIvSeedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesIvSeed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesMetadataDecryptionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureAesMetadataDecryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesMetadataDecryption(statsRouter, statsPostRouterActionFailureAesMetadataDecryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesMetadataDecryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesMetadataEncryptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesMetadataEncryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesMetadataEncryption(statsRouter, statsPostRouterActionFailureAesMetadataEncryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesMetadataEncryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureAesNoContextFoundBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureAesNoContextFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureAesNoContextFound(statsRouter, statsPostRouterFailureAesNoContextFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureAesNoContextFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesPayloadDecryptionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesPayloadDecryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesPayloadDecryption(statsRouter, statsPostRouterActionFailureAesPayloadDecryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesPayloadDecryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureAesPayloadEncryptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureAesPayloadEncryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureAesPayloadEncryption(statsRouter, statsPostRouterActionFailureAesPayloadEncryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureAesPayloadEncryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureAesSetDataLengthBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureAesSetDataLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureAesSetDataLength(statsRouter, statsPostRouterFailureAesSetDataLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureAesSetDataLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdDecodeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureBfdDecode - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdDecode(statsRouter, statsPostRouterActionFailureBfdDecodeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdDecode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdEchoInitBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureBfdEchoInit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdEchoInit(statsRouter, statsPostRouterActionFailureBfdEchoInitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdEchoInit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdEmptyMetadataBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureBfdEmptyMetadata - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdEmptyMetadata(statsRouter, statsPostRouterActionFailureBfdEmptyMetadataBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdEmptyMetadata', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdEmptyPayloadBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureBfdEmptyPayload - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdEmptyPayload(statsRouter, statsPostRouterActionFailureBfdEmptyPayloadBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdEmptyPayload', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureBfdFragmentedMtuDiscoveryBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureBfdFragmentedMtuDiscovery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureBfdFragmentedMtuDiscovery(statsRouter, statsPostRouterFailureBfdFragmentedMtuDiscoveryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureBfdFragmentedMtuDiscovery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdInvalidHeaderBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureBfdInvalidHeader - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdInvalidHeader(statsRouter, statsPostRouterActionFailureBfdInvalidHeaderBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdInvalidHeader', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureBfdMetadataParseBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureBfdMetadataParse - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureBfdMetadataParse(statsRouter, statsPostRouterActionFailureBfdMetadataParseBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureBfdMetadataParse', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureDpiFtpParseFailedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureDpiFtpParseFailed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureDpiFtpParseFailed(statsRouter, statsPostRouterFailureDpiFtpParseFailedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureDpiFtpParseFailed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureDpiFtpPinholeMissBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureDpiFtpPinholeMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureDpiFtpPinholeMiss(statsRouter, statsPostRouterFailureDpiFtpPinholeMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureDpiFtpPinholeMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureDpiFtpPinholeTimeoutBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureDpiFtpPinholeTimeout - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureDpiFtpPinholeTimeout(statsRouter, statsPostRouterFailureDpiFtpPinholeTimeoutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureDpiFtpPinholeTimeout', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHeaderTransformArpTableMissesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHeaderTransformArpTableMisses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHeaderTransformArpTableMisses(statsRouter, statsPostRouterHeaderTransformArpTableMissesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHeaderTransformArpTableMisses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEthernetHeaderTransformPacketExpansionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEthernetHeaderTransformPacketExpansion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEthernetHeaderTransformPacketExpansion(statsRouter, statsPostRouterEthernetHeaderTransformPacketExpansionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEthernetHeaderTransformPacketExpansion', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMoveDisableForwardMetadataDiscardsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMoveDisableForwardMetadataDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMoveDisableForwardMetadataDiscards(statsRouter, statsPostRouterMoveDisableForwardMetadataDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMoveDisableForwardMetadataDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureHmacAllocationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureHmacAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureHmacAllocation(statsRouter, statsPostRouterActionFailureHmacAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureHmacAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureHmacCannotFindDigestBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureHmacCannotFindDigest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureHmacCannotFindDigest(statsRouter, statsPostRouterFailureHmacCannotFindDigestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureHmacCannotFindDigest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureHmacContextNotFoundBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureHmacContextNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureHmacContextNotFound(statsRouter, statsPostRouterFailureHmacContextNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureHmacContextNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureHmacDigestCalculationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureHmacDigestCalculation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureHmacDigestCalculation(statsRouter, statsPostRouterActionFailureHmacDigestCalculationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureHmacDigestCalculation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureHmacDigestCompareBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureHmacDigestCompare - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureHmacDigestCompare(statsRouter, statsPostRouterActionFailureHmacDigestCompareBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureHmacDigestCompare', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterHmacOppositeFlowNotFoundBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterHmacOppositeFlowNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterHmacOppositeFlowNotFound(statsRouter, statsPostRouterHmacOppositeFlowNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterHmacOppositeFlowNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIpHeaderTransformIcmpTranslationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIpHeaderTransformIcmpTranslation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIpHeaderTransformIcmpTranslation(statsRouter, statsPostRouterIpHeaderTransformIcmpTranslationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIpHeaderTransformIcmpTranslation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTransformIpv6ToIpv4MappingBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterTransformIpv6ToIpv4Mapping - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTransformIpv6ToIpv4Mapping(statsRouter, statsPostRouterTransformIpv6ToIpv4MappingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTransformIpv6ToIpv4Mapping', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIpHeaderTransformL4TranslationBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIpHeaderTransformL4Translation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIpHeaderTransformL4Translation(statsRouter, statsPostRouterIpHeaderTransformL4TranslationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIpHeaderTransformL4Translation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureKeepAliveBufferAllocationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureKeepAliveBufferAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureKeepAliveBufferAllocation(statsRouter, statsPostRouterFailureKeepAliveBufferAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureKeepAliveBufferAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureMetadataAddBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureMetadataAdd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureMetadataAdd(statsRouter, statsPostRouterActionFailureMetadataAddBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureMetadataAdd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataCachedAttributesNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMetadataCachedAttributesNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataCachedAttributesNotFound(statsRouter, statsPostRouterMetadataCachedAttributesNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataCachedAttributesNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataEnableFlowMissBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMetadataEnableFlowMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataEnableFlowMiss(statsRouter, statsPostRouterMetadataEnableFlowMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataEnableFlowMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureMetadataGetLengthBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureMetadataGetLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureMetadataGetLength(statsRouter, statsPostRouterActionFailureMetadataGetLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureMetadataGetLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureMetadataInvalidTypeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureMetadataInvalidType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureMetadataInvalidType(statsRouter, statsPostRouterActionFailureMetadataInvalidTypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureMetadataInvalidType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureMetadataNotPresentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureMetadataNotPresent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureMetadataNotPresent(statsRouter, statsPostRouterActionFailureMetadataNotPresentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureMetadataNotPresent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedUnknownForcedDropReasonBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedUnknownForcedDropReason - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedUnknownForcedDropReason(statsRouter, statsPostRouterReceivedUnknownForcedDropReasonBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedUnknownForcedDropReason', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureMetadataReverseBufferAllocationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureMetadataReverseBufferAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureMetadataReverseBufferAllocation(statsRouter, statsPostRouterFailureMetadataReverseBufferAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureMetadataReverseBufferAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataTurnOffBufferAllocationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMetadataTurnOffBufferAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataTurnOffBufferAllocation(statsRouter, statsPostRouterMetadataTurnOffBufferAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataTurnOffBufferAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureMultiplexorUntagDiscardsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionFailureMultiplexorUntagDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureMultiplexorUntagDiscards(statsRouter, statsPostRouterActionFailureMultiplexorUntagDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureMultiplexorUntagDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailurePaddingInvalidPacketLengthBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailurePaddingInvalidPacketLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailurePaddingInvalidPacketLength(statsRouter, statsPostRouterFailurePaddingInvalidPacketLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailurePaddingInvalidPacketLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsSentCorrelatedDataBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathMetricsSentCorrelatedData - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsSentCorrelatedData(statsRouter, statsPostRouterPathMetricsSentCorrelatedDataBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsSentCorrelatedData', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsSentUnidirectionalReplyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathMetricsSentUnidirectionalReply - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsSentUnidirectionalReply(statsRouter, statsPostRouterPathMetricsSentUnidirectionalReplyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsSentUnidirectionalReply', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureRateLimitCheckBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureRateLimitCheck - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureRateLimitCheck(statsRouter, statsPostRouterActionFailureRateLimitCheckBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureRateLimitCheck', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureRetransmissionHandlerBufferAllocationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureRetransmissionHandlerBufferAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureRetransmissionHandlerBufferAllocation(statsRouter, statsPostRouterFailureRetransmissionHandlerBufferAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureRetransmissionHandlerBufferAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureRetransmissionHandlerCapacityExceededBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureRetransmissionHandlerCapacityExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureRetransmissionHandlerCapacityExceeded(statsRouter, statsPostRouterFailureRetransmissionHandlerCapacityExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureRetransmissionHandlerCapacityExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRetransmissionHandlerDeletedFlowDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRetransmissionHandlerDeletedFlowDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRetransmissionHandlerDeletedFlowDiscards(statsRouter, statsPostRouterRetransmissionHandlerDeletedFlowDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRetransmissionHandlerDeletedFlowDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRetransmissionHandlerInvalidAcknowledgementAttributeBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRetransmissionHandlerInvalidAcknowledgementAttribute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRetransmissionHandlerInvalidAcknowledgementAttribute(statsRouter, statsPostRouterRetransmissionHandlerInvalidAcknowledgementAttributeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRetransmissionHandlerInvalidAcknowledgementAttribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRetransmissionHandlerInvalidPacketLengthBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRetransmissionHandlerInvalidPacketLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRetransmissionHandlerInvalidPacketLength(statsRouter, statsPostRouterRetransmissionHandlerInvalidPacketLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRetransmissionHandlerInvalidPacketLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionFailureRetransmissionHandlerReclassifyBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionFailureRetransmissionHandlerReclassify - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionFailureRetransmissionHandlerReclassify(statsRouter, statsPostRouterActionFailureRetransmissionHandlerReclassifyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionFailureRetransmissionHandlerReclassify', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureRetransmissionHandlerTimeoutDiscardsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureRetransmissionHandlerTimeoutDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureRetransmissionHandlerTimeoutDiscards(statsRouter, statsPostRouterFailureRetransmissionHandlerTimeoutDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureRetransmissionHandlerTimeoutDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureTcpProxyBufferAllocationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFailureTcpProxyBufferAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureTcpProxyBufferAllocation(statsRouter, statsPostRouterFailureTcpProxyBufferAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureTcpProxyBufferAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFailureTcpProxyInboundDiscardsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFailureTcpProxyInboundDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFailureTcpProxyInboundDiscards(statsRouter, statsPostRouterFailureTcpProxyInboundDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFailureTcpProxyInboundDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpProxySessionsTimedOutBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterTcpProxySessionsTimedOut - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpProxySessionsTimedOut(statsRouter, statsPostRouterTcpProxySessionsTimedOutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpProxySessionsTimedOut', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpStateIllegalFlagCombinationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterTcpStateIllegalFlagCombination - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpStateIllegalFlagCombination(statsRouter, statsPostRouterTcpStateIllegalFlagCombinationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpStateIllegalFlagCombination', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpStateInvalidTransitionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTcpStateInvalidTransition - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpStateInvalidTransition(statsRouter, statsPostRouterTcpStateInvalidTransitionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpStateInvalidTransition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingActionFailureTtlValidateBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingActionFailureTtlValidate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingActionFailureTtlValidate(statsRouter, statsPostRouterProcessingActionFailureTtlValidateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingActionFailureTtlValidate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesMetadataDecryptionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessAesMetadataDecryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesMetadataDecryption(statsRouter, statsPostRouterActionSuccessAesMetadataDecryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesMetadataDecryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesMetadataEncryptionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessAesMetadataEncryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesMetadataEncryption(statsRouter, statsPostRouterActionSuccessAesMetadataEncryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesMetadataEncryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAesMetadataFalsePositiveDetectedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAesMetadataFalsePositiveDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAesMetadataFalsePositiveDetected(statsRouter, statsPostRouterAesMetadataFalsePositiveDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAesMetadataFalsePositiveDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesNoMetadataBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessAesNoMetadata - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesNoMetadata(statsRouter, statsPostRouterActionSuccessAesNoMetadataBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesNoMetadata', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesNoPayloadBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessAesNoPayload - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesNoPayload(statsRouter, statsPostRouterActionSuccessAesNoPayloadBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesNoPayload', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesPayloadDecryptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessAesPayloadDecryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesPayloadDecryption(statsRouter, statsPostRouterActionSuccessAesPayloadDecryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesPayloadDecryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessAesPayloadEncryptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessAesPayloadEncryption - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessAesPayloadEncryption(statsRouter, statsPostRouterActionSuccessAesPayloadEncryptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessAesPayloadEncryption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessBfdAsyncDiscardedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessBfdAsyncDiscarded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessBfdAsyncDiscarded(statsRouter, statsPostRouterActionSuccessBfdAsyncDiscardedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessBfdAsyncDiscarded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessBfdAsyncProcessedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessBfdAsyncProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessBfdAsyncProcessed(statsRouter, statsPostRouterActionSuccessBfdAsyncProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessBfdAsyncProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessBfdEchoRequestProcessedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessBfdEchoRequestProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessBfdEchoRequestProcessed(statsRouter, statsPostRouterSuccessBfdEchoRequestProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessBfdEchoRequestProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessBfdEchoResponseProcessedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessBfdEchoResponseProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessBfdEchoResponseProcessed(statsRouter, statsPostRouterSuccessBfdEchoResponseProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessBfdEchoResponseProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessBfdMtuDiscoveryRequestsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessBfdMtuDiscoveryRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessBfdMtuDiscoveryRequests(statsRouter, statsPostRouterSuccessBfdMtuDiscoveryRequestsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessBfdMtuDiscoveryRequests', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessBfdRemoteSessionRequestedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessBfdRemoteSessionRequested - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessBfdRemoteSessionRequested(statsRouter, statsPostRouterSuccessBfdRemoteSessionRequestedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessBfdRemoteSessionRequested', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingActionSuccessDetourBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingActionSuccessDetour - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingActionSuccessDetour(statsRouter, statsPostRouterPacketProcessingActionSuccessDetourBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingActionSuccessDetour', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiFtpDataPortDetectedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDpiFtpDataPortDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiFtpDataPortDetected(statsRouter, statsPostRouterDpiFtpDataPortDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiFtpDataPortDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDpiFtpPinholeClosedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessDpiFtpPinholeClosed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDpiFtpPinholeClosed(statsRouter, statsPostRouterSuccessDpiFtpPinholeClosedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDpiFtpPinholeClosed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDpiFtpPinholeHitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessDpiFtpPinholeHit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDpiFtpPinholeHit(statsRouter, statsPostRouterSuccessDpiFtpPinholeHitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDpiFtpPinholeHit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessDpiFtpPinholeOpenedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessDpiFtpPinholeOpened - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessDpiFtpPinholeOpened(statsRouter, statsPostRouterSuccessDpiFtpPinholeOpenedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessDpiFtpPinholeOpened', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiTlsClientDetectedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDpiTlsClientDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiTlsClientDetected(statsRouter, statsPostRouterDpiTlsClientDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiTlsClientDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDpiTlsServerHandshakeDetectedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDpiTlsServerHandshakeDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDpiTlsServerHandshakeDetected(statsRouter, statsPostRouterDpiTlsServerHandshakeDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDpiTlsServerHandshakeDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTlsServerSentForInspectionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterTlsServerSentForInspection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTlsServerSentForInspection(statsRouter, statsPostRouterTlsServerSentForInspectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTlsServerSentForInspection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessDpiUnencryptedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessDpiUnencrypted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessDpiUnencrypted(statsRouter, statsPostRouterActionSuccessDpiUnencryptedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessDpiUnencrypted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingActionSuccessDropBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingActionSuccessDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingActionSuccessDrop(statsRouter, statsPostRouterPacketProcessingActionSuccessDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingActionSuccessDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessDuplicateDetectorAllowBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessDuplicateDetectorAllow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessDuplicateDetectorAllow(statsRouter, statsPostRouterActionSuccessDuplicateDetectorAllowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessDuplicateDetectorAllow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessDuplicateDetectorDenyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessDuplicateDetectorDeny - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessDuplicateDetectorDeny(statsRouter, statsPostRouterActionSuccessDuplicateDetectorDenyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessDuplicateDetectorDeny', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessEthernetHeaderTransformBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessEthernetHeaderTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessEthernetHeaderTransform(statsRouter, statsPostRouterActionSuccessEthernetHeaderTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessEthernetHeaderTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessFlowMoveDetectedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessFlowMoveDetected - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessFlowMoveDetected(statsRouter, statsPostRouterActionSuccessFlowMoveDetectedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessFlowMoveDetected', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessFlowMovePacketsEnqueuedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessFlowMovePacketsEnqueued - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessFlowMovePacketsEnqueued(statsRouter, statsPostRouterSuccessFlowMovePacketsEnqueuedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessFlowMovePacketsEnqueued', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessForwardToWireBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessForwardToWire - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessForwardToWire(statsRouter, statsPostRouterActionSuccessForwardToWireBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessForwardToWire', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessHmacAppendNoPayloadBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessHmacAppendNoPayload - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessHmacAppendNoPayload(statsRouter, statsPostRouterSuccessHmacAppendNoPayloadBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessHmacAppendNoPayload', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessHmacDigestAddedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessHmacDigestAdded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessHmacDigestAdded(statsRouter, statsPostRouterActionSuccessHmacDigestAddedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessHmacDigestAdded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessHmacDigestRemovedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessHmacDigestRemoved - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessHmacDigestRemoved(statsRouter, statsPostRouterActionSuccessHmacDigestRemovedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessHmacDigestRemoved', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessHmacNotRequiredBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessHmacNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessHmacNotRequired(statsRouter, statsPostRouterActionSuccessHmacNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessHmacNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessHmacValidateNoPayloadBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessHmacValidateNoPayload - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessHmacValidateNoPayload(statsRouter, statsPostRouterSuccessHmacValidateNoPayloadBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessHmacValidateNoPayload', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessIpHeaderTransformBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessIpHeaderTransform - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessIpHeaderTransform(statsRouter, statsPostRouterActionSuccessIpHeaderTransformBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessIpHeaderTransform', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessKeepAliveSentTcpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessKeepAliveSentTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessKeepAliveSentTcp(statsRouter, statsPostRouterSuccessKeepAliveSentTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessKeepAliveSentTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessKeepAliveSentUdpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessKeepAliveSentUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessKeepAliveSentUdp(statsRouter, statsPostRouterSuccessKeepAliveSentUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessKeepAliveSentUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessKeepAliveSessionsClosedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessKeepAliveSessionsClosed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessKeepAliveSessionsClosed(statsRouter, statsPostRouterSuccessKeepAliveSessionsClosedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessKeepAliveSessionsClosed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessKeepAliveSessionsOpenedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessKeepAliveSessionsOpened - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessKeepAliveSessionsOpened(statsRouter, statsPostRouterSuccessKeepAliveSessionsOpenedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessKeepAliveSessionsOpened', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataAddFalsePositiveCorrectionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterMetadataAddFalsePositiveCorrection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataAddFalsePositiveCorrection(statsRouter, statsPostRouterMetadataAddFalsePositiveCorrectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataAddFalsePositiveCorrection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataAddNotRequiredBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessMetadataAddNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataAddNotRequired(statsRouter, statsPostRouterSuccessMetadataAddNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataAddNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessMetadataAddedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessMetadataAdded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessMetadataAdded(statsRouter, statsPostRouterActionSuccessMetadataAddedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessMetadataAdded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataPropagateNotRequiredBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessMetadataPropagateNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataPropagateNotRequired(statsRouter, statsPostRouterSuccessMetadataPropagateNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataPropagateNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataReceivedDisableForwardBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterMetadataReceivedDisableForward - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataReceivedDisableForward(statsRouter, statsPostRouterMetadataReceivedDisableForwardBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataReceivedDisableForward', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataReceivedEnableBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessMetadataReceivedEnable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataReceivedEnable(statsRouter, statsPostRouterSuccessMetadataReceivedEnableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataReceivedEnable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataReceivedKeepAliveBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessMetadataReceivedKeepAlive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataReceivedKeepAlive(statsRouter, statsPostRouterSuccessMetadataReceivedKeepAliveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataReceivedKeepAlive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataRemoveFalsePositiveCorrectionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterMetadataRemoveFalsePositiveCorrection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataRemoveFalsePositiveCorrection(statsRouter, statsPostRouterMetadataRemoveFalsePositiveCorrectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataRemoveFalsePositiveCorrection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataRemoveNotRequiredBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessMetadataRemoveNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataRemoveNotRequired(statsRouter, statsPostRouterSuccessMetadataRemoveNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataRemoveNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessMetadataRemovedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessMetadataRemoved - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessMetadataRemoved(statsRouter, statsPostRouterActionSuccessMetadataRemovedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessMetadataRemoved', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessMetadataRightLaneSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessMetadataRightLaneSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessMetadataRightLaneSent(statsRouter, statsPostRouterSuccessMetadataRightLaneSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessMetadataRightLaneSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterMetadataSentDisableForwardBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterMetadataSentDisableForward - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterMetadataSentDisableForward(statsRouter, statsPostRouterMetadataSentDisableForwardBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterMetadataSentDisableForward', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessMetadataUpdatedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessMetadataUpdated - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessMetadataUpdated(statsRouter, statsPostRouterActionSuccessMetadataUpdatedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessMetadataUpdated', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessMultiplexorTaggedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessMultiplexorTagged - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessMultiplexorTagged(statsRouter, statsPostRouterActionSuccessMultiplexorTaggedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessMultiplexorTagged', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessMultiplexorUntaggedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessMultiplexorUntagged - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessMultiplexorUntagged(statsRouter, statsPostRouterActionSuccessMultiplexorUntaggedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessMultiplexorUntagged', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessPaddingAddedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessPaddingAdded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessPaddingAdded(statsRouter, statsPostRouterActionSuccessPaddingAddedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessPaddingAdded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessPaddingRemovedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessPaddingRemoved - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessPaddingRemoved(statsRouter, statsPostRouterActionSuccessPaddingRemovedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessPaddingRemoved', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsAddNotRequiredBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathMetricsAddNotRequired - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsAddNotRequired(statsRouter, statsPostRouterPathMetricsAddNotRequiredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsAddNotRequired', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessPathMetricsRemoveDroppedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessPathMetricsRemoveDropped - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessPathMetricsRemoveDropped(statsRouter, statsPostRouterSuccessPathMetricsRemoveDroppedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessPathMetricsRemoveDropped', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsRemoveNotPresentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathMetricsRemoveNotPresent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsRemoveNotPresent(statsRouter, statsPostRouterPathMetricsRemoveNotPresentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsRemoveNotPresent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessPathMetricsRemovedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessPathMetricsRemoved - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessPathMetricsRemoved(statsRouter, statsPostRouterActionSuccessPathMetricsRemovedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessPathMetricsRemoved', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsSentCorrelatedData2BodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathMetricsSentCorrelatedData2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsSentCorrelatedData2(statsRouter, statsPostRouterPathMetricsSentCorrelatedData2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsSentCorrelatedData2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsSentUnidirectionalReply2BodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathMetricsSentUnidirectionalReply2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsSentUnidirectionalReply2(statsRouter, statsPostRouterPathMetricsSentUnidirectionalReply2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsSentUnidirectionalReply2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsWithMetadataAddedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPathMetricsWithMetadataAdded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsWithMetadataAdded(statsRouter, statsPostRouterPathMetricsWithMetadataAddedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsWithMetadataAdded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPathMetricsWithoutMetadataAddedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPathMetricsWithoutMetadataAdded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPathMetricsWithoutMetadataAdded(statsRouter, statsPostRouterPathMetricsWithoutMetadataAddedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPathMetricsWithoutMetadataAdded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessRateLimitCheckBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterActionSuccessRateLimitCheck - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessRateLimitCheck(statsRouter, statsPostRouterActionSuccessRateLimitCheckBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessRateLimitCheck', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessRetransmissionHandlerAcceptedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessRetransmissionHandlerAccepted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessRetransmissionHandlerAccepted(statsRouter, statsPostRouterActionSuccessRetransmissionHandlerAcceptedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessRetransmissionHandlerAccepted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessRetransmissionHandlerAcknowledgedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessRetransmissionHandlerAcknowledged - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessRetransmissionHandlerAcknowledged(statsRouter, statsPostRouterActionSuccessRetransmissionHandlerAcknowledgedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessRetransmissionHandlerAcknowledged', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerAcknowledgementReceivedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerAcknowledgementReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerAcknowledgementReceived(statsRouter, statsPostRouterSuccessRetransmissionHandlerAcknowledgementReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerAcknowledgementReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerAcknowledgementSentBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerAcknowledgementSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerAcknowledgementSent(statsRouter, statsPostRouterSuccessRetransmissionHandlerAcknowledgementSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerAcknowledgementSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessRetransmissionHandlerBypassedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessRetransmissionHandlerBypassed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessRetransmissionHandlerBypassed(statsRouter, statsPostRouterActionSuccessRetransmissionHandlerBypassedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessRetransmissionHandlerBypassed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterActionSuccessRetransmissionHandlerCachedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterActionSuccessRetransmissionHandlerCached - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterActionSuccessRetransmissionHandlerCached(statsRouter, statsPostRouterActionSuccessRetransmissionHandlerCachedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterActionSuccessRetransmissionHandlerCached', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerDuplicateDiscardsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerDuplicateDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerDuplicateDiscards(statsRouter, statsPostRouterSuccessRetransmissionHandlerDuplicateDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerDuplicateDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRetransmissionHandlerOutstandingPacketsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRetransmissionHandlerOutstandingPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRetransmissionHandlerOutstandingPackets(statsRouter, statsPostRouterRetransmissionHandlerOutstandingPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRetransmissionHandlerOutstandingPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerRetransmissionsSentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerRetransmissionsSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerRetransmissionsSent(statsRouter, statsPostRouterSuccessRetransmissionHandlerRetransmissionsSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerRetransmissionsSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerSessionsClosedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerSessionsClosed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerSessionsClosed(statsRouter, statsPostRouterSuccessRetransmissionHandlerSessionsClosedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerSessionsClosed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessRetransmissionHandlerSessionsOpenedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessRetransmissionHandlerSessionsOpened - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessRetransmissionHandlerSessionsOpened(statsRouter, statsPostRouterSuccessRetransmissionHandlerSessionsOpenedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessRetransmissionHandlerSessionsOpened', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxyAcknowledgementReceivedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessTcpProxyAcknowledgementReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxyAcknowledgementReceived(statsRouter, statsPostRouterSuccessTcpProxyAcknowledgementReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxyAcknowledgementReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxyAcknowledgementSentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessTcpProxyAcknowledgementSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxyAcknowledgementSent(statsRouter, statsPostRouterSuccessTcpProxyAcknowledgementSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxyAcknowledgementSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpProxyDataPacketsTransmittedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTcpProxyDataPacketsTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpProxyDataPacketsTransmitted(statsRouter, statsPostRouterTcpProxyDataPacketsTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpProxyDataPacketsTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxyDataTransmittedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessTcpProxyDataTransmitted - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxyDataTransmitted(statsRouter, statsPostRouterSuccessTcpProxyDataTransmittedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxyDataTransmitted', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpProxyOutstandingPacketsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterTcpProxyOutstandingPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpProxyOutstandingPackets(statsRouter, statsPostRouterTcpProxyOutstandingPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpProxyOutstandingPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxyRetransmissionsSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessTcpProxyRetransmissionsSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxyRetransmissionsSent(statsRouter, statsPostRouterSuccessTcpProxyRetransmissionsSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxyRetransmissionsSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTcpProxyRetransmittedDataSentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTcpProxyRetransmittedDataSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTcpProxyRetransmittedDataSent(statsRouter, statsPostRouterTcpProxyRetransmittedDataSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTcpProxyRetransmittedDataSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxySessionsClosedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSuccessTcpProxySessionsClosed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxySessionsClosed(statsRouter, statsPostRouterSuccessTcpProxySessionsClosedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxySessionsClosed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxySessionsOpenedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessTcpProxySessionsOpened - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxySessionsOpened(statsRouter, statsPostRouterSuccessTcpProxySessionsOpenedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxySessionsOpened', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSuccessTcpProxySessionsResetBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSuccessTcpProxySessionsReset - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSuccessTcpProxySessionsReset(statsRouter, statsPostRouterSuccessTcpProxySessionsResetBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSuccessTcpProxySessionsReset', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingActionSuccessTcpStateBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingActionSuccessTcpState - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingActionSuccessTcpState(statsRouter, statsPostRouterProcessingActionSuccessTcpStateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingActionSuccessTcpState', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingActionSuccessTtlValidateBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingActionSuccessTtlValidate - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingActionSuccessTtlValidate(statsRouter, statsPostRouterProcessingActionSuccessTtlValidateBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingActionSuccessTtlValidate', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedArpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedArp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedArp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedArpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedArp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedBroadcastMacDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedBroadcastMacDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedBroadcastMacDiscards(statsRouter, statsPostRouterClassifierReceivedBroadcastMacDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedBroadcastMacDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedDhcpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedDhcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedDhcp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedDhcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedDhcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedDhcpv6BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedDhcpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedDhcpv6(statsRouter, statsPostRouterPacketProcessingClassifierReceivedDhcpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedDhcpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedDiscards(statsRouter, statsPostRouterPacketProcessingClassifierReceivedDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedExceptionBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedException(statsRouter, statsPostRouterPacketProcessingClassifierReceivedExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedFragmentedIcmpDiscardsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedFragmentedIcmpDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedFragmentedIcmpDiscards(statsRouter, statsPostRouterClassifierReceivedFragmentedIcmpDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedFragmentedIcmpDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedFragmentedIcmpv6DiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedFragmentedIcmpv6Discards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedFragmentedIcmpv6Discards(statsRouter, statsPostRouterClassifierReceivedFragmentedIcmpv6DiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedFragmentedIcmpv6Discards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedIcmpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedIcmp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedIcmp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedIcmpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedIcmp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIcmpTtlDiscardsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIcmpTtlDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIcmpTtlDiscards(statsRouter, statsPostRouterClassifierReceivedIcmpTtlDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIcmpTtlDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedIcmpUnknownTypeDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedIcmpUnknownTypeDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedIcmpUnknownTypeDiscards(statsRouter, statsPostRouterReceivedIcmpUnknownTypeDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedIcmpUnknownTypeDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedIcmpv6BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedIcmpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedIcmpv6(statsRouter, statsPostRouterPacketProcessingClassifierReceivedIcmpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedIcmpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedIcmpv6HopLimitDiscardsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedIcmpv6HopLimitDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedIcmpv6HopLimitDiscards(statsRouter, statsPostRouterReceivedIcmpv6HopLimitDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedIcmpv6HopLimitDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedIcmpv6LinkLocalDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedIcmpv6LinkLocalDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedIcmpv6LinkLocalDiscards(statsRouter, statsPostRouterReceivedIcmpv6LinkLocalDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedIcmpv6LinkLocalDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedIcmpv6UnknownTypeDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedIcmpv6UnknownTypeDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedIcmpv6UnknownTypeDiscards(statsRouter, statsPostRouterReceivedIcmpv6UnknownTypeDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedIcmpv6UnknownTypeDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpInvalidBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpInvalid - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpInvalid(statsRouter, statsPostRouterClassifierReceivedIgmpInvalidBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpInvalid', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpLeaveBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpLeave - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpLeave(statsRouter, statsPostRouterClassifierReceivedIgmpLeaveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpLeave', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpQueryBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpQuery - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpQuery(statsRouter, statsPostRouterClassifierReceivedIgmpQueryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpQuery', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpReportBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpReport - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpReport(statsRouter, statsPostRouterClassifierReceivedIgmpReportBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpReport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpReportV3BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpReportV3 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpReportV3(statsRouter, statsPostRouterClassifierReceivedIgmpReportV3BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpReportV3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIgmpTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIgmpTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIgmpTotal(statsRouter, statsPostRouterClassifierReceivedIgmpTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIgmpTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedInvalidHeaderLengthBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedInvalidHeaderLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedInvalidHeaderLength(statsRouter, statsPostRouterClassifierReceivedInvalidHeaderLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedInvalidHeaderLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedInvalidIpv6BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedInvalidIpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedInvalidIpv6(statsRouter, statsPostRouterProcessingClassifierReceivedInvalidIpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedInvalidIpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedInvalidLengthBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedInvalidLength - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedInvalidLength(statsRouter, statsPostRouterProcessingClassifierReceivedInvalidLengthBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedInvalidLength', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedIpv4BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedIpv4 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedIpv4(statsRouter, statsPostRouterPacketProcessingClassifierReceivedIpv4BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedIpv4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIpv4FabricFragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierReceivedIpv4FabricFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIpv4FabricFragmented(statsRouter, statsPostRouterClassifierReceivedIpv4FabricFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIpv4FabricFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedIpv4FragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedIpv4Fragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedIpv4Fragmented(statsRouter, statsPostRouterProcessingClassifierReceivedIpv4FragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedIpv4Fragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedIpv6BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedIpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedIpv6(statsRouter, statsPostRouterPacketProcessingClassifierReceivedIpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedIpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedIpv6FabricFragmentedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedIpv6FabricFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedIpv6FabricFragmented(statsRouter, statsPostRouterClassifierReceivedIpv6FabricFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedIpv6FabricFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedIpv6FragmentedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedIpv6Fragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedIpv6Fragmented(statsRouter, statsPostRouterProcessingClassifierReceivedIpv6FragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedIpv6Fragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedIsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedIs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedIs(statsRouter, statsPostRouterProcessingClassifierReceivedIsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedIs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedLacpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedLacp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedLacp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedLacpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedLacp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedNdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedNdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedNdp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedNdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedNdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedOspfBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedOspf(statsRouter, statsPostRouterPacketProcessingClassifierReceivedOspfBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedOtherLayer4ProtocolBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedOtherLayer4Protocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedOtherLayer4Protocol(statsRouter, statsPostRouterClassifierReceivedOtherLayer4ProtocolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedOtherLayer4Protocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierReceivedAdvertisementBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierReceivedAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierReceivedAdvertisement(statsRouter, statsPostRouterProcessingClassifierReceivedAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierReceivedAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedSctpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedSctp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedSctp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedSctpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedSctp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierReceivedSpanningTreeDiscardsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierReceivedSpanningTreeDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierReceivedSpanningTreeDiscards(statsRouter, statsPostRouterClassifierReceivedSpanningTreeDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierReceivedSpanningTreeDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedTcpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedTcp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedTotalBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedTotal(statsRouter, statsPostRouterPacketProcessingClassifierReceivedTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedTunnelBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedTunnel - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedTunnel(statsRouter, statsPostRouterPacketProcessingClassifierReceivedTunnelBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedTunnel', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedUdpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedUdp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedUnknownLayer3ProtocolDiscardsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedUnknownLayer3ProtocolDiscards - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedUnknownLayer3ProtocolDiscards(statsRouter, statsPostRouterReceivedUnknownLayer3ProtocolDiscardsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedUnknownLayer3ProtocolDiscards', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedVlanBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedVlan - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedVlan(statsRouter, statsPostRouterPacketProcessingClassifierReceivedVlanBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedVlan', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierReceivedVrrpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierReceivedVrrp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierReceivedVrrp(statsRouter, statsPostRouterPacketProcessingClassifierReceivedVrrpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierReceivedVrrp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentArpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentArp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentArp(statsRouter, statsPostRouterPacketProcessingClassifierSentArpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentArp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentDhcpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentDhcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentDhcp(statsRouter, statsPostRouterPacketProcessingClassifierSentDhcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentDhcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentDhcpv6BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentDhcpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentDhcpv6(statsRouter, statsPostRouterPacketProcessingClassifierSentDhcpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentDhcpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentIcmpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentIcmp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentIcmp(statsRouter, statsPostRouterPacketProcessingClassifierSentIcmpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentIcmp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentIcmpv6BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentIcmpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentIcmpv6(statsRouter, statsPostRouterPacketProcessingClassifierSentIcmpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentIcmpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentIgmpBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentIgmp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentIgmp(statsRouter, statsPostRouterPacketProcessingClassifierSentIgmpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentIgmp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentIpv4BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentIpv4 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentIpv4(statsRouter, statsPostRouterPacketProcessingClassifierSentIpv4BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentIpv4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierSentIpv4FabricFragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierSentIpv4FabricFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierSentIpv4FabricFragmented(statsRouter, statsPostRouterClassifierSentIpv4FabricFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierSentIpv4FabricFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierSentIpv4FragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierSentIpv4Fragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierSentIpv4Fragmented(statsRouter, statsPostRouterProcessingClassifierSentIpv4FragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierSentIpv4Fragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentIpv6BodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentIpv6 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentIpv6(statsRouter, statsPostRouterPacketProcessingClassifierSentIpv6BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentIpv6', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierSentIpv6FabricFragmentedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierSentIpv6FabricFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierSentIpv6FabricFragmented(statsRouter, statsPostRouterClassifierSentIpv6FabricFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierSentIpv6FabricFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierSentIpv6FragmentedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierSentIpv6Fragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierSentIpv6Fragmented(statsRouter, statsPostRouterProcessingClassifierSentIpv6FragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierSentIpv6Fragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierSentIsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingClassifierSentIs - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierSentIs(statsRouter, statsPostRouterProcessingClassifierSentIsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierSentIs', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentLacpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentLacp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentLacp(statsRouter, statsPostRouterPacketProcessingClassifierSentLacpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentLacp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentNdpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentNdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentNdp(statsRouter, statsPostRouterPacketProcessingClassifierSentNdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentNdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentOspfBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentOspf - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentOspf(statsRouter, statsPostRouterPacketProcessingClassifierSentOspfBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierSentOtherLayer3ProtocolBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClassifierSentOtherLayer3Protocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierSentOtherLayer3Protocol(statsRouter, statsPostRouterClassifierSentOtherLayer3ProtocolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierSentOtherLayer3Protocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClassifierSentOtherLayer4ProtocolBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClassifierSentOtherLayer4Protocol - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClassifierSentOtherLayer4Protocol(statsRouter, statsPostRouterClassifierSentOtherLayer4ProtocolBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClassifierSentOtherLayer4Protocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingClassifierSentAdvertisementBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingClassifierSentAdvertisement - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingClassifierSentAdvertisement(statsRouter, statsPostRouterProcessingClassifierSentAdvertisementBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingClassifierSentAdvertisement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentSctpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentSctp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentSctp(statsRouter, statsPostRouterPacketProcessingClassifierSentSctpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentSctp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentTcpBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentTcp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentTcp(statsRouter, statsPostRouterPacketProcessingClassifierSentTcpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentTcp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentTotal(statsRouter, statsPostRouterPacketProcessingClassifierSentTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentTunnelBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentTunnel - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentTunnel(statsRouter, statsPostRouterPacketProcessingClassifierSentTunnelBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentTunnel', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentUdpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentUdp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentUdp(statsRouter, statsPostRouterPacketProcessingClassifierSentUdpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentUdp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentVlanBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentVlan - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentVlan(statsRouter, statsPostRouterPacketProcessingClassifierSentVlanBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentVlan', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingClassifierSentVrrpBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingClassifierSentVrrp - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingClassifierSentVrrp(statsRouter, statsPostRouterPacketProcessingClassifierSentVrrpBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingClassifierSentVrrp', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsPacketProcessingDhcpDiscardedBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsPacketProcessingDhcpDiscarded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsPacketProcessingDhcpDiscarded(statsRouter, statsPostRouterStatsPacketProcessingDhcpDiscardedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsPacketProcessingDhcpDiscarded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpForwardToDerivedInterfaceBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDhcpForwardToDerivedInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpForwardToDerivedInterface(statsRouter, statsPostRouterDhcpForwardToDerivedInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpForwardToDerivedInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpForwardToOriginatingInterfaceBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDhcpForwardToOriginatingInterface - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpForwardToOriginatingInterface(statsRouter, statsPostRouterDhcpForwardToOriginatingInterfaceBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpForwardToOriginatingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpReceivedForInternalApplicationBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDhcpReceivedForInternalApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpReceivedForInternalApplication(statsRouter, statsPostRouterDhcpReceivedForInternalApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpReceivedForInternalApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEnqueueToDeferredRingFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEnqueueToDeferredRingFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEnqueueToDeferredRingFailure(statsRouter, statsPostRouterEnqueueToDeferredRingFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEnqueueToDeferredRingFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEnqueueToDeferredRingSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEnqueueToDeferredRingSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEnqueueToDeferredRingSuccess(statsRouter, statsPostRouterEnqueueToDeferredRingSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEnqueueToDeferredRingSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEnqueueToWorkerCoreFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEnqueueToWorkerCoreFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEnqueueToWorkerCoreFailure(statsRouter, statsPostRouterEnqueueToWorkerCoreFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEnqueueToWorkerCoreFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEnqueueToWorkerCoreSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEnqueueToWorkerCoreSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEnqueueToWorkerCoreSuccess(statsRouter, statsPostRouterEnqueueToWorkerCoreSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEnqueueToWorkerCoreSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFibActionSummaryExceptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingFibActionSummaryException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFibActionSummaryException(statsRouter, statsPostRouterProcessingFibActionSummaryExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFibActionSummaryException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFibActionSummaryFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingFibActionSummaryFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFibActionSummaryFailure(statsRouter, statsPostRouterProcessingFibActionSummaryFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFibActionSummaryFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFibActionSummarySuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingFibActionSummarySuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFibActionSummarySuccess(statsRouter, statsPostRouterProcessingFibActionSummarySuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFibActionSummarySuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFlowActionSummaryExceptionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingFlowActionSummaryException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFlowActionSummaryException(statsRouter, statsPostRouterProcessingFlowActionSummaryExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFlowActionSummaryException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFlowActionSummaryFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingFlowActionSummaryFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFlowActionSummaryFailure(statsRouter, statsPostRouterProcessingFlowActionSummaryFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFlowActionSummaryFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFlowActionSummarySuccessBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingFlowActionSummarySuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFlowActionSummarySuccess(statsRouter, statsPostRouterProcessingFlowActionSummarySuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFlowActionSummarySuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedDuplicateFirstFragmentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationReceivedDuplicateFirstFragment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedDuplicateFirstFragment(statsRouter, statsPostRouterFragmentationReceivedDuplicateFirstFragmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedDuplicateFirstFragment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedDuplicateLastFragmentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationReceivedDuplicateLastFragment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedDuplicateLastFragment(statsRouter, statsPostRouterFragmentationReceivedDuplicateLastFragmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedDuplicateLastFragment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedFailureToReassembleBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationReceivedFailureToReassemble - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedFailureToReassemble(statsRouter, statsPostRouterFragmentationReceivedFailureToReassembleBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedFailureToReassemble', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedFragmentChainsDiscardedBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFragmentationReceivedFragmentChainsDiscarded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedFragmentChainsDiscarded(statsRouter, statsPostRouterFragmentationReceivedFragmentChainsDiscardedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedFragmentChainsDiscarded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedFragmentChainsExceededBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFragmentationReceivedFragmentChainsExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedFragmentChainsExceeded(statsRouter, statsPostRouterFragmentationReceivedFragmentChainsExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedFragmentChainsExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationReceivedFragmentChainsTimeoutBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationReceivedFragmentChainsTimeout - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationReceivedFragmentChainsTimeout(statsRouter, statsPostRouterFragmentationReceivedFragmentChainsTimeoutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationReceivedFragmentChainsTimeout', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFragmentationReceivedIncompleteFragmentsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingFragmentationReceivedIncompleteFragments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFragmentationReceivedIncompleteFragments(statsRouter, statsPostRouterProcessingFragmentationReceivedIncompleteFragmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFragmentationReceivedIncompleteFragments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedInvalidLengthFirstFragmentBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedInvalidLengthFirstFragment - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedInvalidLengthFirstFragment(statsRouter, statsPostRouterReceivedInvalidLengthFirstFragmentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedInvalidLengthFirstFragment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingFragmentationReceivedSuccessfullyReassembledBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingFragmentationReceivedSuccessfullyReassembled - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingFragmentationReceivedSuccessfullyReassembled(statsRouter, statsPostRouterProcessingFragmentationReceivedSuccessfullyReassembledBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingFragmentationReceivedSuccessfullyReassembled', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentFragmentCreationFailureBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationSentFragmentCreationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentFragmentCreationFailure(statsRouter, statsPostRouterFragmentationSentFragmentCreationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentFragmentCreationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentIpv4DontFragmentDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentIpv4DontFragmentDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentIpv4DontFragmentDrop(statsRouter, statsPostRouterSentIpv4DontFragmentDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentIpv4DontFragmentDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentIpv4FabricFragmentsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationSentIpv4FabricFragments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentIpv4FabricFragments(statsRouter, statsPostRouterFragmentationSentIpv4FabricFragmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentIpv4FabricFragments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentIpv4NonFabricFragmentsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentIpv4NonFabricFragments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentIpv4NonFabricFragments(statsRouter, statsPostRouterSentIpv4NonFabricFragmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentIpv4NonFabricFragments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentIpv4PacketsFragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationSentIpv4PacketsFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentIpv4PacketsFragmented(statsRouter, statsPostRouterFragmentationSentIpv4PacketsFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentIpv4PacketsFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentIpv6FabricFragmentsBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFragmentationSentIpv6FabricFragments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentIpv6FabricFragments(statsRouter, statsPostRouterFragmentationSentIpv6FabricFragmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentIpv6FabricFragments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentIpv6MtuExceededDropBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentIpv6MtuExceededDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentIpv6MtuExceededDrop(statsRouter, statsPostRouterSentIpv6MtuExceededDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentIpv6MtuExceededDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentIpv6NonFabricFragmentsBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentIpv6NonFabricFragments - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentIpv6NonFabricFragments(statsRouter, statsPostRouterSentIpv6NonFabricFragmentsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentIpv6NonFabricFragments', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentIpv6PacketsFragmentedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFragmentationSentIpv6PacketsFragmented - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentIpv6PacketsFragmented(statsRouter, statsPostRouterFragmentationSentIpv6PacketsFragmentedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentIpv6PacketsFragmented', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFragmentationSentUnknownL2VersionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFragmentationSentUnknownL2Version - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFragmentationSentUnknownL2Version(statsRouter, statsPostRouterFragmentationSentUnknownL2VersionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFragmentationSentUnknownL2Version', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupAccessPolicyTableAllowBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLookupAccessPolicyTableAllow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupAccessPolicyTableAllow(statsRouter, statsPostRouterLookupAccessPolicyTableAllowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupAccessPolicyTableAllow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupAccessPolicyTableDenyBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLookupAccessPolicyTableDeny - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupAccessPolicyTableDeny(statsRouter, statsPostRouterLookupAccessPolicyTableDenyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupAccessPolicyTableDeny', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupAccessPolicyTableFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLookupAccessPolicyTableFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupAccessPolicyTableFailure(statsRouter, statsPostRouterLookupAccessPolicyTableFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupAccessPolicyTableFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupAccessPolicyTableMissBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLookupAccessPolicyTableMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupAccessPolicyTableMiss(statsRouter, statsPostRouterLookupAccessPolicyTableMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupAccessPolicyTableMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFibTableDenyBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingLookupFibTableDeny - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFibTableDeny(statsRouter, statsPostRouterProcessingLookupFibTableDenyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFibTableDeny', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFibTableFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupFibTableFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFibTableFailure(statsRouter, statsPostRouterProcessingLookupFibTableFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFibTableFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFibTableHitBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupFibTableHit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFibTableHit(statsRouter, statsPostRouterProcessingLookupFibTableHitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFibTableHit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFibTableMissBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingLookupFibTableMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFibTableMiss(statsRouter, statsPostRouterProcessingLookupFibTableMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFibTableMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFlowTableHitBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingLookupFlowTableHit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFlowTableHit(statsRouter, statsPostRouterProcessingLookupFlowTableHitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFlowTableHit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFlowTableInvalidatedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupFlowTableInvalidated - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFlowTableInvalidated(statsRouter, statsPostRouterProcessingLookupFlowTableInvalidatedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFlowTableInvalidated', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupFlowTableMissBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupFlowTableMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupFlowTableMiss(statsRouter, statsPostRouterProcessingLookupFlowTableMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupFlowTableMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupIcmpTableIpv4AllowBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLookupIcmpTableIpv4Allow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupIcmpTableIpv4Allow(statsRouter, statsPostRouterLookupIcmpTableIpv4AllowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupIcmpTableIpv4Allow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupIcmpTableIpv4DenyBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLookupIcmpTableIpv4Deny - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupIcmpTableIpv4Deny(statsRouter, statsPostRouterLookupIcmpTableIpv4DenyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupIcmpTableIpv4Deny', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupIcmpTableIpv6AllowBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLookupIcmpTableIpv6Allow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupIcmpTableIpv6Allow(statsRouter, statsPostRouterLookupIcmpTableIpv6AllowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupIcmpTableIpv6Allow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupIcmpTableIpv6DenyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLookupIcmpTableIpv6Deny - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupIcmpTableIpv6Deny(statsRouter, statsPostRouterLookupIcmpTableIpv6DenyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupIcmpTableIpv6Deny', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentEnableMetadataAllocationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentEnableMetadataAllocationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentEnableMetadataAllocationFailure(statsRouter, statsPostRouterSentEnableMetadataAllocationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentEnableMetadataAllocationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentEnableMetadataCapacityFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSentEnableMetadataCapacityFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentEnableMetadataCapacityFailure(statsRouter, statsPostRouterSentEnableMetadataCapacityFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentEnableMetadataCapacityFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSentEnableMetadataHmacFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSentEnableMetadataHmacFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSentEnableMetadataHmacFailure(statsRouter, statsPostRouterSentEnableMetadataHmacFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSentEnableMetadataHmacFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupSentEnableMetadataSuccessBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterLookupSentEnableMetadataSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupSentEnableMetadataSuccess(statsRouter, statsPostRouterLookupSentEnableMetadataSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupSentEnableMetadataSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupTenantTableFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupTenantTableFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupTenantTableFailure(statsRouter, statsPostRouterProcessingLookupTenantTableFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupTenantTableFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupTenantTableHitBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingLookupTenantTableHit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupTenantTableHit(statsRouter, statsPostRouterProcessingLookupTenantTableHitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupTenantTableHit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingLookupTenantTableMissBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterProcessingLookupTenantTableMiss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingLookupTenantTableMiss(statsRouter, statsPostRouterProcessingLookupTenantTableMissBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingLookupTenantTableMiss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingReceivedControlSuccessBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingReceivedControlSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingReceivedControlSuccess(statsRouter, statsPostRouterPacketProcessingReceivedControlSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingReceivedControlSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingReceivedInjectedSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingReceivedInjectedSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingReceivedInjectedSuccess(statsRouter, statsPostRouterPacketProcessingReceivedInjectedSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingReceivedInjectedSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingReceivedInterfaceStandbyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingReceivedInterfaceStandby - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingReceivedInterfaceStandby(statsRouter, statsPostRouterPacketProcessingReceivedInterfaceStandbyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingReceivedInterfaceStandby', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingReceivedInterfaceStandbyDropBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingReceivedInterfaceStandbyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingReceivedInterfaceStandbyDrop(statsRouter, statsPostRouterProcessingReceivedInterfaceStandbyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingReceivedInterfaceStandbyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingReceivedInterfaceSuccessBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingReceivedInterfaceSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingReceivedInterfaceSuccess(statsRouter, statsPostRouterPacketProcessingReceivedInterfaceSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingReceivedInterfaceSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingSentInterfaceFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingSentInterfaceFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingSentInterfaceFailure(statsRouter, statsPostRouterPacketProcessingSentInterfaceFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingSentInterfaceFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingSentInterfaceRetryBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingSentInterfaceRetry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingSentInterfaceRetry(statsRouter, statsPostRouterPacketProcessingSentInterfaceRetryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingSentInterfaceRetry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingSentInterfaceStandbyBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketProcessingSentInterfaceStandby - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingSentInterfaceStandby(statsRouter, statsPostRouterPacketProcessingSentInterfaceStandbyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingSentInterfaceStandby', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingSentInterfaceStandbyDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingSentInterfaceStandbyDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingSentInterfaceStandbyDrop(statsRouter, statsPostRouterProcessingSentInterfaceStandbyDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingSentInterfaceStandbyDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketProcessingSentInterfaceSuccessBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPacketProcessingSentInterfaceSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketProcessingSentInterfaceSuccess(statsRouter, statsPostRouterPacketProcessingSentInterfaceSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketProcessingSentInterfaceSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterProcessingSentInterfaceUnconfiguredDropBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterProcessingSentInterfaceUnconfiguredDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterProcessingSentInterfaceUnconfiguredDrop(statsRouter, statsPostRouterProcessingSentInterfaceUnconfiguredDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterProcessingSentInterfaceUnconfiguredDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedNotificationsDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientReceivedNotificationsDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedNotificationsDuration(statsRouter, statsPostRouterClientReceivedNotificationsDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedNotificationsDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedNotificationsErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientReceivedNotificationsError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedNotificationsError(statsRouter, statsPostRouterClientReceivedNotificationsErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedNotificationsError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedNotificationsTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientReceivedNotificationsTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedNotificationsTotal(statsRouter, statsPostRouterClientReceivedNotificationsTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedNotificationsTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedResponsesDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientReceivedResponsesDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedResponsesDuration(statsRouter, statsPostRouterClientReceivedResponsesDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedResponsesDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedResponsesErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientReceivedResponsesError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedResponsesError(statsRouter, statsPostRouterClientReceivedResponsesErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedResponsesError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedResponsesTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientReceivedResponsesTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedResponsesTotal(statsRouter, statsPostRouterClientReceivedResponsesTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedResponsesTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientReceivedUnknownTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientReceivedUnknownTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientReceivedUnknownTotal(statsRouter, statsPostRouterClientReceivedUnknownTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientReceivedUnknownTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientSentRequestsErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientSentRequestsError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientSentRequestsError(statsRouter, statsPostRouterClientSentRequestsErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientSentRequestsError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientSentRequestsTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientSentRequestsTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientSentRequestsTotal(statsRouter, statsPostRouterClientSentRequestsTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientSentRequestsTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTreeClientTransactionsServerLatencyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTreeClientTransactionsServerLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTreeClientTransactionsServerLatency(statsRouter, statsPostRouterTreeClientTransactionsServerLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTreeClientTransactionsServerLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReceivedRequestsAverageBodyParam = {
      parameters: [
        {
          name: 'client',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerReceivedRequestsAverage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReceivedRequestsAverage(statsRouter, statsPostRouterServerReceivedRequestsAverageBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReceivedRequestsAverage', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReceivedRequestsErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerReceivedRequestsError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReceivedRequestsError(statsRouter, statsPostRouterServerReceivedRequestsErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReceivedRequestsError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReceivedRequestsIgnoredBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerReceivedRequestsIgnored - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReceivedRequestsIgnored(statsRouter, statsPostRouterServerReceivedRequestsIgnoredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReceivedRequestsIgnored', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReceivedRequestsTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerReceivedRequestsTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReceivedRequestsTotal(statsRouter, statsPostRouterServerReceivedRequestsTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReceivedRequestsTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerSentResponsesErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerSentResponsesError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerSentResponsesError(statsRouter, statsPostRouterServerSentResponsesErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerSentResponsesError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerSentResponsesTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerSentResponsesTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerSentResponsesTotal(statsRouter, statsPostRouterServerSentResponsesTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerSentResponsesTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsConnectDurationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsConnectDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsConnectDuration(statsRouter, statsPostRouterServerTransactionsConnectDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsConnectDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsConnectErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsConnectError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsConnectError(statsRouter, statsPostRouterServerTransactionsConnectErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsConnectError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsConnectProcessedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsConnectProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsConnectProcessed(statsRouter, statsPostRouterServerTransactionsConnectProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsConnectProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsDisconnectDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsDisconnectDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsDisconnectDuration(statsRouter, statsPostRouterServerTransactionsDisconnectDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsDisconnectDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsDisconnectErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsDisconnectError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsDisconnectError(statsRouter, statsPostRouterServerTransactionsDisconnectErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsDisconnectError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsDisconnectProcessedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsDisconnectProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsDisconnectProcessed(statsRouter, statsPostRouterServerTransactionsDisconnectProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsDisconnectProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsListDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsListDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsListDuration(statsRouter, statsPostRouterServerTransactionsListDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsListDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsListErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsListError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsListError(statsRouter, statsPostRouterServerTransactionsListErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsListError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsListProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsListProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsListProcessed(statsRouter, statsPostRouterServerTransactionsListProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsListProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPingDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsPingDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPingDuration(statsRouter, statsPostRouterServerTransactionsPingDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPingDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPingErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsPingError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPingError(statsRouter, statsPostRouterServerTransactionsPingErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPingError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPingProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsPingProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPingProcessed(statsRouter, statsPostRouterServerTransactionsPingProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPingProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPublishDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsPublishDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPublishDuration(statsRouter, statsPostRouterServerTransactionsPublishDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPublishDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPublishErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsPublishError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPublishError(statsRouter, statsPostRouterServerTransactionsPublishErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPublishError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsPublishProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsPublishProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsPublishProcessed(statsRouter, statsPostRouterServerTransactionsPublishProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsPublishProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsReadDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsReadDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsReadDuration(statsRouter, statsPostRouterServerTransactionsReadDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsReadDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsReadErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsReadError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsReadError(statsRouter, statsPostRouterServerTransactionsReadErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsReadError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsReadProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsReadProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsReadProcessed(statsRouter, statsPostRouterServerTransactionsReadProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsReadProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsRemoveDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsRemoveDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsRemoveDuration(statsRouter, statsPostRouterServerTransactionsRemoveDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsRemoveDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsRemoveErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsRemoveError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsRemoveError(statsRouter, statsPostRouterServerTransactionsRemoveErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsRemoveError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsRemoveProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsRemoveProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsRemoveProcessed(statsRouter, statsPostRouterServerTransactionsRemoveProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsRemoveProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUnsubscribeDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsUnsubscribeDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUnsubscribeDuration(statsRouter, statsPostRouterServerTransactionsUnsubscribeDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUnsubscribeDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUnsubscribeErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsUnsubscribeError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUnsubscribeError(statsRouter, statsPostRouterServerTransactionsUnsubscribeErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUnsubscribeError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUnsubscribeProcessedBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsUnsubscribeProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUnsubscribeProcessed(statsRouter, statsPostRouterServerTransactionsUnsubscribeProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUnsubscribeProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUpdateDurationBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsUpdateDuration - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUpdateDuration(statsRouter, statsPostRouterServerTransactionsUpdateDurationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUpdateDuration', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUpdateErrorBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerTransactionsUpdateError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUpdateError(statsRouter, statsPostRouterServerTransactionsUpdateErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUpdateError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerTransactionsUpdateProcessedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerTransactionsUpdateProcessed - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerTransactionsUpdateProcessed(statsRouter, statsPostRouterServerTransactionsUpdateProcessedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerTransactionsUpdateProcessed', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPerformanceMonitoringPeerPathJitterBodyParam = {
      parameters: [
        {
          name: 'protocol',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPerformanceMonitoringPeerPathJitter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPerformanceMonitoringPeerPathJitter(statsRouter, statsPostRouterPerformanceMonitoringPeerPathJitterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPerformanceMonitoringPeerPathJitter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPerformanceMonitoringPeerPathLatencyBodyParam = {
      parameters: [
        {
          name: 'protocol',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPerformanceMonitoringPeerPathLatency - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPerformanceMonitoringPeerPathLatency(statsRouter, statsPostRouterPerformanceMonitoringPeerPathLatencyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPerformanceMonitoringPeerPathLatency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPerformanceMonitoringPeerPathLossBodyParam = {
      parameters: [
        {
          name: 'vlan',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPerformanceMonitoringPeerPathLoss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPerformanceMonitoringPeerPathLoss(statsRouter, statsPostRouterPerformanceMonitoringPeerPathLossBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPerformanceMonitoringPeerPathLoss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPerformanceMonitoringPeerPathMosBodyParam = {
      parameters: [
        {
          name: 'peer-name',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPerformanceMonitoringPeerPathMos - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPerformanceMonitoringPeerPathMos(statsRouter, statsPostRouterPerformanceMonitoringPeerPathMosBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPerformanceMonitoringPeerPathMos', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsProcessCpuUsageBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsProcessCpuUsage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsProcessCpuUsage(statsRouter, statsPostRouterStatsProcessCpuUsageBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsProcessCpuUsage', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsProcessMemoryRssBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsProcessMemoryRss - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsProcessMemoryRss(statsRouter, statsPostRouterStatsProcessMemoryRssBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsProcessMemoryRss', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsProcessMemoryVszBodyParam = {
      parameters: [
        {
          name: 'process-name',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsProcessMemoryVsz - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsProcessMemoryVsz(statsRouter, statsPostRouterStatsProcessMemoryVszBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsProcessMemoryVsz', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerManagerRedisInactivesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerManagerRedisInactives - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerManagerRedisInactives(statsRouter, statsPostRouterServerManagerRedisInactivesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerManagerRedisInactives', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterManagerRedisServerNetworkFlapsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterManagerRedisServerNetworkFlaps - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterManagerRedisServerNetworkFlaps(statsRouter, statsPostRouterManagerRedisServerNetworkFlapsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterManagerRedisServerNetworkFlaps', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerManagerRedisSessionExpirationsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerManagerRedisSessionExpirations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerManagerRedisSessionExpirations(statsRouter, statsPostRouterServerManagerRedisSessionExpirationsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerManagerRedisSessionExpirations', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyDatabaseConnectionActiveConnectionsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyDatabaseConnectionActiveConnections - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyDatabaseConnectionActiveConnections(statsRouter, statsPostRouterRedundancyDatabaseConnectionActiveConnectionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyDatabaseConnectionActiveConnections', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyDatabaseConnectionClientDisconnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyDatabaseConnectionClientDisconnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyDatabaseConnectionClientDisconnect(statsRouter, statsPostRouterRedundancyDatabaseConnectionClientDisconnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyDatabaseConnectionClientDisconnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyDatabaseConnectionConnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancyDatabaseConnectionConnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyDatabaseConnectionConnect(statsRouter, statsPostRouterStatsRedundancyDatabaseConnectionConnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyDatabaseConnectionConnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyDatabaseConnectionErrorDisconnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyDatabaseConnectionErrorDisconnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyDatabaseConnectionErrorDisconnect(statsRouter, statsPostRouterRedundancyDatabaseConnectionErrorDisconnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyDatabaseConnectionErrorDisconnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyDatabaseConnectionErrorsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancyDatabaseConnectionErrors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyDatabaseConnectionErrors(statsRouter, statsPostRouterStatsRedundancyDatabaseConnectionErrorsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyDatabaseConnectionErrors', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyDatabaseConnectionFailedConnectBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyDatabaseConnectionFailedConnect - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyDatabaseConnectionFailedConnect(statsRouter, statsPostRouterRedundancyDatabaseConnectionFailedConnectBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyDatabaseConnectionFailedConnect', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPortInitializationMarkerQueryPendingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPortInitializationMarkerQueryPending - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPortInitializationMarkerQueryPending(statsRouter, statsPostRouterPortInitializationMarkerQueryPendingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPortInitializationMarkerQueryPending', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPortInitializationMarkerRecordFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPortInitializationMarkerRecordFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPortInitializationMarkerRecordFound(statsRouter, statsPostRouterPortInitializationMarkerRecordFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPortInitializationMarkerRecordFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInitializationMarkerRecordNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInitializationMarkerRecordNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInitializationMarkerRecordNotFound(statsRouter, statsPostRouterInitializationMarkerRecordNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInitializationMarkerRecordNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInitializationMarkerRecordReadErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterInitializationMarkerRecordReadError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInitializationMarkerRecordReadError(statsRouter, statsPostRouterInitializationMarkerRecordReadErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInitializationMarkerRecordReadError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPortInitializationMarkerRecordWriteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPortInitializationMarkerRecordWrite - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPortInitializationMarkerRecordWrite(statsRouter, statsPostRouterPortInitializationMarkerRecordWriteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPortInitializationMarkerRecordWrite', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyPortInitializationPendingQueriesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRedundancyPortInitializationPendingQueries - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyPortInitializationPendingQueries(statsRouter, statsPostRouterRedundancyPortInitializationPendingQueriesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyPortInitializationPendingQueries', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterListRecordsRecordFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterListRecordsRecordFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterListRecordsRecordFound(statsRouter, statsPostRouterListRecordsRecordFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterListRecordsRecordFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRecordsListRecordNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordNotFound(statsRouter, statsPostRouterRecordsListRecordNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordParseErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRecordsListRecordParseError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordParseError(statsRouter, statsPostRouterRecordsListRecordParseErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordParseError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordPopErrorsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRecordsListRecordPopErrors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordPopErrors(statsRouter, statsPostRouterRecordsListRecordPopErrorsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordPopErrors', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordPopFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRecordsListRecordPopFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordPopFailures(statsRouter, statsPostRouterRecordsListRecordPopFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordPopFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordPopPendingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRecordsListRecordPopPending - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordPopPending(statsRouter, statsPostRouterRecordsListRecordPopPendingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordPopPending', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRecordsListRecordPopSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRecordsListRecordPopSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRecordsListRecordPopSuccess(statsRouter, statsPostRouterRecordsListRecordPopSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRecordsListRecordPopSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterListRecordsRecordPushBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterListRecordsRecordPush - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterListRecordsRecordPush(statsRouter, statsPostRouterListRecordsRecordPushBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterListRecordsRecordPush', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancySessionDeleteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRedundancySessionDelete - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancySessionDelete(statsRouter, statsPostRouterStatsRedundancySessionDeleteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancySessionDelete', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancySessionErrorsCacheTimeoutsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancySessionErrorsCacheTimeouts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancySessionErrorsCacheTimeouts(statsRouter, statsPostRouterRedundancySessionErrorsCacheTimeoutsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancySessionErrorsCacheTimeouts', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancySessionErrorsDecodeFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancySessionErrorsDecodeFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancySessionErrorsDecodeFailures(statsRouter, statsPostRouterRedundancySessionErrorsDecodeFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancySessionErrorsDecodeFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsFibLookupErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionErrorsFibLookupError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsFibLookupError(statsRouter, statsPostRouterSessionErrorsFibLookupErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsFibLookupError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsInvalidBufferReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionErrorsInvalidBufferReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsInvalidBufferReceived(statsRouter, statsPostRouterSessionErrorsInvalidBufferReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsInvalidBufferReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsInvalidKeyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionErrorsInvalidKey - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsInvalidKey(statsRouter, statsPostRouterSessionErrorsInvalidKeyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsInvalidKey', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterErrorsNewSessionCreationFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterErrorsNewSessionCreationFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterErrorsNewSessionCreationFailure(statsRouter, statsPostRouterErrorsNewSessionCreationFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterErrorsNewSessionCreationFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionErrorsNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsNotFound(statsRouter, statsPostRouterSessionErrorsNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsUpdateFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionErrorsUpdateFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsUpdateFailures(statsRouter, statsPostRouterSessionErrorsUpdateFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsUpdateFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionErrorsSourceLookupErrorBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionErrorsSourceLookupError - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionErrorsSourceLookupError(statsRouter, statsPostRouterSessionErrorsSourceLookupErrorBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionErrorsSourceLookupError', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancySessionErrorsUnsupportedFeatureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancySessionErrorsUnsupportedFeature - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancySessionErrorsUnsupportedFeature(statsRouter, statsPostRouterRedundancySessionErrorsUnsupportedFeatureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancySessionErrorsUnsupportedFeature', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionReadsCreateNewBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionReadsCreateNew - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionReadsCreateNew(statsRouter, statsPostRouterSessionReadsCreateNewBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionReadsCreateNew', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionReadsNetUnreachableSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionReadsNetUnreachableSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionReadsNetUnreachableSent(statsRouter, statsPostRouterSessionReadsNetUnreachableSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionReadsNetUnreachableSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancySessionReadsQueryPendingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRedundancySessionReadsQueryPending - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancySessionReadsQueryPending(statsRouter, statsPostRouterRedundancySessionReadsQueryPendingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancySessionReadsQueryPending', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReadsQueryResultNotFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReadsQueryResultNotFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReadsQueryResultNotFound(statsRouter, statsPostRouterReadsQueryResultNotFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReadsQueryResultNotFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionReadsQueryResultSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionReadsQueryResultSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionReadsQueryResultSuccess(statsRouter, statsPostRouterSessionReadsQueryResultSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionReadsQueryResultSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionReadsQueryResultTimeoutBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionReadsQueryResultTimeout - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionReadsQueryResultTimeout(statsRouter, statsPostRouterSessionReadsQueryResultTimeoutBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionReadsQueryResultTimeout', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionReadsTcpResetSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionReadsTcpResetSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionReadsTcpResetSent(statsRouter, statsPostRouterSessionReadsTcpResetSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionReadsTcpResetSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterCreatedInterNodeServicePathsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterCreatedInterNodeServicePaths - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterCreatedInterNodeServicePaths(statsRouter, statsPostRouterCreatedInterNodeServicePathsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterCreatedInterNodeServicePaths', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterCreatedInterServicePathsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterCreatedInterServicePaths - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterCreatedInterServicePaths(statsRouter, statsPostRouterCreatedInterServicePathsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterCreatedInterServicePaths', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReconstructionCreatedLocalServicePathsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReconstructionCreatedLocalServicePaths - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReconstructionCreatedLocalServicePaths(statsRouter, statsPostRouterReconstructionCreatedLocalServicePathsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReconstructionCreatedLocalServicePaths', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDivertedToExternalProtocolAgentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDivertedToExternalProtocolAgent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDivertedToExternalProtocolAgent(statsRouter, statsPostRouterDivertedToExternalProtocolAgentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDivertedToExternalProtocolAgent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancySessionRefreshBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancySessionRefresh - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancySessionRefresh(statsRouter, statsPostRouterStatsRedundancySessionRefreshBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancySessionRefresh', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionWritesErrorsEncodeFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionWritesErrorsEncodeFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionWritesErrorsEncodeFailures(statsRouter, statsPostRouterSessionWritesErrorsEncodeFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionWritesErrorsEncodeFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWritesErrorsFromDatabaseBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterWritesErrorsFromDatabase - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWritesErrorsFromDatabase(statsRouter, statsPostRouterWritesErrorsFromDatabaseBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWritesErrorsFromDatabase', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionWritesWriteRequestSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionWritesWriteRequestSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionWritesWriteRequestSent(statsRouter, statsPostRouterSessionWritesWriteRequestSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionWritesWriteRequestSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionWritesWriteRequestSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionWritesWriteRequestSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionWritesWriteRequestSuccess(statsRouter, statsPostRouterSessionWritesWriteRequestSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionWritesWriteRequestSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpAdvertisementsDroppedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpAdvertisementsDropped - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpAdvertisementsDropped(statsRouter, statsPostRouterStatsRedundancyVrrpAdvertisementsDroppedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpAdvertisementsDropped', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpAdvertisementsReceivedBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpAdvertisementsReceived - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpAdvertisementsReceived(statsRouter, statsPostRouterStatsRedundancyVrrpAdvertisementsReceivedBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpAdvertisementsReceived', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpAdvertisementsSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpAdvertisementsSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpAdvertisementsSent(statsRouter, statsPostRouterStatsRedundancyVrrpAdvertisementsSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpAdvertisementsSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpBecomeBackupBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpBecomeBackup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpBecomeBackup(statsRouter, statsPostRouterStatsRedundancyVrrpBecomeBackupBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpBecomeBackup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpBecomeMasterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpBecomeMaster - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpBecomeMaster(statsRouter, statsPostRouterStatsRedundancyVrrpBecomeMasterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpBecomeMaster', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyVrrpBecomeMasterFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyVrrpBecomeMasterFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyVrrpBecomeMasterFailure(statsRouter, statsPostRouterRedundancyVrrpBecomeMasterFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyVrrpBecomeMasterFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRedundancyVrrpReceivedInvalidBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRedundancyVrrpReceivedInvalid - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRedundancyVrrpReceivedInvalid(statsRouter, statsPostRouterStatsRedundancyVrrpReceivedInvalidBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRedundancyVrrpReceivedInvalid', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyVrrpReceivedInvalidTtlBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyVrrpReceivedInvalidTtl - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyVrrpReceivedInvalidTtl(statsRouter, statsPostRouterRedundancyVrrpReceivedInvalidTtlBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyVrrpReceivedInvalidTtl', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyVrrpReceivedInvalidTypeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRedundancyVrrpReceivedInvalidType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyVrrpReceivedInvalidType(statsRouter, statsPostRouterRedundancyVrrpReceivedInvalidTypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyVrrpReceivedInvalidType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRedundancyVrrpReceivedInvalidVersionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRedundancyVrrpReceivedInvalidVersion - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRedundancyVrrpReceivedInvalidVersion(statsRouter, statsPostRouterRedundancyVrrpReceivedInvalidVersionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRedundancyVrrpReceivedInvalidVersion', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRegisteredServicesLocalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRegisteredServicesLocal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRegisteredServicesLocal(statsRouter, statsPostRouterStatsRegisteredServicesLocalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRegisteredServicesLocal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRegisteredServicesRemoteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRegisteredServicesRemote - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRegisteredServicesRemote(statsRouter, statsPostRouterStatsRegisteredServicesRemoteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRegisteredServicesRemote', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRegisteredServicesTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRegisteredServicesTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRegisteredServicesTotal(statsRouter, statsPostRouterStatsRegisteredServicesTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRegisteredServicesTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingAgentAddRouteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRoutingAgentAddRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingAgentAddRoute(statsRouter, statsPostRouterStatsRoutingAgentAddRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingAgentAddRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingAgentDeleteRouteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRoutingAgentDeleteRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingAgentDeleteRoute(statsRouter, statsPostRouterStatsRoutingAgentDeleteRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingAgentDeleteRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRoutingAgentFibInstallErrorsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRoutingAgentFibInstallErrors - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRoutingAgentFibInstallErrors(statsRouter, statsPostRouterRoutingAgentFibInstallErrorsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRoutingAgentFibInstallErrors', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingAgentFibMeterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRoutingAgentFibMeter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingAgentFibMeter(statsRouter, statsPostRouterStatsRoutingAgentFibMeterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingAgentFibMeter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingAgentInstallRouteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRoutingAgentInstallRoute - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingAgentInstallRoute(statsRouter, statsPostRouterStatsRoutingAgentInstallRouteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingAgentInstallRoute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingErrorsConnectionBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsRoutingErrorsConnection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingErrorsConnection(statsRouter, statsPostRouterStatsRoutingErrorsConnectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingErrorsConnection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRoutingRouteUpdatesReceivedAddBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRoutingRouteUpdatesReceivedAdd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRoutingRouteUpdatesReceivedAdd(statsRouter, statsPostRouterRoutingRouteUpdatesReceivedAddBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRoutingRouteUpdatesReceivedAdd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRouteUpdatesReceivedClearFibBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRouteUpdatesReceivedClearFib - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRouteUpdatesReceivedClearFib(statsRouter, statsPostRouterRouteUpdatesReceivedClearFibBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRouteUpdatesReceivedClearFib', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRoutingRouteUpdatesReceivedDeleteBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRoutingRouteUpdatesReceivedDelete - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRoutingRouteUpdatesReceivedDelete(statsRouter, statsPostRouterRoutingRouteUpdatesReceivedDeleteBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRoutingRouteUpdatesReceivedDelete', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdatesReceivedEndOfFibBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterUpdatesReceivedEndOfFib - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdatesReceivedEndOfFib(statsRouter, statsPostRouterUpdatesReceivedEndOfFibBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdatesReceivedEndOfFib', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRouteUpdatesReceivedIamActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRouteUpdatesReceivedIamActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRouteUpdatesReceivedIamActive(statsRouter, statsPostRouterRouteUpdatesReceivedIamActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRouteUpdatesReceivedIamActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRouteUpdatesReceivedIamStandbyBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRouteUpdatesReceivedIamStandby - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRouteUpdatesReceivedIamStandby(statsRouter, statsPostRouterRouteUpdatesReceivedIamStandbyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRouteUpdatesReceivedIamStandby', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRoutingRouteUpdatesReceivedTotalBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRoutingRouteUpdatesReceivedTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRoutingRouteUpdatesReceivedTotal(statsRouter, statsPostRouterRoutingRouteUpdatesReceivedTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRoutingRouteUpdatesReceivedTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRoutingRouteUpdatesSentTotalBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRoutingRouteUpdatesSentTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRoutingRouteUpdatesSentTotal(statsRouter, statsPostRouterRoutingRouteUpdatesSentTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRoutingRouteUpdatesSentTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsRoutingRoutesBodyParam = {
      parameters: [
        {
          name: 'process',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsRoutingRoutes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsRoutingRoutes(statsRouter, statsPostRouterStatsRoutingRoutesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsRoutingRoutes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaDhcpUnknownDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAreaDhcpUnknownDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaDhcpUnknownDroppedPackets(statsRouter, statsPostRouterAreaDhcpUnknownDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaDhcpUnknownDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientAckDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientAckDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientAckDroppedPackets(statsRouter, statsPostRouterV4ClientAckDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientAckDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientAckProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientAckProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientAckProcessedPackets(statsRouter, statsPostRouterV4ClientAckProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientAckProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientAckSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientAckSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientAckSentPackets(statsRouter, statsPostRouterV4ClientAckSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientAckSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDeclineDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientDeclineDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDeclineDroppedPackets(statsRouter, statsPostRouterV4ClientDeclineDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDeclineDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDeclineProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientDeclineProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDeclineProcessedPackets(statsRouter, statsPostRouterV4ClientDeclineProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDeclineProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDeclineSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientDeclineSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDeclineSentPackets(statsRouter, statsPostRouterV4ClientDeclineSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDeclineSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDiscoverDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientDiscoverDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDiscoverDroppedPackets(statsRouter, statsPostRouterV4ClientDiscoverDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDiscoverDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDiscoverProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientDiscoverProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDiscoverProcessedPackets(statsRouter, statsPostRouterV4ClientDiscoverProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDiscoverProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientDiscoverSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientDiscoverSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientDiscoverSentPackets(statsRouter, statsPostRouterV4ClientDiscoverSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientDiscoverSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpV4ClientDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDhcpV4ClientDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpV4ClientDroppedPackets(statsRouter, statsPostRouterDhcpV4ClientDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpV4ClientDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientNackDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientNackDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientNackDroppedPackets(statsRouter, statsPostRouterV4ClientNackDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientNackDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientNackProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientNackProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientNackProcessedPackets(statsRouter, statsPostRouterV4ClientNackProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientNackProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientNackSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientNackSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientNackSentPackets(statsRouter, statsPostRouterV4ClientNackSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientNackSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientOfferDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientOfferDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientOfferDroppedPackets(statsRouter, statsPostRouterV4ClientOfferDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientOfferDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientOfferProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientOfferProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientOfferProcessedPackets(statsRouter, statsPostRouterV4ClientOfferProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientOfferProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientOfferSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientOfferSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientOfferSentPackets(statsRouter, statsPostRouterV4ClientOfferSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientOfferSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpV4ClientProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDhcpV4ClientProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpV4ClientProcessedPackets(statsRouter, statsPostRouterDhcpV4ClientProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpV4ClientProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientReleaseDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientReleaseDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientReleaseDroppedPackets(statsRouter, statsPostRouterV4ClientReleaseDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientReleaseDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientReleaseProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientReleaseProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientReleaseProcessedPackets(statsRouter, statsPostRouterV4ClientReleaseProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientReleaseProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientReleaseSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientReleaseSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientReleaseSentPackets(statsRouter, statsPostRouterV4ClientReleaseSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientReleaseSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientRequestDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientRequestDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientRequestDroppedPackets(statsRouter, statsPostRouterV4ClientRequestDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientRequestDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientRequestProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientRequestProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientRequestProcessedPackets(statsRouter, statsPostRouterV4ClientRequestProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientRequestProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientRequestSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientRequestSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientRequestSentPackets(statsRouter, statsPostRouterV4ClientRequestSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientRequestSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDhcpV4ClientSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDhcpV4ClientSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDhcpV4ClientSentPackets(statsRouter, statsPostRouterDhcpV4ClientSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDhcpV4ClientSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientUnknownDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientUnknownDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientUnknownDroppedPackets(statsRouter, statsPostRouterV4ClientUnknownDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientUnknownDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientUnknownProcessedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4ClientUnknownProcessedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientUnknownProcessedPackets(statsRouter, statsPostRouterV4ClientUnknownProcessedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientUnknownProcessedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4ClientUnknownSentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4ClientUnknownSentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4ClientUnknownSentPackets(statsRouter, statsPostRouterV4ClientUnknownSentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4ClientUnknownSentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4RelayReceivedInvalidPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4RelayReceivedInvalidPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4RelayReceivedInvalidPackets(statsRouter, statsPostRouterV4RelayReceivedInvalidPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4RelayReceivedInvalidPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRelayReceivedInvalidRequestPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRelayReceivedInvalidRequestPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRelayReceivedInvalidRequestPackets(statsRouter, statsPostRouterRelayReceivedInvalidRequestPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRelayReceivedInvalidRequestPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRelayReceivedInvalidResponsePacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterRelayReceivedInvalidResponsePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRelayReceivedInvalidResponsePackets(statsRouter, statsPostRouterRelayReceivedInvalidResponsePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRelayReceivedInvalidResponsePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4RelayReceivedRequestPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4RelayReceivedRequestPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4RelayReceivedRequestPackets(statsRouter, statsPostRouterV4RelayReceivedRequestPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4RelayReceivedRequestPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4RelayReceivedResponsePacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4RelayReceivedResponsePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4RelayReceivedResponsePackets(statsRouter, statsPostRouterV4RelayReceivedResponsePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4RelayReceivedResponsePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4RelayTransmittedRequestPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterV4RelayTransmittedRequestPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4RelayTransmittedRequestPackets(statsRouter, statsPostRouterV4RelayTransmittedRequestPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4RelayTransmittedRequestPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterV4RelayTransmittedResponsePacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterV4RelayTransmittedResponsePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterV4RelayTransmittedResponsePackets(statsRouter, statsPostRouterV4RelayTransmittedResponsePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterV4RelayTransmittedResponsePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientRequestReceivedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterClientRequestReceivedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientRequestReceivedFromApplication(statsRouter, statsPostRouterClientRequestReceivedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientRequestReceivedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterRequestSentToFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterRequestSentToFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterRequestSentToFastLane(statsRouter, statsPostRouterRequestSentToFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterRequestSentToFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAdvertisementDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAdvertisementDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAdvertisementDroppedFromApplication(statsRouter, statsPostRouterAdvertisementDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAdvertisementDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAdvertisementReceivedFromFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAdvertisementReceivedFromFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAdvertisementReceivedFromFastLane(statsRouter, statsPostRouterAdvertisementReceivedFromFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAdvertisementReceivedFromFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAdvertisementSentToApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAdvertisementSentToApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAdvertisementSentToApplication(statsRouter, statsPostRouterAdvertisementSentToApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAdvertisementSentToApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSolicitationReceivedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSolicitationReceivedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSolicitationReceivedFromApplication(statsRouter, statsPostRouterSolicitationReceivedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSolicitationReceivedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSolicitationSentToFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSolicitationSentToFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSolicitationSentToFastLane(statsRouter, statsPostRouterSolicitationSentToFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSolicitationSentToFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReplyDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerReplyDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReplyDroppedFromApplication(statsRouter, statsPostRouterServerReplyDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReplyDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReplyReceivedFromFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReplyReceivedFromFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReplyReceivedFromFastLane(statsRouter, statsPostRouterReplyReceivedFromFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReplyReceivedFromFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReplySentToApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerReplySentToApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReplySentToApplication(statsRouter, statsPostRouterServerReplySentToApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReplySentToApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientUnknownDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientUnknownDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientUnknownDroppedFromApplication(statsRouter, statsPostRouterClientUnknownDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientUnknownDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterClientRequestDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterClientRequestDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterClientRequestDroppedFromApplication(statsRouter, statsPostRouterClientRequestDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterClientRequestDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAdvertisementReceivedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAdvertisementReceivedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAdvertisementReceivedFromApplication(statsRouter, statsPostRouterAdvertisementReceivedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAdvertisementReceivedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAdvertisementSentToFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAdvertisementSentToFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAdvertisementSentToFastLane(statsRouter, statsPostRouterAdvertisementSentToFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAdvertisementSentToFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSolicitationDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSolicitationDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSolicitationDroppedFromApplication(statsRouter, statsPostRouterSolicitationDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSolicitationDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSolicitationReceivedFromFastLaneBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSolicitationReceivedFromFastLane - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSolicitationReceivedFromFastLane(statsRouter, statsPostRouterSolicitationReceivedFromFastLaneBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSolicitationReceivedFromFastLane', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSolicitationSentToApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSolicitationSentToApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSolicitationSentToApplication(statsRouter, statsPostRouterSolicitationSentToApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSolicitationSentToApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerReplyDroppedFromApplication2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServerReplyDroppedFromApplication2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerReplyDroppedFromApplication2(statsRouter, statsPostRouterServerReplyDroppedFromApplication2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerReplyDroppedFromApplication2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServerUnknownDroppedFromApplicationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServerUnknownDroppedFromApplication - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServerUnknownDroppedFromApplication(statsRouter, statsPostRouterServerUnknownDroppedFromApplicationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServerUnknownDroppedFromApplication', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedAdaptiveEncryptionModifyPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedAdaptiveEncryptionModifyPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedAdaptiveEncryptionModifyPackets(statsRouter, statsPostRouterReceivedAdaptiveEncryptionModifyPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedAdaptiveEncryptionModifyPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaReceivedCollisionModifyPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAreaReceivedCollisionModifyPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaReceivedCollisionModifyPackets(statsRouter, statsPostRouterAreaReceivedCollisionModifyPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaReceivedCollisionModifyPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDroppedIcmpRequestPacketBlackholeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDroppedIcmpRequestPacketBlackhole - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDroppedIcmpRequestPacketBlackhole(statsRouter, statsPostRouterDroppedIcmpRequestPacketBlackholeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDroppedIcmpRequestPacketBlackhole', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterIcmpRequestPacketNoEgressBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterIcmpRequestPacketNoEgress - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterIcmpRequestPacketNoEgress(statsRouter, statsPostRouterIcmpRequestPacketNoEgressBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterIcmpRequestPacketNoEgress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceAreaReceivedDroppedPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceAreaReceivedDroppedPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceAreaReceivedDroppedPackets(statsRouter, statsPostRouterServiceAreaReceivedDroppedPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceAreaReceivedDroppedPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDroppedTapMultiplexRecoveryPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDroppedTapMultiplexRecoveryPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDroppedTapMultiplexRecoveryPackets(statsRouter, statsPostRouterDroppedTapMultiplexRecoveryPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDroppedTapMultiplexRecoveryPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedDuplicateReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedDuplicateReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedDuplicateReverseMetadataPackets(statsRouter, statsPostRouterReceivedDuplicateReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedDuplicateReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedEmptyReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedEmptyReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedEmptyReverseMetadataPackets(statsRouter, statsPostRouterReceivedEmptyReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedEmptyReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceAreaReceivedExistingFlowsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceAreaReceivedExistingFlows - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceAreaReceivedExistingFlows(statsRouter, statsPostRouterServiceAreaReceivedExistingFlowsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceAreaReceivedExistingFlows', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceAreaReceivedExistingSessionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterServiceAreaReceivedExistingSession - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceAreaReceivedExistingSession(statsRouter, statsPostRouterServiceAreaReceivedExistingSessionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceAreaReceivedExistingSession', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterExistingSessionReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterExistingSessionReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterExistingSessionReverseMetadataPackets(statsRouter, statsPostRouterExistingSessionReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterExistingSessionReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedExternalProtocolAgentPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedExternalProtocolAgentPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedExternalProtocolAgentPackets(statsRouter, statsPostRouterReceivedExternalProtocolAgentPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedExternalProtocolAgentPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterServiceAreaReceivedFabricPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterServiceAreaReceivedFabricPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterServiceAreaReceivedFabricPackets(statsRouter, statsPostRouterServiceAreaReceivedFabricPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterServiceAreaReceivedFabricPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFibBadSharedMemEntryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFibBadSharedMemEntry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFibBadSharedMemEntry(statsRouter, statsPostRouterFibBadSharedMemEntryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFibBadSharedMemEntry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFlowBadSharedMemEntryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterFlowBadSharedMemEntry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFlowBadSharedMemEntry(statsRouter, statsPostRouterFlowBadSharedMemEntryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFlowBadSharedMemEntry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterFlowExpiredReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterFlowExpiredReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterFlowExpiredReverseMetadataPackets(statsRouter, statsPostRouterFlowExpiredReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterFlowExpiredReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaReceivedFlowMovePacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAreaReceivedFlowMovePackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaReceivedFlowMovePackets(statsRouter, statsPostRouterAreaReceivedFlowMovePacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaReceivedFlowMovePackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedInvalidReverseFlowModifyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedInvalidReverseFlowModify - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedInvalidReverseFlowModify(statsRouter, statsPostRouterReceivedInvalidReverseFlowModifyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedInvalidReverseFlowModify', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedInvalidReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedInvalidReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedInvalidReverseMetadataPackets(statsRouter, statsPostRouterReceivedInvalidReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedInvalidReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedMidFlowModifyPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedMidFlowModifyPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedMidFlowModifyPackets(statsRouter, statsPostRouterReceivedMidFlowModifyPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedMidFlowModifyPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaReceivedNoFibEntryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAreaReceivedNoFibEntry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaReceivedNoFibEntry(statsRouter, statsPostRouterAreaReceivedNoFibEntryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaReceivedNoFibEntry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaReceivedNonFabricPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAreaReceivedNonFabricPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaReceivedNonFabricPackets(statsRouter, statsPostRouterAreaReceivedNonFabricPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaReceivedNonFabricPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPacketsWithStaleFlowHitBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPacketsWithStaleFlowHit - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPacketsWithStaleFlowHit(statsRouter, statsPostRouterPacketsWithStaleFlowHitBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPacketsWithStaleFlowHit', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedReverseMetadataProcessFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedReverseMetadataProcessFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedReverseMetadataProcessFailure(statsRouter, statsPostRouterReceivedReverseMetadataProcessFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedReverseMetadataProcessFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedSessionCollisionChangeDirectionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedSessionCollisionChangeDirection - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedSessionCollisionChangeDirection(statsRouter, statsPostRouterReceivedSessionCollisionChangeDirectionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedSessionCollisionChangeDirection', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedSessionCollisionIgnoreDropBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedSessionCollisionIgnoreDrop - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedSessionCollisionIgnoreDrop(statsRouter, statsPostRouterReceivedSessionCollisionIgnoreDropBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedSessionCollisionIgnoreDrop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaReceivedSessionCollisionIgnoredBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAreaReceivedSessionCollisionIgnored - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaReceivedSessionCollisionIgnored(statsRouter, statsPostRouterAreaReceivedSessionCollisionIgnoredBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaReceivedSessionCollisionIgnored', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionIgnoredReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionIgnoredReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionIgnoredReverseMetadataPackets(statsRouter, statsPostRouterSessionIgnoredReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionIgnoredReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionUpdatedReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionUpdatedReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionUpdatedReverseMetadataPackets(statsRouter, statsPostRouterSessionUpdatedReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionUpdatedReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterLookupBadSharedMemEntryBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterLookupBadSharedMemEntry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterLookupBadSharedMemEntry(statsRouter, statsPostRouterLookupBadSharedMemEntryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterLookupBadSharedMemEntry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateFlowWithPeerFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterUpdateFlowWithPeerFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateFlowWithPeerFailure(statsRouter, statsPostRouterUpdateFlowWithPeerFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateFlowWithPeerFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateFlowWithPeerSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterUpdateFlowWithPeerSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateFlowWithPeerSuccess(statsRouter, statsPostRouterUpdateFlowWithPeerSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateFlowWithPeerSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateSessionWithPeerFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateSessionWithPeerFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateSessionWithPeerFailure(statsRouter, statsPostRouterUpdateSessionWithPeerFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateSessionWithPeerFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterUpdateSessionWithPeerSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterUpdateSessionWithPeerSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterUpdateSessionWithPeerSuccess(statsRouter, statsPostRouterUpdateSessionWithPeerSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterUpdateSessionWithPeerSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedValidReverseMetadataPacketsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedValidReverseMetadataPackets - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedValidReverseMetadataPackets(statsRouter, statsPostRouterReceivedValidReverseMetadataPacketsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedValidReverseMetadataPackets', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaSentArpResolveFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAreaSentArpResolveFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaSentArpResolveFailure(statsRouter, statsPostRouterAreaSentArpResolveFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaSentArpResolveFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaSentArpResolvePendingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAreaSentArpResolvePending - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaSentArpResolvePending(statsRouter, statsPostRouterAreaSentArpResolvePendingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaSentArpResolvePending', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAreaSentArpResolveSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAreaSentArpResolveSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAreaSentArpResolveSuccess(statsRouter, statsPostRouterAreaSentArpResolveSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAreaSentArpResolveSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsServiceAreaSentSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsServiceAreaSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsServiceAreaSentSuccess(statsRouter, statsPostRouterStatsServiceAreaSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsServiceAreaSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterResetForAdaptiveEncryptionFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterResetForAdaptiveEncryptionFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterResetForAdaptiveEncryptionFailure(statsRouter, statsPostRouterResetForAdaptiveEncryptionFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterResetForAdaptiveEncryptionFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInstallErrorsDuplicateReverseFlowBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterInstallErrorsDuplicateReverseFlow - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInstallErrorsDuplicateReverseFlow(statsRouter, statsPostRouterInstallErrorsDuplicateReverseFlowBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInstallErrorsDuplicateReverseFlow', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionInstallErrorsFibLookupBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionInstallErrorsFibLookup - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionInstallErrorsFibLookup(statsRouter, statsPostRouterSessionInstallErrorsFibLookupBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionInstallErrorsFibLookup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInstallErrorsGatewayLookupFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInstallErrorsGatewayLookupFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInstallErrorsGatewayLookupFailure(statsRouter, statsPostRouterInstallErrorsGatewayLookupFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInstallErrorsGatewayLookupFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionInstallErrorsInvalidPacketBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionInstallErrorsInvalidPacket - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionInstallErrorsInvalidPacket(statsRouter, statsPostRouterSessionInstallErrorsInvalidPacketBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionInstallErrorsInvalidPacket', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInstallErrorsServicePathsUnavailableBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInstallErrorsServicePathsUnavailable - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInstallErrorsServicePathsUnavailable(statsRouter, statsPostRouterInstallErrorsServicePathsUnavailableBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInstallErrorsServicePathsUnavailable', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInstallErrorsUrpfCheckFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInstallErrorsUrpfCheckFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInstallErrorsUrpfCheckFailure(statsRouter, statsPostRouterInstallErrorsUrpfCheckFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInstallErrorsUrpfCheckFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionInstallErrorsWaypointAllocationBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionInstallErrorsWaypointAllocation - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionInstallErrorsWaypointAllocation(statsRouter, statsPostRouterSessionInstallErrorsWaypointAllocationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionInstallErrorsWaypointAllocation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSessionActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionActive(statsRouter, statsPostRouterStatsSessionActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionAddBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSessionAdd - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionAdd(statsRouter, statsPostRouterStatsSessionAddBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionAdd', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionAddedExistingBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSessionAddedExisting - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionAddedExisting(statsRouter, statsPostRouterStatsSessionAddedExistingBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionAddedExisting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionDuplicateIdBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSessionDuplicateId - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionDuplicateId(statsRouter, statsPostRouterStatsSessionDuplicateIdBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionDuplicateId', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionFlowActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSessionFlowActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionFlowActive(statsRouter, statsPostRouterStatsSessionFlowActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionFlowActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionFlowAddFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionFlowAddFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionFlowAddFailure(statsRouter, statsPostRouterSessionFlowAddFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionFlowAddFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionFlowRemoveFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSessionFlowRemoveFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionFlowRemoveFailure(statsRouter, statsPostRouterSessionFlowRemoveFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionFlowRemoveFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSessionMaxRemoveTimeoutExceededBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSessionMaxRemoveTimeoutExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSessionMaxRemoveTimeoutExceeded(statsRouter, statsPostRouterSessionMaxRemoveTimeoutExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSessionMaxRemoveTimeoutExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSessionRemoveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSessionRemove - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSessionRemove(statsRouter, statsPostRouterStatsSessionRemoveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSessionRemove', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSourceNatActiveTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSourceNatActiveTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSourceNatActiveTables(statsRouter, statsPostRouterStatsSourceNatActiveTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSourceNatActiveTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNatAllocatePortsForDbBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNatAllocatePortsForDb - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNatAllocatePortsForDb(statsRouter, statsPostRouterNatAllocatePortsForDbBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNatAllocatePortsForDb', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNatGiidTransitionToActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNatGiidTransitionToActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNatGiidTransitionToActive(statsRouter, statsPostRouterNatGiidTransitionToActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNatGiidTransitionToActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNatGiidTransitionToInactiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterNatGiidTransitionToInactive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNatGiidTransitionToInactive(statsRouter, statsPostRouterNatGiidTransitionToInactiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNatGiidTransitionToInactive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSourceNatInactiveTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSourceNatInactiveTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSourceNatInactiveTables(statsRouter, statsPostRouterStatsSourceNatInactiveTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSourceNatInactiveTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterNatReinitializePortsInDbBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterNatReinitializePortsInDb - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterNatReinitializePortsInDb(statsRouter, statsPostRouterNatReinitializePortsInDbBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterNatReinitializePortsInDb', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReleasePortsToDbFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReleasePortsToDbFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReleasePortsToDbFailure(statsRouter, statsPostRouterReleasePortsToDbFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReleasePortsToDbFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReleasePortsToDbSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReleasePortsToDbSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReleasePortsToDbSuccess(statsRouter, statsPostRouterReleasePortsToDbSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReleasePortsToDbSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSourceNatReservedPortsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSourceNatReservedPorts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSourceNatReservedPorts(statsRouter, statsPostRouterStatsSourceNatReservedPortsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSourceNatReservedPorts', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSourceTenantMeterBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSourceTenantMeter - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSourceTenantMeter(statsRouter, statsPostRouterStatsSourceTenantMeterBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSourceTenantMeter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscClientsConnectsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSscClientsConnects - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscClientsConnects(statsRouter, statsPostRouterStatsSscClientsConnectsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscClientsConnects', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscClientsDisconnectsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscClientsDisconnects - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscClientsDisconnects(statsRouter, statsPostRouterStatsSscClientsDisconnectsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscClientsDisconnects', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscOperationsCompressionsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscOperationsCompressions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscOperationsCompressions(statsRouter, statsPostRouterStatsSscOperationsCompressionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscOperationsCompressions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscOperationsDecompressionsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSscOperationsDecompressions - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscOperationsDecompressions(statsRouter, statsPostRouterStatsSscOperationsDecompressionsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscOperationsDecompressions', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedByServiceDeregistrationsBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscReceivedByServiceDeregistrations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedByServiceDeregistrations(statsRouter, statsPostRouterSscReceivedByServiceDeregistrationsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedByServiceDeregistrations', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedByServicePublishesBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscReceivedByServicePublishes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedByServicePublishes(statsRouter, statsPostRouterSscReceivedByServicePublishesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedByServicePublishes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedByServiceRegistrationUpdatesBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedByServiceRegistrationUpdates - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedByServiceRegistrationUpdates(statsRouter, statsPostRouterReceivedByServiceRegistrationUpdatesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedByServiceRegistrationUpdates', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedByServiceRegistrationsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSscReceivedByServiceRegistrations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedByServiceRegistrations(statsRouter, statsPostRouterSscReceivedByServiceRegistrationsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedByServiceRegistrations', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedByServiceRequestsBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscReceivedByServiceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedByServiceRequests(statsRouter, statsPostRouterSscReceivedByServiceRequestsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedByServiceRequests', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedByServiceResponsesBodyParam = {
      parameters: [
        {
          name: 'service',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSscReceivedByServiceResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedByServiceResponses(statsRouter, statsPostRouterSscReceivedByServiceResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedByServiceResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsBadRequestResponsesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedErrorsBadRequestResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsBadRequestResponses(statsRouter, statsPostRouterReceivedErrorsBadRequestResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsBadRequestResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedErrorsInvalidMessageBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSscReceivedErrorsInvalidMessage - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedErrorsInvalidMessage(statsRouter, statsPostRouterSscReceivedErrorsInvalidMessageBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedErrorsInvalidMessage', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscReceivedErrorsInvalidRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscReceivedErrorsInvalidRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscReceivedErrorsInvalidRequest(statsRouter, statsPostRouterSscReceivedErrorsInvalidRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscReceivedErrorsInvalidRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsNoClientTransactionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedErrorsNoClientTransaction - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsNoClientTransaction(statsRouter, statsPostRouterReceivedErrorsNoClientTransactionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsNoClientTransaction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsNoEndpointsFoundBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedErrorsNoEndpointsFound - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsNoEndpointsFound(statsRouter, statsPostRouterReceivedErrorsNoEndpointsFoundBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsNoEndpointsFound', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsResponseNotReadyBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedErrorsResponseNotReady - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsResponseNotReady(statsRouter, statsPostRouterReceivedErrorsResponseNotReadyBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsResponseNotReady', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsServerErrorResponsesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterReceivedErrorsServerErrorResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsServerErrorResponses(statsRouter, statsPostRouterReceivedErrorsServerErrorResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsServerErrorResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsUnknownMessageTypeBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedErrorsUnknownMessageType - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsUnknownMessageType(statsRouter, statsPostRouterReceivedErrorsUnknownMessageTypeBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsUnknownMessageType', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReceivedErrorsUnknownSscRequestBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReceivedErrorsUnknownSscRequest - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReceivedErrorsUnknownSscRequest(statsRouter, statsPostRouterReceivedErrorsUnknownSscRequestBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReceivedErrorsUnknownSscRequest', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscSessionsActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscSessionsActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscSessionsActive(statsRouter, statsPostRouterStatsSscSessionsActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscSessionsActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscTransactionsClientBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSscTransactionsClient - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscTransactionsClient(statsRouter, statsPostRouterStatsSscTransactionsClientBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscTransactionsClient', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscTransactionsErrorsInsertionFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscTransactionsErrorsInsertionFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscTransactionsErrorsInsertionFailures(statsRouter, statsPostRouterSscTransactionsErrorsInsertionFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscTransactionsErrorsInsertionFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscTransactionsServerBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscTransactionsServer - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscTransactionsServer(statsRouter, statsPostRouterStatsSscTransactionsServerBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscTransactionsServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscTransmittedByServicePublishesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSscTransmittedByServicePublishes - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscTransmittedByServicePublishes(statsRouter, statsPostRouterSscTransmittedByServicePublishesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscTransmittedByServicePublishes', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscTransmittedByServiceRequestsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscTransmittedByServiceRequests - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscTransmittedByServiceRequests(statsRouter, statsPostRouterSscTransmittedByServiceRequestsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscTransmittedByServiceRequests', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscTransmittedCompletedResponsesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscTransmittedCompletedResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscTransmittedCompletedResponses(statsRouter, statsPostRouterStatsSscTransmittedCompletedResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscTransmittedCompletedResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscTransmittedErrorsWriteFailuresBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterSscTransmittedErrorsWriteFailures - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscTransmittedErrorsWriteFailures(statsRouter, statsPostRouterSscTransmittedErrorsWriteFailuresBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscTransmittedErrorsWriteFailures', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscTransmittedLocalResponsesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsSscTransmittedLocalResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscTransmittedLocalResponses(statsRouter, statsPostRouterStatsSscTransmittedLocalResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscTransmittedLocalResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterSscTransmittedPublishOnRegistrationsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterSscTransmittedPublishOnRegistrations - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterSscTransmittedPublishOnRegistrations(statsRouter, statsPostRouterSscTransmittedPublishOnRegistrationsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterSscTransmittedPublishOnRegistrations', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsSscTransmittedRetransmittedResponsesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsSscTransmittedRetransmittedResponses - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsSscTransmittedRetransmittedResponses(statsRouter, statsPostRouterStatsSscTransmittedRetransmittedResponsesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsSscTransmittedRetransmittedResponses', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDevicePortQueueDepthAvgBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDevicePortQueueDepthAvg - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDevicePortQueueDepthAvg(statsRouter, statsPostRouterDevicePortQueueDepthAvgBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDevicePortQueueDepthAvg', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDevicePortQueueDepthMaxBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDevicePortQueueDepthMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDevicePortQueueDepthMax(statsRouter, statsPostRouterDevicePortQueueDepthMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDevicePortQueueDepthMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDevicePortQueueDepthMinBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterDevicePortQueueDepthMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDevicePortQueueDepthMin(statsRouter, statsPostRouterDevicePortQueueDepthMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDevicePortQueueDepthMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterDevicePortQueueDepthTotalBodyParam = {
      parameters: [
        {
          name: 'port',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterDevicePortQueueDepthTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterDevicePortQueueDepthTotal(statsRouter, statsPostRouterDevicePortQueueDepthTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterDevicePortQueueDepthTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngDevicePortScheduleFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEngDevicePortScheduleFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngDevicePortScheduleFailure(statsRouter, statsPostRouterEngDevicePortScheduleFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngDevicePortScheduleFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngDevicePortScheduleSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEngDevicePortScheduleSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngDevicePortScheduleSuccess(statsRouter, statsPostRouterEngDevicePortScheduleSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngDevicePortScheduleSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInternalApplicationQueueDepthAvgBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInternalApplicationQueueDepthAvg - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInternalApplicationQueueDepthAvg(statsRouter, statsPostRouterInternalApplicationQueueDepthAvgBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInternalApplicationQueueDepthAvg', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInternalApplicationQueueDepthMaxBodyParam = {
      parameters: [
        {
          name: 'traffic-class',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterInternalApplicationQueueDepthMax - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInternalApplicationQueueDepthMax(statsRouter, statsPostRouterInternalApplicationQueueDepthMaxBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInternalApplicationQueueDepthMax', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInternalApplicationQueueDepthMinBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterInternalApplicationQueueDepthMin - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInternalApplicationQueueDepthMin(statsRouter, statsPostRouterInternalApplicationQueueDepthMinBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInternalApplicationQueueDepthMin', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterInternalApplicationQueueDepthTotalBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterInternalApplicationQueueDepthTotal - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterInternalApplicationQueueDepthTotal(statsRouter, statsPostRouterInternalApplicationQueueDepthTotalBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterInternalApplicationQueueDepthTotal', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngInternalApplicationScheduleFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEngInternalApplicationScheduleFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngInternalApplicationScheduleFailure(statsRouter, statsPostRouterEngInternalApplicationScheduleFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngInternalApplicationScheduleFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngInternalApplicationScheduleSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterEngInternalApplicationScheduleSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngInternalApplicationScheduleSuccess(statsRouter, statsPostRouterEngInternalApplicationScheduleSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngInternalApplicationScheduleSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngInternalApplicationSentRetryBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEngInternalApplicationSentRetry - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngInternalApplicationSentRetry(statsRouter, statsPostRouterEngInternalApplicationSentRetryBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngInternalApplicationSentRetry', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterEngInternalApplicationSentSuccessBodyParam = {
      parameters: [
        {
          name: 'internal-application',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterEngInternalApplicationSentSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterEngInternalApplicationSentSuccess(statsRouter, statsPostRouterEngInternalApplicationSentSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterEngInternalApplicationSentSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsTrafficExportEnqueueFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsTrafficExportEnqueueFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsTrafficExportEnqueueFailure(statsRouter, statsPostRouterStatsTrafficExportEnqueueFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsTrafficExportEnqueueFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterTrafficExportRateLimitExceededBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterTrafficExportRateLimitExceeded - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterTrafficExportRateLimitExceeded(statsRouter, statsPostRouterTrafficExportRateLimitExceededBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterTrafficExportRateLimitExceeded', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsTrafficExportTransmitBatchesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterStatsTrafficExportTransmitBatches - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsTrafficExportTransmitBatches(statsRouter, statsPostRouterStatsTrafficExportTransmitBatchesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsTrafficExportTransmitBatches', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsTrafficExportTransmitFailureBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsTrafficExportTransmitFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsTrafficExportTransmitFailure(statsRouter, statsPostRouterStatsTrafficExportTransmitFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsTrafficExportTransmitFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsTrafficExportTransmitSuccessBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsTrafficExportTransmitSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsTrafficExportTransmitSuccess(statsRouter, statsPostRouterStatsTrafficExportTransmitSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsTrafficExportTransmitSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWaypointActiveInterTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWaypointActiveInterTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWaypointActiveInterTables(statsRouter, statsPostRouterWaypointActiveInterTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWaypointActiveInterTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPortsForDefaultRangeTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterPortsForDefaultRangeTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPortsForDefaultRangeTables(statsRouter, statsPostRouterPortsForDefaultRangeTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPortsForDefaultRangeTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterPortsForRangeBasedTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterPortsForRangeBasedTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterPortsForRangeBasedTables(statsRouter, statsPostRouterPortsForRangeBasedTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterPortsForRangeBasedTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWaypointGiidTransitionToActiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterWaypointGiidTransitionToActive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWaypointGiidTransitionToActive(statsRouter, statsPostRouterWaypointGiidTransitionToActiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWaypointGiidTransitionToActive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWaypointGiidTransitionToInactiveBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWaypointGiidTransitionToInactive - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWaypointGiidTransitionToInactive(statsRouter, statsPostRouterWaypointGiidTransitionToInactiveBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWaypointGiidTransitionToInactive', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWaypointInactiveInterTablesBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterWaypointInactiveInterTables - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWaypointInactiveInterTables(statsRouter, statsPostRouterWaypointInactiveInterTablesBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWaypointInactiveInterTables', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWaypointReinitializePortsInDbBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWaypointReinitializePortsInDb - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWaypointReinitializePortsInDb(statsRouter, statsPostRouterWaypointReinitializePortsInDbBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWaypointReinitializePortsInDb', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReleasePortsToDbFailure2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReleasePortsToDbFailure2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReleasePortsToDbFailure2(statsRouter, statsPostRouterReleasePortsToDbFailure2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReleasePortsToDbFailure2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterReleasePortsToDbSuccess2BodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterReleasePortsToDbSuccess2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterReleasePortsToDbSuccess2(statsRouter, statsPostRouterReleasePortsToDbSuccess2BodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterReleasePortsToDbSuccess2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterStatsWaypointReservedPortsBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterStatsWaypointReservedPorts - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterStatsWaypointReservedPorts(statsRouter, statsPostRouterStatsWaypointReservedPortsBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterStatsWaypointReservedPorts', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAesContextCreateFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAesContextCreateFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAesContextCreateFailure(statsRouter, statsPostRouterAesContextCreateFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAesContextCreateFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAesContextCreateSuccessBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAesContextCreateSuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAesContextCreateSuccess(statsRouter, statsPostRouterAesContextCreateSuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAesContextCreateSuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAesContextDestroyFailureBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: false
        }
      ]
    };
    describe('#postRouterAesContextDestroyFailure - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAesContextDestroyFailure(statsRouter, statsPostRouterAesContextDestroyFailureBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAesContextDestroyFailure', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterAesContextDestroySuccessBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterAesContextDestroySuccess - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterAesContextDestroySuccess(statsRouter, statsPostRouterAesContextDestroySuccessBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterAesContextDestroySuccess', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWorkerCoreCachingLoopExceptionBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWorkerCoreCachingLoopException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWorkerCoreCachingLoopException(statsRouter, statsPostRouterWorkerCoreCachingLoopExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWorkerCoreCachingLoopException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWorkerCoreControlMessagesSentBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWorkerCoreControlMessagesSent - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWorkerCoreControlMessagesSent(statsRouter, statsPostRouterWorkerCoreControlMessagesSentBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWorkerCoreControlMessagesSent', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWorkerCorePacketProcessingUtilizationBodyParam = {
      parameters: [
        {
          name: 'core',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWorkerCorePacketProcessingUtilization - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWorkerCorePacketProcessingUtilization(statsRouter, statsPostRouterWorkerCorePacketProcessingUtilizationBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWorkerCorePacketProcessingUtilization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const statsPostRouterWorkerCoreProcessLoopExceptionBodyParam = {
      parameters: [
        {
          name: 'node',
          values: [
            'string'
          ],
          itemize: true
        }
      ]
    };
    describe('#postRouterWorkerCoreProcessLoopException - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.postRouterWorkerCoreProcessLoopException(statsRouter, statsPostRouterWorkerCoreProcessLoopExceptionBodyParam, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Stats', 'postRouterWorkerCoreProcessLoopException', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const serviceRouter = 'fakedata';
    describe('#getService - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getService(null, null, serviceRouter, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Service', 'getService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const serviceService = 'fakedata';
    describe('#getService2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getService2(null, null, serviceRouter, serviceService, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.routes);
                assert.equal(true, Array.isArray(data.response.addresses));
                assert.equal('string', data.response.serviceGroup);
                assert.equal('string', data.response.bandwidth);
                assert.equal('string', data.response.sessions);
                assert.equal('string', data.response.sessionArrivalRate);
                assert.equal('string', data.response.scope);
                assert.equal('string', data.response.tenant);
                assert.equal('string', data.response.bytesTransmitted);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Service', 'getService2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getServiceClass - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getServiceClass(null, null, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('ServiceClass', 'getServiceClass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const tenantRouter = 'fakedata';
    describe('#getTenant - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getTenant(tenantRouter, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('object', typeof data.response[0]);
                assert.equal('object', typeof data.response[1]);
                assert.equal('object', typeof data.response[2]);
                assert.equal('object', typeof data.response[3]);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Tenant', 'getTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const tenantTenant = 'fakedata';
    describe('#getTenant2 - errors', () => {
      it('should work if integrated or standalone with mockdata', (done) => {
        try {
          a.getTenant2(tenantRouter, tenantTenant, null, null, (data, error) => {
            try {
              if (stub) {
                runCommonAsserts(data, error);
                assert.equal('string', data.response.name);
                assert.equal('string', data.response.description);
                assert.equal('string', data.response.bandwidth);
                assert.equal(8, data.response.sessions);
                assert.equal(7, data.response.traffic);
                assert.equal(9, data.response.services);
                assert.equal(2, data.response.interfaces);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Tenant', 'getTenant2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityDistrict - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityDistrict(configConfigStore, configDistrict, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityDistrict', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityDscpMapDscpmap - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityDscpMapDscpmap(configConfigStore, configDscpmap, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityDscpMapDscpmap', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigMapDscpmapDscpPrioritizationDscpprioritization - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigMapDscpmapDscpPrioritizationDscpprioritization(configConfigStore, configDscpmap, configDscpprioritization, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigMapDscpmapDscpPrioritizationDscpprioritization', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPrioritizationDscpprioritizationDscpRangeDscprange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPrioritizationDscpprioritizationDscpRangeDscprange(configConfigStore, configDscpmap, configDscpprioritization, configDscprange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPrioritizationDscpprioritizationDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigDscpmapDscpTrafficClassDscptrafficclass - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigDscpmapDscpTrafficClassDscptrafficclass(configConfigStore, configDscpmap, configDscptrafficclass, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigDscpmapDscpTrafficClassDscptrafficclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigClassDscptrafficclassDscpRangeDscprange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigClassDscptrafficclassDscpRangeDscprange(configConfigStore, configDscpmap, configDscptrafficclass, configDscprange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigClassDscptrafficclassDscpRangeDscprange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityIpfixCollectorIpfixcollector - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityIpfixCollectorIpfixcollector(configConfigStore, configIpfixcollector, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityIpfixCollectorIpfixcollector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityLdapServerLdapserver - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityLdapServerLdapserver(configConfigStore, configLdapserver, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityLdapServerLdapserver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityRouter - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityRouter(configConfigStore, configRouter, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityRouter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterDistrictSettingsDistrictsettings - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterDistrictSettingsDistrictsettings(configConfigStore, configRouter, configDistrictsettings, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterDistrictSettingsDistrictsettings', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterDnsDnsconfig - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterDnsDnsconfig(configConfigStore, configRouter, configDnsconfig, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterDnsDnsconfig', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterNatPoolNatpool - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterNatPoolNatpool(configConfigStore, configRouter, configNatpool, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterNatPoolNatpool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPoolNatpoolAddressAddresspool - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPoolNatpoolAddressAddresspool(configConfigStore, configRouter, configNatpool, configAddresspool, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPoolNatpoolAddressAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterNode - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterNode(configConfigStore, configRouter, configNode, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterNode', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNodeDeviceInterfaceDeviceinterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNodeDeviceInterfaceDeviceinterface(configConfigStore, configRouter, configNode, configDeviceinterface, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNodeDeviceInterfaceDeviceinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigInterfaceDeviceinterfaceNetworkNetworkinterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigInterfaceDeviceinterfaceNetworkNetworkinterface(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigInterfaceDeviceinterfaceNetworkNetworkinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNetworkInterfaceNetworkinterfaceAddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNetworkInterfaceNetworkinterfaceAddress(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNetworkInterfaceNetworkinterfaceAddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAddressHostServiceHostservice - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAddressHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAddressHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceHostserviceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceHostserviceAccessPolicyAccesspolicy(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceHostserviceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceHostserviceAddressPoolAddresspool - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceHostserviceAddressPoolAddresspool(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceHostserviceAddressPoolAddresspool', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAddressPoolAddresspoolCustom - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAddressPoolAddresspoolCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configCustom, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAddressPoolAddresspoolCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPoolAddresspoolStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPoolAddresspoolStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPoolAddresspoolStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStaticAssignmentStaticassignmentCustom - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStaticAssignmentStaticassignmentCustom(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configCustom, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStaticAssignmentStaticassignmentCustom', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAssignmentStaticassignmentStaticRouteStaticroute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAssignmentStaticassignmentStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configStaticroute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAssignmentStaticassignmentStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticassignment, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPoolAddresspoolStaticRouteStaticroute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPoolAddresspoolStaticRouteStaticroute(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configStaticroute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPoolAddresspoolStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAddresspoolVendorSpecificInformationVendorspecificinformation - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAddresspoolVendorSpecificInformationVendorspecificinformation(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configAddresspool, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAddresspoolVendorSpecificInformationVendorspecificinformation', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceHostserviceStaticAssignmentStaticassignment - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceHostserviceStaticAssignmentStaticassignment(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceHostserviceStaticAssignmentStaticassignment', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStaticAssignmentStaticassignmentCustom2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStaticAssignmentStaticassignmentCustom2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configCustom, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStaticAssignmentStaticassignmentCustom2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAssignmentStaticassignmentStaticRouteStaticroute2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAssignmentStaticassignmentStaticRouteStaticroute2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configStaticroute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAssignmentStaticassignmentStaticRouteStaticroute2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendoridentifyingvendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigIdentifyingVendorSpecificInformationVendoridentifyingvendorspecificinformation3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configStaticassignment, configVendorspecificinformation, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStaticassignmentVendorSpecificInformationVendorspecificinformation2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigHostServiceHostserviceTransport - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigHostServiceHostserviceTransport(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigHostServiceHostserviceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigTransportPortRangePortrange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigTransportPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAddress, configHostservice, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigTransportPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNetworkInterfaceNetworkinterfaceAdjacency - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNetworkInterfaceNetworkinterfaceAdjacency(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNetworkInterfaceNetworkinterfaceAdjacency', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAdjacencyPortRangePortrange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAdjacencyPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAdjacencyPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigMetricsDecreaseReportDelayDecreasereportdelay - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigMetricsDecreaseReportDelayDecreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configDecreasereportdelay, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigMetricsDecreaseReportDelayDecreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigMetricsIncreaseReportDelayIncreasereportdelay - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigMetricsIncreaseReportDelayIncreasereportdelay(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configAdjacency, configIncreasereportdelay, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigMetricsIncreaseReportDelayIncreasereportdelay', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigInterfaceNetworkinterfaceHostServiceHostservice - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigInterfaceNetworkinterfaceHostServiceHostservice(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigInterfaceNetworkinterfaceHostServiceHostservice', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceHostserviceAccessPolicyAccesspolicy2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceHostserviceAccessPolicyAccesspolicy2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceHostserviceAccessPolicyAccesspolicy2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigHostServiceHostserviceTransport2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigHostServiceHostserviceTransport2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigHostServiceHostserviceTransport2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigTransportPortRangePortrange2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigTransportPortRangePortrange2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configHostservice, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigTransportPortRangePortrange2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configIfcfgoption, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigInterfaceNetworkinterfaceIfcfgOptionIfcfgoption', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNetworkInterfaceNetworkinterfaceNeighbor - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNetworkInterfaceNetworkinterfaceNeighbor(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighbor, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNetworkInterfaceNetworkinterfaceNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNetworkInterfaceNetworkinterfaceNeighborhood - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNetworkInterfaceNetworkinterfaceNeighborhood(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNetworkInterfaceNetworkinterfaceNeighborhood', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNeighborhoodPortRangePortrange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNeighborhoodPortRangePortrange(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNeighborhoodPortRangePortrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigMetricsDecreaseReportDelayDecreasereportdelay2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigMetricsDecreaseReportDelayDecreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configDecreasereportdelay, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigMetricsDecreaseReportDelayDecreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigMetricsIncreaseReportDelayIncreasereportdelay2 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigMetricsIncreaseReportDelayIncreasereportdelay2(configConfigStore, configRouter, configNode, configDeviceinterface, configNetworkinterface, configNeighborhood, configIncreasereportdelay, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigMetricsIncreaseReportDelayIncreasereportdelay2', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterPeer - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterPeer(configConfigStore, configRouter, configPeer, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterPeer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterRedundancyGroupRedundancygroup - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterRedundancyGroupRedundancygroup(configConfigStore, configRouter, configRedundancygroup, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterRedundancyGroupRedundancygroup', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRedundancyGroupRedundancygroupMember - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRedundancyGroupRedundancygroupMember(configConfigStore, configRouter, configRedundancygroup, configMember, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRedundancyGroupRedundancygroupMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterRouting - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterRouting(configConfigStore, configRouter, configRouting, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterRouting', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingInterface(configConfigStore, configRouter, configRouting, configInterfaceParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingOspf - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingOspf(configConfigStore, configRouter, configRouting, configOspf, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingOspf', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigOspfArea - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigOspfArea(configConfigStore, configRouter, configRouting, configOspf, configArea, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigOspfArea', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAreaInterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAreaInterface(configConfigStore, configRouter, configRouting, configOspf, configArea, configInterfaceParam, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAreaInterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAreaSummaryRangeSummaryrange - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAreaSummaryRangeSummaryrange(configConfigStore, configRouter, configRouting, configOspf, configArea, configSummaryrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAreaSummaryRangeSummaryrange', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigOspfRedistribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigOspfRedistribute(configConfigStore, configRouter, configRouting, configOspf, configRedistribute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigOspfRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingProtocolRoutingprotocol - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingProtocolRoutingprotocol(configConfigStore, configRouter, configRouting, configRoutingprotocol, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingProtocolRoutingprotocol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigProtocolRoutingprotocolAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigProtocolRoutingprotocolAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigProtocolRoutingprotocolAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigFamilyAddressfamilyAggregateAddressAggregateaddress - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigFamilyAddressfamilyAggregateAddressAggregateaddress(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configAggregateaddress, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigFamilyAddressfamilyAggregateAddressAggregateaddress', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAddressFamilyAddressfamilyNetwork - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAddressFamilyAddressfamilyNetwork(configConfigStore, configRouter, configRouting, configRoutingprotocol, configAddressfamily, configNetwork, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAddressFamilyAddressfamilyNetwork', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingProtocolRoutingprotocolNeighbor - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingProtocolRoutingprotocolNeighbor(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingProtocolRoutingprotocolNeighbor', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigNeighborAddressFamilyAddressfamily - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigNeighborAddressFamilyAddressfamily(configConfigStore, configRouter, configRouting, configRoutingprotocol, configNeighbor, configAddressfamily, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigNeighborAddressFamilyAddressfamily', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingProtocolRoutingprotocolRedistribute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingProtocolRoutingprotocolRedistribute(configConfigStore, configRouter, configRouting, configRoutingprotocol, configRedistribute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingProtocolRoutingprotocolRedistribute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRoutingStaticRouteStaticroute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRoutingStaticRouteStaticroute(configConfigStore, configRouter, configRouting, configStaticroute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRoutingStaticRouteStaticroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStaticrouteNextHopInterfaceNexthopinterface - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStaticrouteNextHopInterfaceNexthopinterface(configConfigStore, configRouter, configRouting, configStaticroute, configNexthopinterface, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStaticrouteNextHopInterfaceNexthopinterface', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterServiceRoutePolicyServiceroutepolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterServiceRoutePolicyServiceroutepolicy(configConfigStore, configRouter, configServiceroutepolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterServiceRoutePolicyServiceroutepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterServiceRouteServiceroute - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterServiceRouteServiceroute(configConfigStore, configRouter, configServiceroute, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterServiceRouteServiceroute', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceRouteServicerouteHost - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceRouteServicerouteHost(configConfigStore, configRouter, configServiceroute, configHost, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceRouteServicerouteHost', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouteServicerouteNextHopNexthop - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouteServicerouteNextHopNexthop(configConfigStore, configRouter, configServiceroute, configNexthop, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouteServicerouteNextHopNexthop', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigRouterSystemLogCategoryLogcategory - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigRouterSystemLogCategoryLogcategory(configConfigStore, configRouter, configLogcategory, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigRouterSystemLogCategoryLogcategory', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigSystemNtpServer - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigSystemNtpServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigSystemNtpServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigSnmpServerAccessControlAccesscontrol - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigSnmpServerAccessControlAccesscontrol(configConfigStore, configRouter, configAccesscontrol, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigSnmpServerAccessControlAccesscontrol', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigSnmpServerNotificationReceiverNotificationreceiver - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigSnmpServerNotificationReceiverNotificationreceiver(configConfigStore, configRouter, configNotificationreceiver, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigSnmpServerNotificationReceiverNotificationreceiver', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServicesWebserverServer - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServicesWebserverServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServicesWebserverServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigSystemSyslogServer - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigSystemSyslogServer(configConfigStore, configRouter, configServer, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigSystemSyslogServer', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAuthorityRoutingFilter - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAuthorityRoutingFilter(configConfigStore, configFilter, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAuthorityRoutingFilter', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigFilterRule - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigFilterRule(configConfigStore, configFilter, configRule, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigFilterRule', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigAuthorityRoutingPolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigAuthorityRoutingPolicy(configConfigStore, configPolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigAuthorityRoutingPolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPolicyStatement - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPolicyStatement(configConfigStore, configPolicy, configStatement, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPolicyStatement', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStatementAction - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStatementAction(configConfigStore, configPolicy, configStatement, configAction, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStatementAction', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStatementCondition - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStatementCondition(configConfigStore, configPolicy, configStatement, configCondition, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStatementCondition', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthoritySecurity - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthoritySecurity(configConfigStore, configSecurity, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthoritySecurity', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityServiceClassServiceclass - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityServiceClassServiceclass(configConfigStore, configServiceclass, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityServiceClassServiceclass', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityServicePolicyServicepolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityServicePolicyServicepolicy(configConfigStore, configServicepolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityServicePolicyServicepolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigPolicyServicepolicyAppliesToAppliesto - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigPolicyServicepolicyAppliesToAppliesto(configConfigStore, configServicepolicy, configAppliesto, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigPolicyServicepolicyAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServicePolicyServicepolicyVector - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServicePolicyServicepolicyVector(configConfigStore, configServicepolicy, configVector, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServicePolicyServicepolicyVector', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityService - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityService(configConfigStore, configService, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityService', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceAccessPolicyAccesspolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceAccessPolicyAccesspolicy(configConfigStore, configService, configAccesspolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceAccessPolicyAccesspolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceAppliesToAppliesto - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceAppliesToAppliesto(configConfigStore, configService, configAppliesto, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceAppliesToAppliesto', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceMulticastSenderPolicyMulticastsenderpolicy - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceMulticastSenderPolicyMulticastsenderpolicy(configConfigStore, configService, configMulticastsenderpolicy, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceMulticastSenderPolicyMulticastsenderpolicy', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigServiceTransport - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigServiceTransport(configConfigStore, configService, configTransport, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigServiceTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigTransportPortRangePortrange3 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigTransportPortRangePortrange3(configConfigStore, configService, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigTransportPortRangePortrange3', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthoritySessionTypeSessiontype - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthoritySessionTypeSessiontype(configConfigStore, configSessiontype, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthoritySessionTypeSessiontype', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigSessionTypeSessiontypeTransport - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigSessionTypeSessiontypeTransport(configConfigStore, configSessiontype, configTransport, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigSessionTypeSessiontypeTransport', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigTransportPortRangePortrange4 - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigTransportPortRangePortrange4(configConfigStore, configSessiontype, configTransport, configPortrange, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigTransportPortRangePortrange4', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityStepRepoSteprepo - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityStepRepoSteprepo(configConfigStore, configSteprepo, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityStepRepoSteprepo', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityTenant - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityTenant(configConfigStore, configTenant, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityTenant', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigTenantMember - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigTenantMember(configConfigStore, configTenant, configMember, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigTenantMember', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteConfigStoreAuthorityTrafficProfileTrafficprofile - errors', () => {
      it('should work if integrated but since no mockdata should error when run standalone', (done) => {
        try {
          a.deleteConfigStoreAuthorityTrafficProfileTrafficprofile(configConfigStore, configTrafficprofile, (data, error) => {
            try {
              if (stub) {
                const displayE = 'Error 400 received on request';
                runErrorAsserts(data, error, 'AD.500', 'Test-128technology-connectorRest-handleEndResponse', displayE);
              } else {
                runCommonAsserts(data, error);
              }
              saveMockData('Config', 'deleteConfigStoreAuthorityTrafficProfileTrafficprofile', 'default', data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
  });
});
